@charset "UTF-8";
.logo--man-grail::before, .app-security__collapse-button::before, .btn-settings::before, .btn-hint::before, [class^='ico-']::before, .rejected .badge::before, .review .badge::before, .unapproved .badge::before, .cleared .badge::before, .approved .badge::before {
  display: inline-block;
  vertical-align: middle;
  text-align: center;
  text-decoration: none;
  text-rendering: optimizeLegibility;
  font-family: 'icon';
  font-weight: normal;
  -webkit-font-smoothing: antialiased;
  font-style: normal;
  speak: none;
}

.app-header__nav--main ul, .app-header__nav--secondary ul {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  margin: 0;
  padding: 0;
  list-style: none;
}

@font-face {
  font-family: "istok";
  font-weight: 400;
  font-style: normal;
  src: url("../fonts/istok.woff?v1") format("woff"), url("../fonts/istok.ttf?v1") format("truetype"), url("../fonts/istok.svg?v1#istok") format("svg");
}

@font-face {
  font-family: "istok";
  font-weight: 700;
  font-style: normal;
  src: url("../fonts/istok-bold.woff?v1") format("woff"), url("../fonts/istok-bold.ttf?v1") format("truetype"), url("../fonts/istok-bold.svg?v1#istok") format("svg");
}

@font-face {
  font-family: "road_rage";
  font-weight: 400;
  font-style: normal;
  src: url("../fonts/Road_Rage.woff?v1") format("woff"), url("../fonts/Road_Rage.ttf?v1") format("truetype"), url("../fonts/Road_Rage.svg?v1#road_rage") format("svg");
}

.title-font {
  font-family: "road_rage", Fallback, sans-serif;
  font-size: 20px;
  text-align: center;
  padding-top: .2rem !important;
  padding-bottom: .2rem !important;
}

.app-header__nav--main, .app-header__nav--secondary {
  text-transform: uppercase;
}

.security__title, .title {
  display: inline-block;
  border-radius: .2em;
  background: #2a91d1;
  padding: .2em .3em;
  width: auto;
  line-height: 1;
  color: white;
  font-weight: 400;
}

.table--property th, label, .property-pair dt, .label {
  color: #656c7e;
  font-weight: 400;
}

.rejected .badge, .review .badge, .unapproved .badge, .cleared .badge, .approved .badge {
  font-size: .7rem;
  font-weight: 400;
}

@font-face {
  font-family: "icon";
  font-weight: normal;
  font-style: normal;
  src: url("../fonts/icograil.woff?v1") format("woff"), url("../fonts/icograil.ttf?v1") format("truetype"), url("../fonts/icograil.svg?v1#icon") format("svg");
}

*,
*::before,
*::after {
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
}

html {
  font-family: sans-serif;
  line-height: 1.15;
  -webkit-text-size-adjust: 100%;
  -ms-text-size-adjust: 100%;
  -ms-overflow-style: scrollbar;
  -webkit-tap-highlight-color: transparent;
}

*:focus {
  outline: transparent;
}

@-ms-viewport {
  width: device-width;
}

article, aside, dialog, figcaption, figure, footer, header, hgroup, main, nav, section {
  display: block;
}

body {
  margin: 0;
  font-family: "Istok", "Helvetica", Arial, sans-serif;
  font-size: 0.8125rem;
  font-weight: normal;
  line-height: 1.5;
  color: #404040;
  text-align: left;
  background-color: white;
}

[tabindex="-1"]:focus {
  outline: none !important;
}

hr {
  -webkit-box-sizing: content-box;
          box-sizing: content-box;
  height: 0;
  overflow: visible;
}

h1, h2, h3, h4, h5, h6 {
  margin-top: 0;
  margin-bottom: .5rem;
}

p {
  margin-top: 0;
  margin-bottom: 1rem;
}

abbr[title],
abbr[data-original-title] {
  text-decoration: underline;
  -webkit-text-decoration: underline dotted;
          text-decoration: underline dotted;
  cursor: help;
  border-bottom: 0;
}

address {
  margin-bottom: 1rem;
  font-style: normal;
  line-height: inherit;
}

ol,
ul,
dl {
  margin-top: 0;
  margin-bottom: 1rem;
}

ol ol,
ul ul,
ol ul,
ul ol {
  margin-bottom: 0;
}

dt {
  font-weight: bold;
}

dd {
  margin-bottom: .5rem;
  margin-left: 0;
}

blockquote {
  margin: 0 0 1rem;
}

dfn {
  font-style: italic;
}

b,
strong {
  font-weight: bolder;
}

small {
  font-size: 80%;
}

sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
}

sub {
  bottom: -.25em;
}

sup {
  top: -.5em;
}

a {
  color: #004c93;
  text-decoration: none;
  background-color: transparent;
  -webkit-text-decoration-skip: objects;
}

a:hover {
  color: #2a91d1;
  text-decoration: underline;
}

a:not([href]):not([tabindex]) {
  color: inherit;
  text-decoration: none;
}

a:not([href]):not([tabindex]):focus, a:not([href]):not([tabindex]):hover {
  color: inherit;
  text-decoration: none;
}

a:not([href]):not([tabindex]):focus {
  outline: 0;
}

pre,
code,
kbd,
samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

pre {
  margin-top: 0;
  margin-bottom: 1rem;
  overflow: auto;
}

figure {
  margin: 0 0 1rem;
}

img {
  vertical-align: middle;
  border-style: none;
}

svg:not(:root) {
  overflow: hidden;
}

a,
area,
button,
[role="button"],
input,
label,
select,
summary,
textarea {
  -ms-touch-action: manipulation;
      touch-action: manipulation;
}

table {
  border-collapse: collapse;
}

caption {
  padding-top: 0.2rem;
  padding-bottom: 0.2rem;
  color: #656c7e;
  text-align: left;
  caption-side: bottom;
}

th {
  text-align: inherit;
}

label {
  display: inline-block;
  margin-bottom: .5rem;
}

button:focus {
  outline: 1px dotted;
  outline: 5px auto -webkit-focus-ring-color;
}

input,
button,
select,
optgroup,
textarea {
  margin: 0;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}

button,
input {
  overflow: visible;
}

button,
select {
  text-transform: none;
}

button,
html [type="button"],
[type="reset"],
[type="submit"] {
  -webkit-appearance: button;
}

button::-moz-focus-inner,
[type="button"]::-moz-focus-inner,
[type="reset"]::-moz-focus-inner,
[type="submit"]::-moz-focus-inner {
  padding: 0;
  border-style: none;
}

input[type="radio"],
input[type="checkbox"] {
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  padding: 0;
}

input[type="date"],
input[type="time"],
input[type="datetime-local"],
input[type="month"] {
  -webkit-appearance: listbox;
}

textarea {
  overflow: auto;
  resize: vertical;
}

fieldset {
  min-width: 0;
  padding: 0;
  margin: 0;
  border: 0;
}

legend {
  display: block;
  width: 100%;
  max-width: 100%;
  padding: 0;
  margin-bottom: .5rem;
  font-size: 1.5rem;
  line-height: inherit;
  color: inherit;
  white-space: normal;
}

progress {
  vertical-align: baseline;
}

[type="number"]::-webkit-inner-spin-button,
[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

[type="search"] {
  outline-offset: -2px;
  -webkit-appearance: none;
}

[type="search"]::-webkit-search-cancel-button,
[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

::-webkit-file-upload-button {
  font: inherit;
  -webkit-appearance: button;
}

output {
  display: inline-block;
}

summary {
  display: list-item;
}

template {
  display: none;
}

[hidden] {
  display: none !important;
}

.container {
  margin-right: auto;
  margin-left: auto;
  padding-right: 15px;
  padding-left: 15px;
  width: 100%;
}

@media (min-width: 576px) {
  .container {
    max-width: 540px;
  }
}

@media (min-width: 768px) {
  .container {
    max-width: 720px;
  }
}

@media (min-width: 992px) {
  .container {
    max-width: 960px;
  }
}

@media (min-width: 1200px) {
  .container {
    max-width: 1140px;
  }
}

.container-fluid {
  width: 100%;
  margin-right: auto;
  margin-left: auto;
  padding-right: 15px;
  padding-left: 15px;
}

.row {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  margin-right: -15px;
  margin-left: -15px;
}

.no-gutters {
  margin-right: 0;
  margin-left: 0;
}

.no-gutters > .col,
.no-gutters > [class*="col-"] {
  padding-right: 0;
  padding-left: 0;
}

.col-1, .col-2, .col-3, .col-4, .col-5, .col-6, .col-7, .col-8, .col-9, .col-10, .col-11, .col-12, .col,
.col-auto, .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm,
.col-sm-auto, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-md,
.col-md-auto, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg,
.col-lg-auto, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12, .col-xl,
.col-xl-auto {
  position: relative;
  width: 100%;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px;
}

.col {
  -ms-flex-preferred-size: 0;
      flex-basis: 0;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  max-width: 100%;
}

.col-auto {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
          flex: 0 0 auto;
  width: auto;
  max-width: none;
}

.col-1 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 8.33333%;
          flex: 0 0 8.33333%;
  max-width: 8.33333%;
}

.col-2 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 16.66667%;
          flex: 0 0 16.66667%;
  max-width: 16.66667%;
}

.col-3 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 25%;
          flex: 0 0 25%;
  max-width: 25%;
}

.col-4 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 33.33333%;
          flex: 0 0 33.33333%;
  max-width: 33.33333%;
}

.col-5 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 41.66667%;
          flex: 0 0 41.66667%;
  max-width: 41.66667%;
}

.col-6 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 50%;
          flex: 0 0 50%;
  max-width: 50%;
}

.col-7 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 58.33333%;
          flex: 0 0 58.33333%;
  max-width: 58.33333%;
}

.col-8 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 66.66667%;
          flex: 0 0 66.66667%;
  max-width: 66.66667%;
}

.col-9 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 75%;
          flex: 0 0 75%;
  max-width: 75%;
}

.col-10 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 83.33333%;
          flex: 0 0 83.33333%;
  max-width: 83.33333%;
}

.col-11 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 91.66667%;
          flex: 0 0 91.66667%;
  max-width: 91.66667%;
}

.col-12 {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 100%;
          flex: 0 0 100%;
  max-width: 100%;
}

.order-1 {
  -webkit-box-ordinal-group: 2;
      -ms-flex-order: 1;
          order: 1;
}

.order-2 {
  -webkit-box-ordinal-group: 3;
      -ms-flex-order: 2;
          order: 2;
}

.order-3 {
  -webkit-box-ordinal-group: 4;
      -ms-flex-order: 3;
          order: 3;
}

.order-4 {
  -webkit-box-ordinal-group: 5;
      -ms-flex-order: 4;
          order: 4;
}

.order-5 {
  -webkit-box-ordinal-group: 6;
      -ms-flex-order: 5;
          order: 5;
}

.order-6 {
  -webkit-box-ordinal-group: 7;
      -ms-flex-order: 6;
          order: 6;
}

.order-7 {
  -webkit-box-ordinal-group: 8;
      -ms-flex-order: 7;
          order: 7;
}

.order-8 {
  -webkit-box-ordinal-group: 9;
      -ms-flex-order: 8;
          order: 8;
}

.order-9 {
  -webkit-box-ordinal-group: 10;
      -ms-flex-order: 9;
          order: 9;
}

.order-10 {
  -webkit-box-ordinal-group: 11;
      -ms-flex-order: 10;
          order: 10;
}

.order-11 {
  -webkit-box-ordinal-group: 12;
      -ms-flex-order: 11;
          order: 11;
}

.order-12 {
  -webkit-box-ordinal-group: 13;
      -ms-flex-order: 12;
          order: 12;
}

@media (min-width: 576px) {
  .col-sm {
    -ms-flex-preferred-size: 0;
        flex-basis: 0;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    max-width: 100%;
  }
  .col-sm-auto {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 auto;
            flex: 0 0 auto;
    width: auto;
    max-width: none;
  }
  .col-sm-1 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
            flex: 0 0 8.33333%;
    max-width: 8.33333%;
  }
  .col-sm-2 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
            flex: 0 0 16.66667%;
    max-width: 16.66667%;
  }
  .col-sm-3 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%;
    max-width: 25%;
  }
  .col-sm-4 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
            flex: 0 0 33.33333%;
    max-width: 33.33333%;
  }
  .col-sm-5 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
            flex: 0 0 41.66667%;
    max-width: 41.66667%;
  }
  .col-sm-6 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%;
    max-width: 50%;
  }
  .col-sm-7 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
            flex: 0 0 58.33333%;
    max-width: 58.33333%;
  }
  .col-sm-8 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
            flex: 0 0 66.66667%;
    max-width: 66.66667%;
  }
  .col-sm-9 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%;
    max-width: 75%;
  }
  .col-sm-10 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
            flex: 0 0 83.33333%;
    max-width: 83.33333%;
  }
  .col-sm-11 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
            flex: 0 0 91.66667%;
    max-width: 91.66667%;
  }
  .col-sm-12 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%;
    max-width: 100%;
  }
  .order-sm-1 {
    -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
            order: 1;
  }
  .order-sm-2 {
    -webkit-box-ordinal-group: 3;
        -ms-flex-order: 2;
            order: 2;
  }
  .order-sm-3 {
    -webkit-box-ordinal-group: 4;
        -ms-flex-order: 3;
            order: 3;
  }
  .order-sm-4 {
    -webkit-box-ordinal-group: 5;
        -ms-flex-order: 4;
            order: 4;
  }
  .order-sm-5 {
    -webkit-box-ordinal-group: 6;
        -ms-flex-order: 5;
            order: 5;
  }
  .order-sm-6 {
    -webkit-box-ordinal-group: 7;
        -ms-flex-order: 6;
            order: 6;
  }
  .order-sm-7 {
    -webkit-box-ordinal-group: 8;
        -ms-flex-order: 7;
            order: 7;
  }
  .order-sm-8 {
    -webkit-box-ordinal-group: 9;
        -ms-flex-order: 8;
            order: 8;
  }
  .order-sm-9 {
    -webkit-box-ordinal-group: 10;
        -ms-flex-order: 9;
            order: 9;
  }
  .order-sm-10 {
    -webkit-box-ordinal-group: 11;
        -ms-flex-order: 10;
            order: 10;
  }
  .order-sm-11 {
    -webkit-box-ordinal-group: 12;
        -ms-flex-order: 11;
            order: 11;
  }
  .order-sm-12 {
    -webkit-box-ordinal-group: 13;
        -ms-flex-order: 12;
            order: 12;
  }
}

@media (min-width: 768px) {
  .col-md {
    -ms-flex-preferred-size: 0;
        flex-basis: 0;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    max-width: 100%;
  }
  .col-md-auto {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 auto;
            flex: 0 0 auto;
    width: auto;
    max-width: none;
  }
  .col-md-1 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
            flex: 0 0 8.33333%;
    max-width: 8.33333%;
  }
  .col-md-2 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
            flex: 0 0 16.66667%;
    max-width: 16.66667%;
  }
  .col-md-3 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%;
    max-width: 25%;
  }
  .col-md-4 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
            flex: 0 0 33.33333%;
    max-width: 33.33333%;
  }
  .col-md-5 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
            flex: 0 0 41.66667%;
    max-width: 41.66667%;
  }
  .col-md-6 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%;
    max-width: 50%;
  }
  .col-md-7 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
            flex: 0 0 58.33333%;
    max-width: 58.33333%;
  }
  .col-md-8 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
            flex: 0 0 66.66667%;
    max-width: 66.66667%;
  }
  .col-md-9 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%;
    max-width: 75%;
  }
  .col-md-10 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
            flex: 0 0 83.33333%;
    max-width: 83.33333%;
  }
  .col-md-11 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
            flex: 0 0 91.66667%;
    max-width: 91.66667%;
  }
  .col-md-12 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%;
    max-width: 100%;
  }
  .order-md-1 {
    -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
            order: 1;
  }
  .order-md-2 {
    -webkit-box-ordinal-group: 3;
        -ms-flex-order: 2;
            order: 2;
  }
  .order-md-3 {
    -webkit-box-ordinal-group: 4;
        -ms-flex-order: 3;
            order: 3;
  }
  .order-md-4 {
    -webkit-box-ordinal-group: 5;
        -ms-flex-order: 4;
            order: 4;
  }
  .order-md-5 {
    -webkit-box-ordinal-group: 6;
        -ms-flex-order: 5;
            order: 5;
  }
  .order-md-6 {
    -webkit-box-ordinal-group: 7;
        -ms-flex-order: 6;
            order: 6;
  }
  .order-md-7 {
    -webkit-box-ordinal-group: 8;
        -ms-flex-order: 7;
            order: 7;
  }
  .order-md-8 {
    -webkit-box-ordinal-group: 9;
        -ms-flex-order: 8;
            order: 8;
  }
  .order-md-9 {
    -webkit-box-ordinal-group: 10;
        -ms-flex-order: 9;
            order: 9;
  }
  .order-md-10 {
    -webkit-box-ordinal-group: 11;
        -ms-flex-order: 10;
            order: 10;
  }
  .order-md-11 {
    -webkit-box-ordinal-group: 12;
        -ms-flex-order: 11;
            order: 11;
  }
  .order-md-12 {
    -webkit-box-ordinal-group: 13;
        -ms-flex-order: 12;
            order: 12;
  }
}

@media (min-width: 992px) {
  .col-lg {
    -ms-flex-preferred-size: 0;
        flex-basis: 0;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    max-width: 100%;
  }
  .col-lg-auto {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 auto;
            flex: 0 0 auto;
    width: auto;
    max-width: none;
  }
  .col-lg-1 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
            flex: 0 0 8.33333%;
    max-width: 8.33333%;
  }
  .col-lg-2 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
            flex: 0 0 16.66667%;
    max-width: 16.66667%;
  }
  .col-lg-3 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%;
    max-width: 25%;
  }
  .col-lg-4 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
            flex: 0 0 33.33333%;
    max-width: 33.33333%;
  }
  .col-lg-5 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
            flex: 0 0 41.66667%;
    max-width: 41.66667%;
  }
  .col-lg-6 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%;
    max-width: 50%;
  }
  .col-lg-7 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
            flex: 0 0 58.33333%;
    max-width: 58.33333%;
  }
  .col-lg-8 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
            flex: 0 0 66.66667%;
    max-width: 66.66667%;
  }
  .col-lg-9 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%;
    max-width: 75%;
  }
  .col-lg-10 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
            flex: 0 0 83.33333%;
    max-width: 83.33333%;
  }
  .col-lg-11 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
            flex: 0 0 91.66667%;
    max-width: 91.66667%;
  }
  .col-lg-12 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%;
    max-width: 100%;
  }
  .order-lg-1 {
    -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
            order: 1;
  }
  .order-lg-2 {
    -webkit-box-ordinal-group: 3;
        -ms-flex-order: 2;
            order: 2;
  }
  .order-lg-3 {
    -webkit-box-ordinal-group: 4;
        -ms-flex-order: 3;
            order: 3;
  }
  .order-lg-4 {
    -webkit-box-ordinal-group: 5;
        -ms-flex-order: 4;
            order: 4;
  }
  .order-lg-5 {
    -webkit-box-ordinal-group: 6;
        -ms-flex-order: 5;
            order: 5;
  }
  .order-lg-6 {
    -webkit-box-ordinal-group: 7;
        -ms-flex-order: 6;
            order: 6;
  }
  .order-lg-7 {
    -webkit-box-ordinal-group: 8;
        -ms-flex-order: 7;
            order: 7;
  }
  .order-lg-8 {
    -webkit-box-ordinal-group: 9;
        -ms-flex-order: 8;
            order: 8;
  }
  .order-lg-9 {
    -webkit-box-ordinal-group: 10;
        -ms-flex-order: 9;
            order: 9;
  }
  .order-lg-10 {
    -webkit-box-ordinal-group: 11;
        -ms-flex-order: 10;
            order: 10;
  }
  .order-lg-11 {
    -webkit-box-ordinal-group: 12;
        -ms-flex-order: 11;
            order: 11;
  }
  .order-lg-12 {
    -webkit-box-ordinal-group: 13;
        -ms-flex-order: 12;
            order: 12;
  }
}

@media (min-width: 1200px) {
  .col-xl {
    -ms-flex-preferred-size: 0;
        flex-basis: 0;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    max-width: 100%;
  }
  .col-xl-auto {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 auto;
            flex: 0 0 auto;
    width: auto;
    max-width: none;
  }
  .col-xl-1 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
            flex: 0 0 8.33333%;
    max-width: 8.33333%;
  }
  .col-xl-2 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
            flex: 0 0 16.66667%;
    max-width: 16.66667%;
  }
  .col-xl-3 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%;
    max-width: 25%;
  }
  .col-xl-4 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
            flex: 0 0 33.33333%;
    max-width: 33.33333%;
  }
  .col-xl-5 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
            flex: 0 0 41.66667%;
    max-width: 41.66667%;
  }
  .col-xl-6 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%;
    max-width: 50%;
  }
  .col-xl-7 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
            flex: 0 0 58.33333%;
    max-width: 58.33333%;
  }
  .col-xl-8 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
            flex: 0 0 66.66667%;
    max-width: 66.66667%;
  }
  .col-xl-9 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%;
    max-width: 75%;
  }
  .col-xl-10 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
            flex: 0 0 83.33333%;
    max-width: 83.33333%;
  }
  .col-xl-11 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
            flex: 0 0 91.66667%;
    max-width: 91.66667%;
  }
  .col-xl-12 {
    -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%;
    max-width: 100%;
  }
  .order-xl-1 {
    -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
            order: 1;
  }
  .order-xl-2 {
    -webkit-box-ordinal-group: 3;
        -ms-flex-order: 2;
            order: 2;
  }
  .order-xl-3 {
    -webkit-box-ordinal-group: 4;
        -ms-flex-order: 3;
            order: 3;
  }
  .order-xl-4 {
    -webkit-box-ordinal-group: 5;
        -ms-flex-order: 4;
            order: 4;
  }
  .order-xl-5 {
    -webkit-box-ordinal-group: 6;
        -ms-flex-order: 5;
            order: 5;
  }
  .order-xl-6 {
    -webkit-box-ordinal-group: 7;
        -ms-flex-order: 6;
            order: 6;
  }
  .order-xl-7 {
    -webkit-box-ordinal-group: 8;
        -ms-flex-order: 7;
            order: 7;
  }
  .order-xl-8 {
    -webkit-box-ordinal-group: 9;
        -ms-flex-order: 8;
            order: 8;
  }
  .order-xl-9 {
    -webkit-box-ordinal-group: 10;
        -ms-flex-order: 9;
            order: 9;
  }
  .order-xl-10 {
    -webkit-box-ordinal-group: 11;
        -ms-flex-order: 10;
            order: 10;
  }
  .order-xl-11 {
    -webkit-box-ordinal-group: 12;
        -ms-flex-order: 11;
            order: 11;
  }
  .order-xl-12 {
    -webkit-box-ordinal-group: 13;
        -ms-flex-order: 12;
            order: 12;
  }
}

.table {
  width: 100%;
  max-width: 100%;
  margin-bottom: 0.25rem;
  background-color: transparent;
}

.table th,
.table td {
  padding: 0.2rem;
  vertical-align: top;
  border-top: 1px solid #ced5d8;
}

.table thead th {
  vertical-align: bottom;
  border-bottom: 2px solid #ced5d8;
}

.table tbody + tbody {
  border-top: 2px solid #ced5d8;
}

.table .table {
  background-color: white;
}

.table-sm th,
.table-sm td {
  padding: 0.1rem;
}

.table-bordered {
  border: 1px solid #ced5d8;
}

.table-bordered th,
.table-bordered td {
  border: 1px solid #ced5d8;
}

.table-bordered thead th,
.table-bordered thead td {
  border-bottom-width: 2px;
}

.table-striped tbody tr:nth-of-type(odd) {
  background-color: rgba(247, 247, 247, 0.5);
}

.table-hover tbody tr:hover {
  background-color: rgba(82, 187, 239, 0.2);
}

.table-primary,
.table-primary > th,
.table-primary > td {
  background-color: #c3e0f2;
}

.table-hover .table-primary:hover {
  background-color: #aed5ed;
}

.table-hover .table-primary:hover > td,
.table-hover .table-primary:hover > th {
  background-color: #aed5ed;
}

.table-secondary,
.table-secondary > th,
.table-secondary > td {
  background-color: #e6eaeb;
}

.table-hover .table-secondary:hover {
  background-color: #d8dee0;
}

.table-hover .table-secondary:hover > td,
.table-hover .table-secondary:hover > th {
  background-color: #d8dee0;
}

.table-success,
.table-success > th,
.table-success > td {
  background-color: #c4ece9;
}

.table-hover .table-success:hover {
  background-color: #b1e6e2;
}

.table-hover .table-success:hover > td,
.table-hover .table-success:hover > th {
  background-color: #b1e6e2;
}

.table-info,
.table-info > th,
.table-info > td {
  background-color: #bee5eb;
}

.table-hover .table-info:hover {
  background-color: #abdde5;
}

.table-hover .table-info:hover > td,
.table-hover .table-info:hover > th {
  background-color: #abdde5;
}

.table-warning,
.table-warning > th,
.table-warning > td {
  background-color: #fbf5bd;
}

.table-hover .table-warning:hover {
  background-color: #faf1a5;
}

.table-hover .table-warning:hover > td,
.table-hover .table-warning:hover > th {
  background-color: #faf1a5;
}

.table-danger,
.table-danger > th,
.table-danger > td {
  background-color: #f5d2d1;
}

.table-hover .table-danger:hover {
  background-color: #f0bebc;
}

.table-hover .table-danger:hover > td,
.table-hover .table-danger:hover > th {
  background-color: #f0bebc;
}

.table-light,
.table-light > th,
.table-light > td {
  background-color: #fdfdfd;
}

.table-hover .table-light:hover {
  background-color: #f0f0f0;
}

.table-hover .table-light:hover > td,
.table-hover .table-light:hover > th {
  background-color: #f0f0f0;
}

.table-dark,
.table-dark > th,
.table-dark > td {
  background-color: #ccced1;
}

.table-hover .table-dark:hover {
  background-color: #bfc1c5;
}

.table-hover .table-dark:hover > td,
.table-hover .table-dark:hover > th {
  background-color: #bfc1c5;
}

.table-active,
.table-active > th,
.table-active > td {
  background-color: rgba(82, 187, 239, 0.2);
}

.table-hover .table-active:hover {
  background-color: rgba(59, 178, 237, 0.2);
}

.table-hover .table-active:hover > td,
.table-hover .table-active:hover > th {
  background-color: rgba(59, 178, 237, 0.2);
}

.thead-inverse th {
  color: white;
  background-color: #4d4d4d;
}

.thead-default th {
  color: #565b68;
  background-color: #ebedee;
}

.table-inverse {
  color: white;
  background-color: #4d4d4d;
}

.table-inverse th,
.table-inverse td,
.table-inverse thead th {
  border-color: #606060;
}

.table-inverse.table-bordered {
  border: 0;
}

.table-inverse.table-striped tbody tr:nth-of-type(odd) {
  background-color: rgba(255, 255, 255, 0.05);
}

.table-inverse.table-hover tbody tr:hover {
  background-color: rgba(255, 255, 255, 0.075);
}

@media (max-width: 991px) {
  .table-responsive {
    display: block;
    width: 100%;
    overflow-x: auto;
    -ms-overflow-style: -ms-autohiding-scrollbar;
  }
  .table-responsive.table-bordered {
    border: 0;
  }
}

.form-control {
  display: block;
  width: 100%;
  padding: 0.45rem 0.6rem;
  font-size: 0.8125rem;
  line-height: 1.25;
  color: #565b68;
  background-color: white;
  background-image: none;
  background-clip: padding-box;
  border: 1px solid rgba(64, 64, 64, 0.15);
  border-radius: 0.25rem;
  -webkit-transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
}

.form-control::-ms-expand {
  background-color: transparent;
  border: 0;
}

.form-control:focus {
  color: #565b68;
  background-color: white;
  border-color: #92c7e9;
  outline: none;
}

.form-control::-webkit-input-placeholder {
  color: #656c7e;
  opacity: 1;
}

.form-control:-ms-input-placeholder {
  color: #656c7e;
  opacity: 1;
}

.form-control::-ms-input-placeholder {
  color: #656c7e;
  opacity: 1;
}

.form-control::placeholder {
  color: #656c7e;
  opacity: 1;
}

.form-control:disabled, .form-control[readonly] {
  background-color: #ebedee;
  opacity: 1;
}

select.form-control:not([size]):not([multiple]) {
  height: calc(1.91562rem + 2px);
}

select.form-control:focus::-ms-value {
  color: #565b68;
  background-color: white;
}

.form-control-file,
.form-control-range {
  display: block;
}

.col-form-label {
  padding-top: calc(0.45rem - 1px * 2);
  padding-bottom: calc(0.45rem - 1px * 2);
  margin-bottom: 0;
}

.col-form-label-lg {
  padding-top: calc(0.5rem - 1px * 2);
  padding-bottom: calc(0.5rem - 1px * 2);
  font-size: 1rem;
}

.col-form-label-sm {
  padding-top: calc(0.1rem - 1px * 2);
  padding-bottom: calc(0.1rem - 1px * 2);
  font-size: 0.6rem;
}

.col-form-legend {
  padding-top: 0.45rem;
  padding-bottom: 0.45rem;
  margin-bottom: 0;
  font-size: 0.8125rem;
}

.form-control-plaintext {
  padding-top: 0.45rem;
  padding-bottom: 0.45rem;
  margin-bottom: 0;
  line-height: 1.25;
  border: solid transparent;
  border-width: 1px 0;
}

.form-control-plaintext.form-control-sm, .input-group-sm > .form-control-plaintext.form-control,
.input-group-sm > .form-control-plaintext.input-group-addon,
.input-group-sm > .input-group-btn > .form-control-plaintext.btn, .form-control-plaintext.form-control-lg, .input-group-lg > .form-control-plaintext.form-control,
.input-group-lg > .form-control-plaintext.input-group-addon,
.input-group-lg > .input-group-btn > .form-control-plaintext.btn {
  padding-right: 0;
  padding-left: 0;
}

.form-control-sm, .input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
  padding: 0.1rem 0.1rem;
  font-size: 0.6rem;
  line-height: 1;
  border-radius: 0.2rem;
}

select.form-control-sm:not([size]):not([multiple]), .input-group-sm > select.form-control:not([size]):not([multiple]),
.input-group-sm > select.input-group-addon:not([size]):not([multiple]),
.input-group-sm > .input-group-btn > select.btn:not([size]):not([multiple]) {
  height: calc(0.8rem + 2px);
}

.form-control-lg, .input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
  padding: 0.5rem 1rem;
  font-size: 1rem;
  line-height: 1.5;
  border-radius: 0.3rem;
}

select.form-control-lg:not([size]):not([multiple]), .input-group-lg > select.form-control:not([size]):not([multiple]),
.input-group-lg > select.input-group-addon:not([size]):not([multiple]),
.input-group-lg > .input-group-btn > select.btn:not([size]):not([multiple]) {
  height: calc(2.5rem + 2px);
}

.form-group {
  margin-bottom: 1rem;
}

.form-text {
  display: block;
  margin-top: 0.25rem;
}

.form-row {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  margin-right: -5px;
  margin-left: -5px;
}

.form-row > .col,
.form-row > [class*="col-"] {
  padding-right: 5px;
  padding-left: 5px;
}

.form-check {
  position: relative;
  display: block;
  margin-bottom: 0.5rem;
}

.form-check.disabled .form-check-label {
  color: #656c7e;
}

.form-check-label {
  padding-left: 1.25rem;
  margin-bottom: 0;
}

.form-check-input {
  position: absolute;
  margin-top: 0.25rem;
  margin-left: -1.25rem;
}

.form-check-inline {
  display: inline-block;
}

.form-check-inline .form-check-label {
  vertical-align: middle;
}

.form-check-inline + .form-check-inline {
  margin-left: 0.75rem;
}

.invalid-feedback {
  display: none;
  margin-top: .25rem;
  font-size: .875rem;
  color: #dd5e5b;
}

.invalid-tooltip {
  position: absolute;
  top: 100%;
  z-index: 5;
  display: none;
  width: 250px;
  padding: .5rem;
  margin-top: .1rem;
  font-size: .875rem;
  line-height: 1;
  color: #fff;
  background-color: rgba(221, 94, 91, 0.8);
  border-radius: .2rem;
}

.was-validated .form-control:valid, .form-control.is-valid, .was-validated
.custom-select:valid,
.custom-select.is-valid {
  border-color: #2cbcb2;
}

.was-validated .form-control:valid:focus, .form-control.is-valid:focus, .was-validated
.custom-select:valid:focus,
.custom-select.is-valid:focus {
  -webkit-box-shadow: 0 0 0 0.2rem rgba(44, 188, 178, 0.25);
          box-shadow: 0 0 0 0.2rem rgba(44, 188, 178, 0.25);
}

.was-validated .form-control:valid ~ .invalid-feedback,
.was-validated .form-control:valid ~ .invalid-tooltip, .form-control.is-valid ~ .invalid-feedback,
.form-control.is-valid ~ .invalid-tooltip, .was-validated
.custom-select:valid ~ .invalid-feedback,
.was-validated
.custom-select:valid ~ .invalid-tooltip,
.custom-select.is-valid ~ .invalid-feedback,
.custom-select.is-valid ~ .invalid-tooltip {
  display: block;
}

.was-validated .form-check-input:valid + .form-check-label, .form-check-input.is-valid + .form-check-label {
  color: #2cbcb2;
}

.was-validated .custom-control-input:valid ~ .custom-control-indicator, .custom-control-input.is-valid ~ .custom-control-indicator {
  background-color: rgba(44, 188, 178, 0.25);
}

.was-validated .custom-control-input:valid ~ .custom-control-description, .custom-control-input.is-valid ~ .custom-control-description {
  color: #2cbcb2;
}

.was-validated .custom-file-input:valid ~ .custom-file-control, .custom-file-input.is-valid ~ .custom-file-control {
  border-color: #2cbcb2;
}

.was-validated .custom-file-input:valid ~ .custom-file-control::before, .custom-file-input.is-valid ~ .custom-file-control::before {
  border-color: inherit;
}

.was-validated .custom-file-input:valid:focus, .custom-file-input.is-valid:focus {
  -webkit-box-shadow: 0 0 0 0.2rem rgba(44, 188, 178, 0.25);
          box-shadow: 0 0 0 0.2rem rgba(44, 188, 178, 0.25);
}

.was-validated .form-control:invalid, .form-control.is-invalid, .was-validated
.custom-select:invalid,
.custom-select.is-invalid {
  border-color: #dd5e5b;
}

.was-validated .form-control:invalid:focus, .form-control.is-invalid:focus, .was-validated
.custom-select:invalid:focus,
.custom-select.is-invalid:focus {
  -webkit-box-shadow: 0 0 0 0.2rem rgba(221, 94, 91, 0.25);
          box-shadow: 0 0 0 0.2rem rgba(221, 94, 91, 0.25);
}

.was-validated .form-control:invalid ~ .invalid-feedback,
.was-validated .form-control:invalid ~ .invalid-tooltip, .form-control.is-invalid ~ .invalid-feedback,
.form-control.is-invalid ~ .invalid-tooltip, .was-validated
.custom-select:invalid ~ .invalid-feedback,
.was-validated
.custom-select:invalid ~ .invalid-tooltip,
.custom-select.is-invalid ~ .invalid-feedback,
.custom-select.is-invalid ~ .invalid-tooltip {
  display: block;
}

.was-validated .form-check-input:invalid + .form-check-label, .form-check-input.is-invalid + .form-check-label {
  color: #dd5e5b;
}

.was-validated .custom-control-input:invalid ~ .custom-control-indicator, .custom-control-input.is-invalid ~ .custom-control-indicator {
  background-color: rgba(221, 94, 91, 0.25);
}

.was-validated .custom-control-input:invalid ~ .custom-control-description, .custom-control-input.is-invalid ~ .custom-control-description {
  color: #dd5e5b;
}

.was-validated .custom-file-input:invalid ~ .custom-file-control, .custom-file-input.is-invalid ~ .custom-file-control {
  border-color: #dd5e5b;
}

.was-validated .custom-file-input:invalid ~ .custom-file-control::before, .custom-file-input.is-invalid ~ .custom-file-control::before {
  border-color: inherit;
}

.was-validated .custom-file-input:invalid:focus, .custom-file-input.is-invalid:focus {
  -webkit-box-shadow: 0 0 0 0.2rem rgba(221, 94, 91, 0.25);
          box-shadow: 0 0 0 0.2rem rgba(221, 94, 91, 0.25);
}

.form-inline {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-flow: row wrap;
          flex-flow: row wrap;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}

.form-inline .form-check {
  width: 100%;
}

@media (min-width: 576px) {
  .form-inline label {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    margin-bottom: 0;
  }
  .form-inline .form-group {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-flex: 0;
        -ms-flex: 0 0 auto;
            flex: 0 0 auto;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-flow: row wrap;
            flex-flow: row wrap;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    margin-bottom: 0;
  }
  .form-inline .form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle;
  }
  .form-inline .form-control-plaintext {
    display: inline-block;
  }
  .form-inline .input-group {
    width: auto;
  }
  .form-inline .form-control-label {
    margin-bottom: 0;
    vertical-align: middle;
  }
  .form-inline .form-check {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    width: auto;
    margin-top: 0;
    margin-bottom: 0;
  }
  .form-inline .form-check-label {
    padding-left: 0;
  }
  .form-inline .form-check-input {
    position: relative;
    margin-top: 0;
    margin-right: 0.25rem;
    margin-left: 0;
  }
  .form-inline .custom-control {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    padding-left: 0;
  }
  .form-inline .custom-control-indicator {
    position: static;
    display: inline-block;
    margin-right: 0.25rem;
    vertical-align: text-bottom;
  }
  .form-inline .has-feedback .form-control-feedback {
    top: 0;
  }
}

.btn {
  display: inline-block;
  font-weight: normal;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  border: 1px solid transparent;
  padding: 0.45rem 0.6rem;
  font-size: 0.8125rem;
  line-height: 1.25;
  border-radius: 0.25rem;
  -webkit-transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, -webkit-box-shadow 0.15s ease-in-out;
  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, -webkit-box-shadow 0.15s ease-in-out;
  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out, -webkit-box-shadow 0.15s ease-in-out;
}

.btn:focus, .btn:hover {
  text-decoration: none;
}

.btn:focus, .btn.focus {
  outline: 0;
  -webkit-box-shadow: 0 0 0 3px rgba(42, 145, 209, 0.25);
          box-shadow: 0 0 0 3px rgba(42, 145, 209, 0.25);
}

.btn.disabled, .btn:disabled {
  opacity: .65;
}

.btn:active, .btn.active {
  background-image: none;
}

a.btn.disabled,
fieldset[disabled] a.btn {
  pointer-events: none;
}

.btn-primary {
  color: #fff;
  background-color: #2a91d1;
  border-color: #2a91d1;
}

.btn-primary:hover {
  color: #fff;
  background-color: #247bb1;
  border-color: #2174a7;
}

.btn-primary:focus, .btn-primary.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(42, 145, 209, 0.5);
          box-shadow: 0 0 0 3px rgba(42, 145, 209, 0.5);
}

.btn-primary.disabled, .btn-primary:disabled {
  background-color: #2a91d1;
  border-color: #2a91d1;
}

.btn-primary:active, .btn-primary.active,
.show > .btn-primary.dropdown-toggle {
  background-color: #247bb1;
  background-image: none;
  border-color: #2174a7;
}

.btn-secondary {
  color: #111;
  background-color: #a7b3b7;
  border-color: #a7b3b7;
}

.btn-secondary:hover {
  color: #111;
  background-color: #92a1a6;
  border-color: #8b9ba0;
}

.btn-secondary:focus, .btn-secondary.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(167, 179, 183, 0.5);
          box-shadow: 0 0 0 3px rgba(167, 179, 183, 0.5);
}

.btn-secondary.disabled, .btn-secondary:disabled {
  background-color: #a7b3b7;
  border-color: #a7b3b7;
}

.btn-secondary:active, .btn-secondary.active,
.show > .btn-secondary.dropdown-toggle {
  background-color: #92a1a6;
  background-image: none;
  border-color: #8b9ba0;
}

.btn-success {
  color: #fff;
  background-color: #2cbcb2;
  border-color: #2cbcb2;
}

.btn-success:hover {
  color: #fff;
  background-color: #259d95;
  border-color: #22938b;
}

.btn-success:focus, .btn-success.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(44, 188, 178, 0.5);
          box-shadow: 0 0 0 3px rgba(44, 188, 178, 0.5);
}

.btn-success.disabled, .btn-success:disabled {
  background-color: #2cbcb2;
  border-color: #2cbcb2;
}

.btn-success:active, .btn-success.active,
.show > .btn-success.dropdown-toggle {
  background-color: #259d95;
  background-image: none;
  border-color: #22938b;
}

.btn-info {
  color: #fff;
  background-color: #17a2b8;
  border-color: #17a2b8;
}

.btn-info:hover {
  color: #fff;
  background-color: #138496;
  border-color: #117a8b;
}

.btn-info:focus, .btn-info.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(23, 162, 184, 0.5);
          box-shadow: 0 0 0 3px rgba(23, 162, 184, 0.5);
}

.btn-info.disabled, .btn-info:disabled {
  background-color: #17a2b8;
  border-color: #17a2b8;
}

.btn-info:active, .btn-info.active,
.show > .btn-info.dropdown-toggle {
  background-color: #138496;
  background-image: none;
  border-color: #117a8b;
}

.btn-warning {
  color: #111;
  background-color: #f0dc14;
  border-color: #f0dc14;
}

.btn-warning:hover {
  color: #111;
  background-color: #d0bf0d;
  border-color: #c4b40d;
}

.btn-warning:focus, .btn-warning.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(240, 220, 20, 0.5);
          box-shadow: 0 0 0 3px rgba(240, 220, 20, 0.5);
}

.btn-warning.disabled, .btn-warning:disabled {
  background-color: #f0dc14;
  border-color: #f0dc14;
}

.btn-warning:active, .btn-warning.active,
.show > .btn-warning.dropdown-toggle {
  background-color: #d0bf0d;
  background-image: none;
  border-color: #c4b40d;
}

.btn-danger {
  color: #fff;
  background-color: #dd5e5b;
  border-color: #dd5e5b;
}

.btn-danger:hover {
  color: #fff;
  background-color: #d63f3b;
  border-color: #d43531;
}

.btn-danger:focus, .btn-danger.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(221, 94, 91, 0.5);
          box-shadow: 0 0 0 3px rgba(221, 94, 91, 0.5);
}

.btn-danger.disabled, .btn-danger:disabled {
  background-color: #dd5e5b;
  border-color: #dd5e5b;
}

.btn-danger:active, .btn-danger.active,
.show > .btn-danger.dropdown-toggle {
  background-color: #d63f3b;
  background-image: none;
  border-color: #d43531;
}

.btn-light {
  color: #111;
  background-color: #f7f7f7;
  border-color: #f7f7f7;
}

.btn-light:hover {
  color: #111;
  background-color: #e4e4e4;
  border-color: #dedede;
}

.btn-light:focus, .btn-light.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(247, 247, 247, 0.5);
          box-shadow: 0 0 0 3px rgba(247, 247, 247, 0.5);
}

.btn-light.disabled, .btn-light:disabled {
  background-color: #f7f7f7;
  border-color: #f7f7f7;
}

.btn-light:active, .btn-light.active,
.show > .btn-light.dropdown-toggle {
  background-color: #e4e4e4;
  background-image: none;
  border-color: #dedede;
}

.btn-dark {
  color: #fff;
  background-color: #4a4f5a;
  border-color: #4a4f5a;
}

.btn-dark:hover {
  color: #fff;
  background-color: #393c45;
  border-color: #33363e;
}

.btn-dark:focus, .btn-dark.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(74, 79, 90, 0.5);
          box-shadow: 0 0 0 3px rgba(74, 79, 90, 0.5);
}

.btn-dark.disabled, .btn-dark:disabled {
  background-color: #4a4f5a;
  border-color: #4a4f5a;
}

.btn-dark:active, .btn-dark.active,
.show > .btn-dark.dropdown-toggle {
  background-color: #393c45;
  background-image: none;
  border-color: #33363e;
}

.btn-outline-primary {
  color: #2a91d1;
  background-color: transparent;
  background-image: none;
  border-color: #2a91d1;
}

.btn-outline-primary:hover {
  color: #fff;
  background-color: #2a91d1;
  border-color: #2a91d1;
}

.btn-outline-primary:focus, .btn-outline-primary.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(42, 145, 209, 0.5);
          box-shadow: 0 0 0 3px rgba(42, 145, 209, 0.5);
}

.btn-outline-primary.disabled, .btn-outline-primary:disabled {
  color: #2a91d1;
  background-color: transparent;
}

.btn-outline-primary:active, .btn-outline-primary.active,
.show > .btn-outline-primary.dropdown-toggle {
  color: #fff;
  background-color: #2a91d1;
  border-color: #2a91d1;
}

.btn-outline-secondary {
  color: #a7b3b7;
  background-color: transparent;
  background-image: none;
  border-color: #a7b3b7;
}

.btn-outline-secondary:hover {
  color: #fff;
  background-color: #a7b3b7;
  border-color: #a7b3b7;
}

.btn-outline-secondary:focus, .btn-outline-secondary.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(167, 179, 183, 0.5);
          box-shadow: 0 0 0 3px rgba(167, 179, 183, 0.5);
}

.btn-outline-secondary.disabled, .btn-outline-secondary:disabled {
  color: #a7b3b7;
  background-color: transparent;
}

.btn-outline-secondary:active, .btn-outline-secondary.active,
.show > .btn-outline-secondary.dropdown-toggle {
  color: #fff;
  background-color: #a7b3b7;
  border-color: #a7b3b7;
}

.btn-outline-success {
  color: #2cbcb2;
  background-color: transparent;
  background-image: none;
  border-color: #2cbcb2;
}

.btn-outline-success:hover {
  color: #fff;
  background-color: #2cbcb2;
  border-color: #2cbcb2;
}

.btn-outline-success:focus, .btn-outline-success.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(44, 188, 178, 0.5);
          box-shadow: 0 0 0 3px rgba(44, 188, 178, 0.5);
}

.btn-outline-success.disabled, .btn-outline-success:disabled {
  color: #2cbcb2;
  background-color: transparent;
}

.btn-outline-success:active, .btn-outline-success.active,
.show > .btn-outline-success.dropdown-toggle {
  color: #fff;
  background-color: #2cbcb2;
  border-color: #2cbcb2;
}

.btn-outline-info {
  color: #17a2b8;
  background-color: transparent;
  background-image: none;
  border-color: #17a2b8;
}

.btn-outline-info:hover {
  color: #fff;
  background-color: #17a2b8;
  border-color: #17a2b8;
}

.btn-outline-info:focus, .btn-outline-info.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(23, 162, 184, 0.5);
          box-shadow: 0 0 0 3px rgba(23, 162, 184, 0.5);
}

.btn-outline-info.disabled, .btn-outline-info:disabled {
  color: #17a2b8;
  background-color: transparent;
}

.btn-outline-info:active, .btn-outline-info.active,
.show > .btn-outline-info.dropdown-toggle {
  color: #fff;
  background-color: #17a2b8;
  border-color: #17a2b8;
}

.btn-outline-warning {
  color: #f0dc14;
  background-color: transparent;
  background-image: none;
  border-color: #f0dc14;
}

.btn-outline-warning:hover {
  color: #fff;
  background-color: #f0dc14;
  border-color: #f0dc14;
}

.btn-outline-warning:focus, .btn-outline-warning.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(240, 220, 20, 0.5);
          box-shadow: 0 0 0 3px rgba(240, 220, 20, 0.5);
}

.btn-outline-warning.disabled, .btn-outline-warning:disabled {
  color: #f0dc14;
  background-color: transparent;
}

.btn-outline-warning:active, .btn-outline-warning.active,
.show > .btn-outline-warning.dropdown-toggle {
  color: #fff;
  background-color: #f0dc14;
  border-color: #f0dc14;
}

.btn-outline-danger {
  color: #dd5e5b;
  background-color: transparent;
  background-image: none;
  border-color: #dd5e5b;
}

.btn-outline-danger:hover {
  color: #fff;
  background-color: #dd5e5b;
  border-color: #dd5e5b;
}

.btn-outline-danger:focus, .btn-outline-danger.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(221, 94, 91, 0.5);
          box-shadow: 0 0 0 3px rgba(221, 94, 91, 0.5);
}

.btn-outline-danger.disabled, .btn-outline-danger:disabled {
  color: #dd5e5b;
  background-color: transparent;
}

.btn-outline-danger:active, .btn-outline-danger.active,
.show > .btn-outline-danger.dropdown-toggle {
  color: #fff;
  background-color: #dd5e5b;
  border-color: #dd5e5b;
}

.btn-outline-light {
  color: #f7f7f7;
  background-color: transparent;
  background-image: none;
  border-color: #f7f7f7;
}

.btn-outline-light:hover {
  color: #fff;
  background-color: #f7f7f7;
  border-color: #f7f7f7;
}

.btn-outline-light:focus, .btn-outline-light.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(247, 247, 247, 0.5);
          box-shadow: 0 0 0 3px rgba(247, 247, 247, 0.5);
}

.btn-outline-light.disabled, .btn-outline-light:disabled {
  color: #f7f7f7;
  background-color: transparent;
}

.btn-outline-light:active, .btn-outline-light.active,
.show > .btn-outline-light.dropdown-toggle {
  color: #fff;
  background-color: #f7f7f7;
  border-color: #f7f7f7;
}

.btn-outline-dark {
  color: #4a4f5a;
  background-color: transparent;
  background-image: none;
  border-color: #4a4f5a;
}

.btn-outline-dark:hover {
  color: #fff;
  background-color: #4a4f5a;
  border-color: #4a4f5a;
}

.btn-outline-dark:focus, .btn-outline-dark.focus {
  -webkit-box-shadow: 0 0 0 3px rgba(74, 79, 90, 0.5);
          box-shadow: 0 0 0 3px rgba(74, 79, 90, 0.5);
}

.btn-outline-dark.disabled, .btn-outline-dark:disabled {
  color: #4a4f5a;
  background-color: transparent;
}

.btn-outline-dark:active, .btn-outline-dark.active,
.show > .btn-outline-dark.dropdown-toggle {
  color: #fff;
  background-color: #4a4f5a;
  border-color: #4a4f5a;
}

.btn-link {
  font-weight: normal;
  color: #004c93;
  border-radius: 0;
}

.btn-link, .btn-link:active, .btn-link.active, .btn-link:disabled {
  background-color: transparent;
}

.btn-link, .btn-link:focus, .btn-link:active {
  border-color: transparent;
  -webkit-box-shadow: none;
          box-shadow: none;
}

.btn-link:hover {
  border-color: transparent;
}

.btn-link:focus, .btn-link:hover {
  color: #2a91d1;
  text-decoration: underline;
  background-color: transparent;
}

.btn-link:disabled {
  color: #656c7e;
}

.btn-link:disabled:focus, .btn-link:disabled:hover {
  text-decoration: none;
}

.btn-lg, .btn-group-lg > .btn {
  padding: 0.5rem 1rem;
  font-size: 1rem;
  line-height: 1.5;
  border-radius: 0.3rem;
}

.btn-sm, .btn-group-sm > .btn {
  padding: 0.1rem 0.1rem;
  font-size: 0.6rem;
  line-height: 1.2;
  border-radius: 0.2rem;
}

.btn-block {
  display: block;
  width: 100%;
}

.btn-block + .btn-block {
  margin-top: 0.5rem;
}

input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
}

.fade {
  opacity: 0;
  -webkit-transition: opacity 0.15s linear;
  transition: opacity 0.15s linear;
}

.fade.show {
  opacity: 1;
}

.collapse {
  display: none;
}

.collapse.show {
  display: block;
}

tr.collapse.show {
  display: table-row;
}

tbody.collapse.show {
  display: table-row-group;
}

.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition: height 0.35s ease;
  transition: height 0.35s ease;
}

.dropup,
.dropdown {
  position: relative;
}

.dropdown-toggle::after {
  display: inline-block;
  width: 0;
  height: 0;
  margin-left: 0.255em;
  vertical-align: 0.255em;
  content: "";
  border-top: 0.3em solid;
  border-right: 0.3em solid transparent;
  border-left: 0.3em solid transparent;
}

.dropdown-toggle:empty::after {
  margin-left: 0;
}

.dropup .dropdown-menu {
  margin-top: 0;
  margin-bottom: 0.125rem;
}

.dropup .dropdown-toggle::after {
  border-top: 0;
  border-bottom: 0.3em solid;
}

.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 10rem;
  padding: 0.5rem 0;
  margin: 0.125rem 0 0;
  font-size: 0.8125rem;
  color: #404040;
  text-align: left;
  list-style: none;
  background-color: white;
  background-clip: padding-box;
  border: 1px solid rgba(64, 64, 64, 0.15);
  border-radius: 0.25rem;
}

.dropdown-divider {
  height: 0;
  margin: 0.125rem 0;
  overflow: hidden;
  border-top: 1px solid #ebedee;
}

.dropdown-item {
  display: block;
  width: 100%;
  padding: 0.25rem 1.5rem;
  clear: both;
  font-weight: normal;
  color: #4d4d4d;
  text-align: inherit;
  white-space: nowrap;
  background: none;
  border: 0;
}

.dropdown-item:focus, .dropdown-item:hover {
  color: #404040;
  text-decoration: none;
  background-color: #f7f7f7;
}

.dropdown-item.active, .dropdown-item:active {
  color: white;
  text-decoration: none;
  background-color: #2a91d1;
}

.dropdown-item.disabled, .dropdown-item:disabled {
  color: #656c7e;
  background-color: transparent;
}

.show > a {
  outline: 0;
}

.dropdown-menu.show {
  display: block;
}

.dropdown-header {
  display: block;
  padding: 0.5rem 1.5rem;
  margin-bottom: 0;
  font-size: 0.6rem;
  color: #656c7e;
  white-space: nowrap;
}

.btn-group,
.btn-group-vertical {
  position: relative;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  vertical-align: middle;
}

.btn-group > .btn,
.btn-group-vertical > .btn {
  position: relative;
  -webkit-box-flex: 0;
      -ms-flex: 0 1 auto;
          flex: 0 1 auto;
  margin-bottom: 0;
}

.btn-group > .btn:hover,
.btn-group-vertical > .btn:hover {
  z-index: 2;
}

.btn-group > .btn:focus, .btn-group > .btn:active, .btn-group > .btn.active,
.btn-group-vertical > .btn:focus,
.btn-group-vertical > .btn:active,
.btn-group-vertical > .btn.active {
  z-index: 2;
}

.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group,
.btn-group-vertical .btn + .btn,
.btn-group-vertical .btn + .btn-group,
.btn-group-vertical .btn-group + .btn,
.btn-group-vertical .btn-group + .btn-group {
  margin-left: -1px;
}

.btn-toolbar {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
}

.btn-toolbar .input-group {
  width: auto;
}

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
}

.btn-group > .btn:first-child {
  margin-left: 0;
}

.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.btn-group > .btn-group {
  float: left;
}

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.btn + .dropdown-toggle-split {
  padding-right: 0.45rem;
  padding-left: 0.45rem;
}

.btn + .dropdown-toggle-split::after {
  margin-left: 0;
}

.btn-sm + .dropdown-toggle-split, .btn-group-sm > .btn + .dropdown-toggle-split {
  padding-right: 0.075rem;
  padding-left: 0.075rem;
}

.btn-lg + .dropdown-toggle-split, .btn-group-lg > .btn + .dropdown-toggle-split {
  padding-right: 0.75rem;
  padding-left: 0.75rem;
}

.btn-group-vertical {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  -webkit-box-align: start;
      -ms-flex-align: start;
          align-items: flex-start;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
}

.btn-group-vertical .btn,
.btn-group-vertical .btn-group {
  width: 100%;
}

.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0;
}

.btn-group-vertical > .btn:first-child:not(:last-child) {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.btn-group-vertical > .btn:last-child:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}

.input-group {
  position: relative;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
}

.input-group .form-control {
  position: relative;
  z-index: 2;
  -webkit-box-flex: 1;
      -ms-flex: 1 1 auto;
          flex: 1 1 auto;
  width: 1%;
  margin-bottom: 0;
}

.input-group .form-control:focus, .input-group .form-control:active, .input-group .form-control:hover {
  z-index: 3;
}

.input-group-addon,
.input-group-btn,
.input-group .form-control {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}

.input-group-addon:not(:first-child):not(:last-child),
.input-group-btn:not(:first-child):not(:last-child),
.input-group .form-control:not(:first-child):not(:last-child) {
  border-radius: 0;
}

.input-group-addon,
.input-group-btn {
  white-space: nowrap;
  vertical-align: middle;
}

.input-group-addon {
  padding: 0.45rem 0.6rem;
  margin-bottom: 0;
  font-size: 0.8125rem;
  font-weight: normal;
  line-height: 1.25;
  color: #565b68;
  text-align: center;
  background-color: #ebedee;
  background-clip: padding-box;
  border: 1px solid rgba(64, 64, 64, 0.15);
  border-radius: 0.25rem;
}

.input-group-addon.form-control-sm,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .input-group-addon.btn {
  padding: 0.1rem 0.1rem;
  font-size: 0.6rem;
  border-radius: 0.2rem;
}

.input-group-addon.form-control-lg,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .input-group-addon.btn {
  padding: 0.5rem 1rem;
  font-size: 1rem;
  border-radius: 0.3rem;
}

.input-group-addon input[type="radio"],
.input-group-addon input[type="checkbox"] {
  margin-top: 0;
}

.input-group .form-control:not(:last-child),
.input-group-addon:not(:last-child),
.input-group-btn:not(:last-child) > .btn,
.input-group-btn:not(:last-child) > .btn-group > .btn,
.input-group-btn:not(:last-child) > .dropdown-toggle,
.input-group-btn:not(:first-child) > .btn:not(:last-child):not(.dropdown-toggle),
.input-group-btn:not(:first-child) > .btn-group:not(:last-child) > .btn {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.input-group-addon:not(:last-child) {
  border-right: 0;
}

.input-group .form-control:not(:first-child),
.input-group-addon:not(:first-child),
.input-group-btn:not(:first-child) > .btn,
.input-group-btn:not(:first-child) > .btn-group > .btn,
.input-group-btn:not(:first-child) > .dropdown-toggle,
.input-group-btn:not(:last-child) > .btn:not(:first-child),
.input-group-btn:not(:last-child) > .btn-group:not(:first-child) > .btn {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.form-control + .input-group-addon:not(:first-child) {
  border-left: 0;
}

.input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap;
}

.input-group-btn > .btn {
  position: relative;
  background-clip: padding-box;
  border: 1px solid rgba(64, 64, 64, 0.15);
}

.input-group-btn > .btn + .btn {
  margin-left: -1px;
}

.input-group-btn > .btn:focus, .input-group-btn > .btn:active, .input-group-btn > .btn:hover {
  z-index: 3;
}

.input-group-btn:not(:last-child) > .btn,
.input-group-btn:not(:last-child) > .btn-group {
  margin-right: -1px;
}

.input-group-btn:not(:first-child) > .btn,
.input-group-btn:not(:first-child) > .btn-group {
  z-index: 2;
  margin-left: -1px;
}

.input-group-btn:not(:first-child) > .btn:focus, .input-group-btn:not(:first-child) > .btn:active, .input-group-btn:not(:first-child) > .btn:hover,
.input-group-btn:not(:first-child) > .btn-group:focus,
.input-group-btn:not(:first-child) > .btn-group:active,
.input-group-btn:not(:first-child) > .btn-group:hover {
  z-index: 3;
}

.custom-control {
  position: relative;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  min-height: 1.5rem;
  padding-left: 1.5rem;
  margin-right: 1rem;
}

.custom-control-input {
  position: absolute;
  z-index: -1;
  opacity: 0;
}

.custom-control-input:checked ~ .custom-control-indicator {
  color: white;
  background-color: #2a91d1;
}

.custom-control-input:focus ~ .custom-control-indicator {
  -webkit-box-shadow: 0 0 0 1px white, 0 0 0 3px #2a91d1;
          box-shadow: 0 0 0 1px white, 0 0 0 3px #2a91d1;
}

.custom-control-input:active ~ .custom-control-indicator {
  color: white;
  background-color: #bcddf2;
}

.custom-control-input:disabled ~ .custom-control-indicator {
  background-color: #ebedee;
}

.custom-control-input:disabled ~ .custom-control-description {
  color: #656c7e;
}

.custom-control-indicator {
  position: absolute;
  top: 0.25rem;
  left: 0;
  display: block;
  width: 1rem;
  height: 1rem;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  background-color: #ddd;
  background-repeat: no-repeat;
  background-position: center center;
  background-size: 50% 50%;
}

.custom-checkbox .custom-control-indicator {
  border-radius: 0.25rem;
}

.custom-checkbox .custom-control-input:checked ~ .custom-control-indicator {
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='white' d='M6.564.75l-3.59 3.612-1.538-1.55L0 4.26 2.974 7.25 8 2.193z'/%3E%3C/svg%3E");
}

.custom-checkbox .custom-control-input:indeterminate ~ .custom-control-indicator {
  background-color: #2a91d1;
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 4'%3E%3Cpath stroke='white' d='M0 2h4'/%3E%3C/svg%3E");
}

.custom-radio .custom-control-indicator {
  border-radius: 50%;
}

.custom-radio .custom-control-input:checked ~ .custom-control-indicator {
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3E%3Ccircle r='3' fill='white'/%3E%3C/svg%3E");
}

.custom-controls-stacked {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
}

.custom-controls-stacked .custom-control {
  margin-bottom: 0.25rem;
}

.custom-controls-stacked .custom-control + .custom-control {
  margin-left: 0;
}

.custom-select {
  display: inline-block;
  max-width: 100%;
  height: calc(1.91562rem + 2px);
  padding: 0.375rem 1.75rem 0.375rem 0.75rem;
  line-height: 1.25;
  color: #565b68;
  vertical-align: middle;
  background: white url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 5'%3E%3Cpath fill='%23333' d='M2 0L0 2h4zm0 5L0 3h4z'/%3E%3C/svg%3E") no-repeat right 0.75rem center;
  background-clip: padding-box;
  background-size: 8px 10px;
  border: 1px solid rgba(64, 64, 64, 0.15);
  border-radius: 0.25rem;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
}

.custom-select:focus {
  border-color: #92c7e9;
  outline: none;
}

.custom-select:focus::-ms-value {
  color: #565b68;
  background-color: white;
}

.custom-select:disabled {
  color: #656c7e;
  background-color: #ebedee;
}

.custom-select::-ms-expand {
  opacity: 0;
}

.custom-select-sm {
  height: calc(0.8rem + 2px);
  padding-top: 0.375rem;
  padding-bottom: 0.375rem;
  font-size: 75%;
}

.custom-file {
  position: relative;
  display: inline-block;
  max-width: 100%;
  height: calc(1.91562rem + 2px);
  margin-bottom: 0;
}

.custom-file-input {
  min-width: 14rem;
  max-width: 100%;
  height: calc(1.91562rem + 2px);
  margin: 0;
  opacity: 0;
}

.custom-file-input:focus ~ .custom-file-control {
  -webkit-box-shadow: 0 0 0 0.075rem white, 0 0 0 0.2rem #2a91d1;
          box-shadow: 0 0 0 0.075rem white, 0 0 0 0.2rem #2a91d1;
}

.custom-file-control {
  position: absolute;
  top: 0;
  right: 0;
  left: 0;
  z-index: 5;
  height: calc(1.91562rem + 2px);
  padding: 0.45rem 0.6rem;
  overflow: hidden;
  line-height: 1.25;
  color: #565b68;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  background-color: white;
  background-clip: padding-box;
  border: 1px solid rgba(64, 64, 64, 0.15);
  border-radius: 0.25rem;
}

.custom-file-control:lang(en):empty::after {
  content: "Choose file...";
}

.custom-file-control::before {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 6;
  display: block;
  height: calc(1.91562rem + 2px);
  padding: 0.45rem 0.6rem;
  line-height: 1.25;
  color: #565b68;
  background-color: #ebedee;
  border-left: 1px solid rgba(64, 64, 64, 0.15);
}

.custom-file-control:lang(en)::before {
  content: "Browse";
}

.nav {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  padding-left: 0;
  margin-bottom: 0;
  list-style: none;
}

.nav-link {
  display: block;
  padding: 0.5rem 1rem;
}

.nav-link:focus, .nav-link:hover {
  text-decoration: none;
}

.nav-link.disabled {
  color: #656c7e;
}

.nav-tabs {
  border-bottom: 1px solid #ddd;
}

.nav-tabs .nav-item {
  margin-bottom: -1px;
}

.nav-tabs .nav-link {
  border: 1px solid transparent;
  border-top-left-radius: 0.25rem;
  border-top-right-radius: 0.25rem;
}

.nav-tabs .nav-link:focus, .nav-tabs .nav-link:hover {
  border-color: #ebedee #ebedee #ddd;
}

.nav-tabs .nav-link.disabled {
  color: #656c7e;
  background-color: transparent;
  border-color: transparent;
}

.nav-tabs .nav-link.active,
.nav-tabs .nav-item.show .nav-link {
  color: #565b68;
  background-color: white;
  border-color: #ddd #ddd white;
}

.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.nav-pills .nav-link {
  border-radius: 0.25rem;
}

.nav-pills .nav-link.active,
.show > .nav-pills .nav-link {
  color: white;
  background-color: #2a91d1;
}

.nav-fill .nav-item {
  -webkit-box-flex: 1;
      -ms-flex: 1 1 auto;
          flex: 1 1 auto;
  text-align: center;
}

.nav-justified .nav-item {
  -ms-flex-preferred-size: 0;
      flex-basis: 0;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  text-align: center;
}

.tab-content > .tab-pane {
  display: none;
}

.tab-content > .active {
  display: block;
}

.navbar {
  position: relative;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  padding: 0.125rem 0.25rem;
}

.navbar > .container,
.navbar > .container-fluid {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
}

.navbar-brand {
  display: inline-block;
  padding-top: 0.35938rem;
  padding-bottom: 0.35938rem;
  margin-right: 0.25rem;
  font-size: 1rem;
  line-height: inherit;
  white-space: nowrap;
}

.navbar-brand:focus, .navbar-brand:hover {
  text-decoration: none;
}

.navbar-nav {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  padding-left: 0;
  margin-bottom: 0;
  list-style: none;
}

.navbar-nav .nav-link {
  padding-right: 0;
  padding-left: 0;
}

.navbar-nav .dropdown-menu {
  position: static;
  float: none;
}

.navbar-text {
  display: inline-block;
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
}

.navbar-collapse {
  -ms-flex-preferred-size: 100%;
      flex-basis: 100%;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}

.navbar-toggler {
  padding: 0.25rem 0.75rem;
  font-size: 1rem;
  line-height: 1;
  background: transparent;
  border: 1px solid transparent;
  border-radius: 0.25rem;
}

.navbar-toggler:focus, .navbar-toggler:hover {
  text-decoration: none;
}

.navbar-toggler-icon {
  display: inline-block;
  width: 1.5em;
  height: 1.5em;
  vertical-align: middle;
  content: "";
  background: no-repeat center center;
  background-size: 100% 100%;
}

@media (max-width: 575px) {
  .navbar-expand-sm > .container,
  .navbar-expand-sm > .container-fluid {
    padding-right: 0;
    padding-left: 0;
  }
}

@media (min-width: 576px) {
  .navbar-expand-sm {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
    -webkit-box-pack: start;
        -ms-flex-pack: start;
            justify-content: flex-start;
  }
  .navbar-expand-sm .navbar-nav {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
  }
  .navbar-expand-sm .navbar-nav .dropdown-menu {
    position: absolute;
  }
  .navbar-expand-sm .navbar-nav .dropdown-menu-right {
    right: 0;
    left: auto;
  }
  .navbar-expand-sm .navbar-nav .nav-link {
    padding-right: .5rem;
    padding-left: .5rem;
  }
  .navbar-expand-sm > .container,
  .navbar-expand-sm > .container-fluid {
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
  }
  .navbar-expand-sm .navbar-collapse {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .navbar-expand-sm .navbar-toggler {
    display: none;
  }
}

@media (max-width: 767px) {
  .navbar-expand-md > .container,
  .navbar-expand-md > .container-fluid {
    padding-right: 0;
    padding-left: 0;
  }
}

@media (min-width: 768px) {
  .navbar-expand-md {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
    -webkit-box-pack: start;
        -ms-flex-pack: start;
            justify-content: flex-start;
  }
  .navbar-expand-md .navbar-nav {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
  }
  .navbar-expand-md .navbar-nav .dropdown-menu {
    position: absolute;
  }
  .navbar-expand-md .navbar-nav .dropdown-menu-right {
    right: 0;
    left: auto;
  }
  .navbar-expand-md .navbar-nav .nav-link {
    padding-right: .5rem;
    padding-left: .5rem;
  }
  .navbar-expand-md > .container,
  .navbar-expand-md > .container-fluid {
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
  }
  .navbar-expand-md .navbar-collapse {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .navbar-expand-md .navbar-toggler {
    display: none;
  }
}

@media (max-width: 991px) {
  .navbar-expand-lg > .container,
  .navbar-expand-lg > .container-fluid {
    padding-right: 0;
    padding-left: 0;
  }
}

@media (min-width: 992px) {
  .navbar-expand-lg {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
    -webkit-box-pack: start;
        -ms-flex-pack: start;
            justify-content: flex-start;
  }
  .navbar-expand-lg .navbar-nav {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
  }
  .navbar-expand-lg .navbar-nav .dropdown-menu {
    position: absolute;
  }
  .navbar-expand-lg .navbar-nav .dropdown-menu-right {
    right: 0;
    left: auto;
  }
  .navbar-expand-lg .navbar-nav .nav-link {
    padding-right: .5rem;
    padding-left: .5rem;
  }
  .navbar-expand-lg > .container,
  .navbar-expand-lg > .container-fluid {
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
  }
  .navbar-expand-lg .navbar-collapse {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .navbar-expand-lg .navbar-toggler {
    display: none;
  }
}

@media (max-width: 1199px) {
  .navbar-expand-xl > .container,
  .navbar-expand-xl > .container-fluid {
    padding-right: 0;
    padding-left: 0;
  }
}

@media (min-width: 1200px) {
  .navbar-expand-xl {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
    -webkit-box-pack: start;
        -ms-flex-pack: start;
            justify-content: flex-start;
  }
  .navbar-expand-xl .navbar-nav {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row;
  }
  .navbar-expand-xl .navbar-nav .dropdown-menu {
    position: absolute;
  }
  .navbar-expand-xl .navbar-nav .dropdown-menu-right {
    right: 0;
    left: auto;
  }
  .navbar-expand-xl .navbar-nav .nav-link {
    padding-right: .5rem;
    padding-left: .5rem;
  }
  .navbar-expand-xl > .container,
  .navbar-expand-xl > .container-fluid {
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap;
  }
  .navbar-expand-xl .navbar-collapse {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .navbar-expand-xl .navbar-toggler {
    display: none;
  }
}

.navbar-expand {
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -ms-flex-wrap: nowrap;
      flex-wrap: nowrap;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
}

.navbar-expand > .container,
.navbar-expand > .container-fluid {
  padding-right: 0;
  padding-left: 0;
}

.navbar-expand .navbar-nav {
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
}

.navbar-expand .navbar-nav .dropdown-menu {
  position: absolute;
}

.navbar-expand .navbar-nav .dropdown-menu-right {
  right: 0;
  left: auto;
}

.navbar-expand .navbar-nav .nav-link {
  padding-right: .5rem;
  padding-left: .5rem;
}

.navbar-expand > .container,
.navbar-expand > .container-fluid {
  -ms-flex-wrap: nowrap;
      flex-wrap: nowrap;
}

.navbar-expand .navbar-collapse {
  display: -webkit-box !important;
  display: -ms-flexbox !important;
  display: flex !important;
}

.navbar-expand .navbar-toggler {
  display: none;
}

.navbar-light .navbar-brand {
  color: rgba(64, 64, 64, 0.9);
}

.navbar-light .navbar-brand:focus, .navbar-light .navbar-brand:hover {
  color: rgba(64, 64, 64, 0.9);
}

.navbar-light .navbar-nav .nav-link {
  color: rgba(64, 64, 64, 0.5);
}

.navbar-light .navbar-nav .nav-link:focus, .navbar-light .navbar-nav .nav-link:hover {
  color: rgba(64, 64, 64, 0.7);
}

.navbar-light .navbar-nav .nav-link.disabled {
  color: rgba(64, 64, 64, 0.3);
}

.navbar-light .navbar-nav .show > .nav-link,
.navbar-light .navbar-nav .active > .nav-link,
.navbar-light .navbar-nav .nav-link.show,
.navbar-light .navbar-nav .nav-link.active {
  color: rgba(64, 64, 64, 0.9);
}

.navbar-light .navbar-toggler {
  color: rgba(64, 64, 64, 0.5);
  border-color: rgba(64, 64, 64, 0.1);
}

.navbar-light .navbar-toggler-icon {
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(64, 64, 64, 0.5)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
}

.navbar-light .navbar-text {
  color: rgba(64, 64, 64, 0.5);
}

.navbar-dark .navbar-brand {
  color: white;
}

.navbar-dark .navbar-brand:focus, .navbar-dark .navbar-brand:hover {
  color: white;
}

.navbar-dark .navbar-nav .nav-link {
  color: rgba(255, 255, 255, 0.5);
}

.navbar-dark .navbar-nav .nav-link:focus, .navbar-dark .navbar-nav .nav-link:hover {
  color: rgba(255, 255, 255, 0.75);
}

.navbar-dark .navbar-nav .nav-link.disabled {
  color: rgba(255, 255, 255, 0.25);
}

.navbar-dark .navbar-nav .show > .nav-link,
.navbar-dark .navbar-nav .active > .nav-link,
.navbar-dark .navbar-nav .nav-link.show,
.navbar-dark .navbar-nav .nav-link.active {
  color: white;
}

.navbar-dark .navbar-toggler {
  color: rgba(255, 255, 255, 0.5);
  border-color: rgba(255, 255, 255, 0.1);
}

.navbar-dark .navbar-toggler-icon {
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(255, 255, 255, 0.5)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
}

.navbar-dark .navbar-text {
  color: rgba(255, 255, 255, 0.5);
}

.pagination {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  padding-left: 0;
  list-style: none;
  border-radius: 0.25rem;
}

.page-item:first-child .page-link {
  margin-left: 0;
  border-top-left-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem;
}

.page-item:last-child .page-link {
  border-top-right-radius: 0.25rem;
  border-bottom-right-radius: 0.25rem;
}

.page-item.active .page-link {
  z-index: 2;
  color: white;
  background-color: #2a91d1;
  border-color: #2a91d1;
}

.page-item.disabled .page-link {
  color: #656c7e;
  pointer-events: none;
  background-color: white;
  border-color: #ddd;
}

.page-link {
  position: relative;
  display: block;
  padding: 0.5rem 0.75rem;
  margin-left: -1px;
  line-height: 1.25;
  color: #004c93;
  background-color: white;
  border: 1px solid #ddd;
}

.page-link:focus, .page-link:hover {
  color: #2a91d1;
  text-decoration: none;
  background-color: #ebedee;
  border-color: #ddd;
}

.pagination-lg .page-link {
  padding: 0.75rem 1.5rem;
  font-size: 1rem;
  line-height: 1.5;
}

.pagination-lg .page-item:first-child .page-link {
  border-top-left-radius: 0.3rem;
  border-bottom-left-radius: 0.3rem;
}

.pagination-lg .page-item:last-child .page-link {
  border-top-right-radius: 0.3rem;
  border-bottom-right-radius: 0.3rem;
}

.pagination-sm .page-link {
  padding: 0.25rem 0.5rem;
  font-size: 0.6rem;
  line-height: 1.2;
}

.pagination-sm .page-item:first-child .page-link {
  border-top-left-radius: 0.2rem;
  border-bottom-left-radius: 0.2rem;
}

.pagination-sm .page-item:last-child .page-link {
  border-top-right-radius: 0.2rem;
  border-bottom-right-radius: 0.2rem;
}

.badge {
  display: inline-block;
  padding: 0.25em 0.4em;
  font-size: 75%;
  font-weight: bold;
  line-height: 1;
  color: white;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: 0.25rem;
}

.badge:empty {
  display: none;
}

.btn .badge {
  position: relative;
  top: -1px;
}

.badge-pill {
  padding-right: 0.6em;
  padding-left: 0.6em;
  border-radius: 10rem;
}

.badge-primary {
  color: #fff;
  background-color: #2a91d1;
}

.badge-primary[href]:focus, .badge-primary[href]:hover {
  color: #fff;
  text-decoration: none;
  background-color: #2174a7;
}

.badge-secondary {
  color: #111;
  background-color: #a7b3b7;
}

.badge-secondary[href]:focus, .badge-secondary[href]:hover {
  color: #111;
  text-decoration: none;
  background-color: #8b9ba0;
}

.badge-success {
  color: #fff;
  background-color: #2cbcb2;
}

.badge-success[href]:focus, .badge-success[href]:hover {
  color: #fff;
  text-decoration: none;
  background-color: #22938b;
}

.badge-info {
  color: #fff;
  background-color: #17a2b8;
}

.badge-info[href]:focus, .badge-info[href]:hover {
  color: #fff;
  text-decoration: none;
  background-color: #117a8b;
}

.badge-warning {
  color: #111;
  background-color: #f0dc14;
}

.badge-warning[href]:focus, .badge-warning[href]:hover {
  color: #111;
  text-decoration: none;
  background-color: #c4b40d;
}

.badge-danger {
  color: #fff;
  background-color: #dd5e5b;
}

.badge-danger[href]:focus, .badge-danger[href]:hover {
  color: #fff;
  text-decoration: none;
  background-color: #d43531;
}

.badge-light {
  color: #111;
  background-color: #f7f7f7;
}

.badge-light[href]:focus, .badge-light[href]:hover {
  color: #111;
  text-decoration: none;
  background-color: #dedede;
}

.badge-dark {
  color: #fff;
  background-color: #4a4f5a;
}

.badge-dark[href]:focus, .badge-dark[href]:hover {
  color: #fff;
  text-decoration: none;
  background-color: #33363e;
}

.alert {
  padding: 0.75rem 1.25rem;
  margin-bottom: 1rem;
  border: 1px solid transparent;
  border-radius: 0.25rem;
}

.alert-heading {
  color: inherit;
}

.alert-link {
  font-weight: bold;
}

.alert-dismissible .close {
  position: relative;
  top: -0.75rem;
  right: -1.25rem;
  padding: 0.75rem 1.25rem;
  color: inherit;
}

.alert-primary {
  color: #164b6d;
  background-color: #d4e9f6;
  border-color: #c3e0f2;
}

.alert-primary hr {
  border-top-color: #aed5ed;
}

.alert-primary .alert-link {
  color: #0d2e43;
}

.alert-secondary {
  color: #575d5f;
  background-color: #edf0f1;
  border-color: #e6eaeb;
}

.alert-secondary hr {
  border-top-color: #d8dee0;
}

.alert-secondary .alert-link {
  color: #3f4344;
}

.alert-success {
  color: #17625d;
  background-color: #d5f2f0;
  border-color: #c4ece9;
}

.alert-success hr {
  border-top-color: #b1e6e2;
}

.alert-success .alert-link {
  color: #0d3936;
}

.alert-info {
  color: #0c5460;
  background-color: #d1ecf1;
  border-color: #bee5eb;
}

.alert-info hr {
  border-top-color: #abdde5;
}

.alert-info .alert-link {
  color: #062c33;
}

.alert-warning {
  color: #7d720a;
  background-color: #fcf8d0;
  border-color: #fbf5bd;
}

.alert-warning hr {
  border-top-color: #faf1a5;
}

.alert-warning .alert-link {
  color: #4e4706;
}

.alert-danger {
  color: #73312f;
  background-color: #f8dfde;
  border-color: #f5d2d1;
}

.alert-danger hr {
  border-top-color: #f0bebc;
}

.alert-danger .alert-link {
  color: #4f2220;
}

.alert-light {
  color: gray;
  background-color: #fdfdfd;
  border-color: #fdfdfd;
}

.alert-light hr {
  border-top-color: #f0f0f0;
}

.alert-light .alert-link {
  color: #676767;
}

.alert-dark {
  color: #27292f;
  background-color: #dbdcde;
  border-color: #ccced1;
}

.alert-dark hr {
  border-top-color: #bfc1c5;
}

.alert-dark .alert-link {
  color: #101113;
}

@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 1rem 0;
  }
  to {
    background-position: 0 0;
  }
}

@keyframes progress-bar-stripes {
  from {
    background-position: 1rem 0;
  }
  to {
    background-position: 0 0;
  }
}

.progress {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  height: 1rem;
  overflow: hidden;
  font-size: 0.75rem;
  background-color: #ebedee;
  border-radius: 0.25rem;
}

.progress-bar {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  color: white;
  background-color: #2a91d1;
}

.progress-bar-striped {
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 1rem 1rem;
}

.progress-bar-animated {
  -webkit-animation: progress-bar-stripes 1s linear infinite;
          animation: progress-bar-stripes 1s linear infinite;
}

.list-group {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  padding-left: 0;
  margin-bottom: 0;
}

.list-group-item-action {
  width: 100%;
  color: #565b68;
  text-align: inherit;
}

.list-group-item-action:focus, .list-group-item-action:hover {
  color: #565b68;
  text-decoration: none;
  background-color: #f7f7f7;
}

.list-group-item-action:active {
  color: #404040;
  background-color: #ebedee;
}

.list-group-item {
  position: relative;
  display: block;
  padding: 0.75rem 1.25rem;
  margin-bottom: -1px;
  background-color: white;
  border: 1px solid rgba(64, 64, 64, 0.125);
}

.list-group-item:first-child {
  border-top-left-radius: 0.25rem;
  border-top-right-radius: 0.25rem;
}

.list-group-item:last-child {
  margin-bottom: 0;
  border-bottom-right-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem;
}

.list-group-item:focus, .list-group-item:hover {
  text-decoration: none;
}

.list-group-item.disabled, .list-group-item:disabled {
  color: #656c7e;
  background-color: white;
}

.list-group-item.active {
  z-index: 2;
  color: white;
  background-color: #2a91d1;
  border-color: #2a91d1;
}

.list-group-flush .list-group-item {
  border-right: 0;
  border-left: 0;
  border-radius: 0;
}

.list-group-flush:first-child .list-group-item:first-child {
  border-top: 0;
}

.list-group-flush:last-child .list-group-item:last-child {
  border-bottom: 0;
}

.list-group-item-primary {
  color: #164b6d;
  background-color: #c3e0f2;
}

a.list-group-item-primary,
button.list-group-item-primary {
  color: #164b6d;
}

a.list-group-item-primary:focus, a.list-group-item-primary:hover,
button.list-group-item-primary:focus,
button.list-group-item-primary:hover {
  color: #164b6d;
  background-color: #aed5ed;
}

a.list-group-item-primary.active,
button.list-group-item-primary.active {
  color: #fff;
  background-color: #164b6d;
  border-color: #164b6d;
}

.list-group-item-secondary {
  color: #575d5f;
  background-color: #e6eaeb;
}

a.list-group-item-secondary,
button.list-group-item-secondary {
  color: #575d5f;
}

a.list-group-item-secondary:focus, a.list-group-item-secondary:hover,
button.list-group-item-secondary:focus,
button.list-group-item-secondary:hover {
  color: #575d5f;
  background-color: #d8dee0;
}

a.list-group-item-secondary.active,
button.list-group-item-secondary.active {
  color: #fff;
  background-color: #575d5f;
  border-color: #575d5f;
}

.list-group-item-success {
  color: #17625d;
  background-color: #c4ece9;
}

a.list-group-item-success,
button.list-group-item-success {
  color: #17625d;
}

a.list-group-item-success:focus, a.list-group-item-success:hover,
button.list-group-item-success:focus,
button.list-group-item-success:hover {
  color: #17625d;
  background-color: #b1e6e2;
}

a.list-group-item-success.active,
button.list-group-item-success.active {
  color: #fff;
  background-color: #17625d;
  border-color: #17625d;
}

.list-group-item-info {
  color: #0c5460;
  background-color: #bee5eb;
}

a.list-group-item-info,
button.list-group-item-info {
  color: #0c5460;
}

a.list-group-item-info:focus, a.list-group-item-info:hover,
button.list-group-item-info:focus,
button.list-group-item-info:hover {
  color: #0c5460;
  background-color: #abdde5;
}

a.list-group-item-info.active,
button.list-group-item-info.active {
  color: #fff;
  background-color: #0c5460;
  border-color: #0c5460;
}

.list-group-item-warning {
  color: #7d720a;
  background-color: #fbf5bd;
}

a.list-group-item-warning,
button.list-group-item-warning {
  color: #7d720a;
}

a.list-group-item-warning:focus, a.list-group-item-warning:hover,
button.list-group-item-warning:focus,
button.list-group-item-warning:hover {
  color: #7d720a;
  background-color: #faf1a5;
}

a.list-group-item-warning.active,
button.list-group-item-warning.active {
  color: #fff;
  background-color: #7d720a;
  border-color: #7d720a;
}

.list-group-item-danger {
  color: #73312f;
  background-color: #f5d2d1;
}

a.list-group-item-danger,
button.list-group-item-danger {
  color: #73312f;
}

a.list-group-item-danger:focus, a.list-group-item-danger:hover,
button.list-group-item-danger:focus,
button.list-group-item-danger:hover {
  color: #73312f;
  background-color: #f0bebc;
}

a.list-group-item-danger.active,
button.list-group-item-danger.active {
  color: #fff;
  background-color: #73312f;
  border-color: #73312f;
}

.list-group-item-light {
  color: gray;
  background-color: #fdfdfd;
}

a.list-group-item-light,
button.list-group-item-light {
  color: gray;
}

a.list-group-item-light:focus, a.list-group-item-light:hover,
button.list-group-item-light:focus,
button.list-group-item-light:hover {
  color: gray;
  background-color: #f0f0f0;
}

a.list-group-item-light.active,
button.list-group-item-light.active {
  color: #fff;
  background-color: gray;
  border-color: gray;
}

.list-group-item-dark {
  color: #27292f;
  background-color: #ccced1;
}

a.list-group-item-dark,
button.list-group-item-dark {
  color: #27292f;
}

a.list-group-item-dark:focus, a.list-group-item-dark:hover,
button.list-group-item-dark:focus,
button.list-group-item-dark:hover {
  color: #27292f;
  background-color: #bfc1c5;
}

a.list-group-item-dark.active,
button.list-group-item-dark.active {
  color: #fff;
  background-color: #27292f;
  border-color: #27292f;
}

.close {
  float: right;
  font-size: 1.21875rem;
  font-weight: bold;
  line-height: 1;
  color: #404040;
  text-shadow: 0 1px 0 white;
  opacity: .5;
}

.close:focus, .close:hover {
  color: #404040;
  text-decoration: none;
  opacity: .75;
}

button.close {
  padding: 0;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
}

.modal-open {
  overflow: hidden;
}

.modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1050;
  display: none;
  overflow: hidden;
  outline: 0;
}

.modal.fade .modal-dialog {
  -webkit-transition: -webkit-transform 0.3s ease-out;
  transition: -webkit-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out;
  -webkit-transform: translate(0, -25%);
          transform: translate(0, -25%);
}

.modal.show .modal-dialog {
  -webkit-transform: translate(0, 0);
          transform: translate(0, 0);
}

.modal-open .modal {
  overflow-x: hidden;
  overflow-y: auto;
}

.modal-dialog {
  position: relative;
  width: auto;
  margin: 10px;
}

.modal-content {
  position: relative;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  background-color: white;
  background-clip: padding-box;
  border: 1px solid #ebedee;
  border-radius: 0.3rem;
  outline: 0;
}

.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #565b68;
}

.modal-backdrop.fade {
  opacity: 0;
}

.modal-backdrop.show {
  opacity: 0.6;
}

.modal-header {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  padding: 0.4em 1em;
  border-bottom: 2px solid #2a91d1;
}

.modal-header .close {
  margin-left: auto;
}

.modal-title {
  margin-bottom: 0;
  line-height: 1.5;
}

.modal-body {
  position: relative;
  -webkit-box-flex: 1;
      -ms-flex: 1 1 auto;
          flex: 1 1 auto;
  padding: 1em;
}

.modal-footer {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end;
  padding: 1em;
  border-top: 1px solid #ebedee;
}

.modal-footer > :not(:first-child) {
  margin-left: .25rem;
}

.modal-footer > :not(:last-child) {
  margin-right: .25rem;
}

.modal-scrollbar-measure {
  position: absolute;
  top: -9999px;
  width: 50px;
  height: 50px;
  overflow: scroll;
}

@media (min-width: 576px) {
  .modal-dialog {
    max-width: 500px;
    margin: 30px auto;
  }
  .modal-sm {
    max-width: 400px;
  }
}

div.build-modal > div.modal-lg {
  min-width: 720px;
}

div.reshape-modal > div.modal-lg {
  min-width: 800px;
}

div.filter-modal > div.modal-lg {
  min-width: 1100px;
}

@media (min-width: 992px) {
  .modal-lg {
    max-width: 800px;
  }
  div.build-modal > div.modal-lg {
    max-width: 720px;
  }
  div.reshape-modal > div.modal-lg {
    max-width: 800px;
  }
  div.histogram-modal > div.modal-lg,
  div.code-modal > div.modal-lg {
    max-width: 700px;
  }
}

.tooltip {
  position: absolute;
  z-index: 1070;
  display: block;
  margin: 0;
  font-family: "Istok", "Helvetica", Arial, sans-serif;
  font-style: normal;
  font-weight: normal;
  line-height: 1.5;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  white-space: normal;
  line-break: auto;
  font-size: 0.6rem;
  word-wrap: break-word;
  opacity: 0;
}

.tooltip.show {
  opacity: 0.9;
}

.tooltip .arrow {
  position: absolute;
  display: block;
  width: 5px;
  height: 5px;
}

.tooltip.bs-tooltip-top, .tooltip.bs-tooltip-auto[x-placement^="top"] {
  padding: 5px 0;
}

.tooltip.bs-tooltip-top .arrow, .tooltip.bs-tooltip-auto[x-placement^="top"] .arrow {
  bottom: 0;
}

.tooltip.bs-tooltip-top .arrow::before, .tooltip.bs-tooltip-auto[x-placement^="top"] .arrow::before {
  margin-left: -3px;
  content: "";
  border-width: 5px 5px 0;
  border-top-color: #404040;
}

.tooltip.bs-tooltip-right, .tooltip.bs-tooltip-auto[x-placement^="right"] {
  padding: 0 5px;
}

.tooltip.bs-tooltip-right .arrow, .tooltip.bs-tooltip-auto[x-placement^="right"] .arrow {
  left: 0;
}

.tooltip.bs-tooltip-right .arrow::before, .tooltip.bs-tooltip-auto[x-placement^="right"] .arrow::before {
  margin-top: -3px;
  content: "";
  border-width: 5px 5px 5px 0;
  border-right-color: #404040;
}

.tooltip.bs-tooltip-bottom, .tooltip.bs-tooltip-auto[x-placement^="bottom"] {
  padding: 5px 0;
}

.tooltip.bs-tooltip-bottom .arrow, .tooltip.bs-tooltip-auto[x-placement^="bottom"] .arrow {
  top: 0;
}

.tooltip.bs-tooltip-bottom .arrow::before, .tooltip.bs-tooltip-auto[x-placement^="bottom"] .arrow::before {
  margin-left: -3px;
  content: "";
  border-width: 0 5px 5px;
  border-bottom-color: #404040;
}

.tooltip.bs-tooltip-left, .tooltip.bs-tooltip-auto[x-placement^="left"] {
  padding: 0 5px;
}

.tooltip.bs-tooltip-left .arrow, .tooltip.bs-tooltip-auto[x-placement^="left"] .arrow {
  right: 0;
}

.tooltip.bs-tooltip-left .arrow::before, .tooltip.bs-tooltip-auto[x-placement^="left"] .arrow::before {
  right: 0;
  margin-top: -3px;
  content: "";
  border-width: 5px 0 5px 5px;
  border-left-color: #404040;
}

.tooltip .arrow::before {
  position: absolute;
  border-color: transparent;
  border-style: solid;
}

.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: white;
  text-align: center;
  background-color: #404040;
  border-radius: 0.25rem;
}

.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1060;
  display: block;
  max-width: 276px;
  padding: 1px;
  font-family: "Istok", "Helvetica", Arial, sans-serif;
  font-style: normal;
  font-weight: normal;
  line-height: 1.5;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  white-space: normal;
  line-break: auto;
  font-size: 0.6rem;
  word-wrap: break-word;
  background-color: white;
  background-clip: padding-box;
  border: 1px solid rgba(64, 64, 64, 0.2);
  border-radius: 0.3rem;
}

.popover .arrow {
  position: absolute;
  display: block;
  width: 10px;
  height: 5px;
}

.popover .arrow::before,
.popover .arrow::after {
  position: absolute;
  display: block;
  border-color: transparent;
  border-style: solid;
}

.popover .arrow::before {
  content: "";
  border-width: 11px;
}

.popover .arrow::after {
  content: "";
  border-width: 11px;
}

.popover.bs-popover-top, .popover.bs-popover-auto[x-placement^="top"] {
  margin-bottom: 10px;
}

.popover.bs-popover-top .arrow, .popover.bs-popover-auto[x-placement^="top"] .arrow {
  bottom: 0;
}

.popover.bs-popover-top .arrow::before, .popover.bs-popover-auto[x-placement^="top"] .arrow::before,
.popover.bs-popover-top .arrow::after, .popover.bs-popover-auto[x-placement^="top"] .arrow::after {
  border-bottom-width: 0;
}

.popover.bs-popover-top .arrow::before, .popover.bs-popover-auto[x-placement^="top"] .arrow::before {
  bottom: -11px;
  margin-left: -6px;
  border-top-color: rgba(64, 64, 64, 0.25);
}

.popover.bs-popover-top .arrow::after, .popover.bs-popover-auto[x-placement^="top"] .arrow::after {
  bottom: -10px;
  margin-left: -6px;
  border-top-color: white;
}

.popover.bs-popover-right, .popover.bs-popover-auto[x-placement^="right"] {
  margin-left: 10px;
}

.popover.bs-popover-right .arrow, .popover.bs-popover-auto[x-placement^="right"] .arrow {
  left: 0;
}

.popover.bs-popover-right .arrow::before, .popover.bs-popover-auto[x-placement^="right"] .arrow::before,
.popover.bs-popover-right .arrow::after, .popover.bs-popover-auto[x-placement^="right"] .arrow::after {
  margin-top: -8px;
  border-left-width: 0;
}

.popover.bs-popover-right .arrow::before, .popover.bs-popover-auto[x-placement^="right"] .arrow::before {
  left: -11px;
  border-right-color: rgba(64, 64, 64, 0.25);
}

.popover.bs-popover-right .arrow::after, .popover.bs-popover-auto[x-placement^="right"] .arrow::after {
  left: -10px;
  border-right-color: white;
}

.popover.bs-popover-bottom, .popover.bs-popover-auto[x-placement^="bottom"] {
  margin-top: 10px;
}

.popover.bs-popover-bottom .arrow, .popover.bs-popover-auto[x-placement^="bottom"] .arrow {
  top: 0;
}

.popover.bs-popover-bottom .arrow::before, .popover.bs-popover-auto[x-placement^="bottom"] .arrow::before,
.popover.bs-popover-bottom .arrow::after, .popover.bs-popover-auto[x-placement^="bottom"] .arrow::after {
  margin-left: -7px;
  border-top-width: 0;
}

.popover.bs-popover-bottom .arrow::before, .popover.bs-popover-auto[x-placement^="bottom"] .arrow::before {
  top: -11px;
  border-bottom-color: rgba(64, 64, 64, 0.25);
}

.popover.bs-popover-bottom .arrow::after, .popover.bs-popover-auto[x-placement^="bottom"] .arrow::after {
  top: -10px;
  border-bottom-color: white;
}

.popover.bs-popover-bottom .popover-header::before, .popover.bs-popover-auto[x-placement^="bottom"] .popover-header::before {
  position: absolute;
  top: 0;
  left: 50%;
  display: block;
  width: 20px;
  margin-left: -10px;
  content: "";
  border-bottom: 1px solid #f7f7f7;
}

.popover.bs-popover-left, .popover.bs-popover-auto[x-placement^="left"] {
  margin-right: 10px;
}

.popover.bs-popover-left .arrow, .popover.bs-popover-auto[x-placement^="left"] .arrow {
  right: 0;
}

.popover.bs-popover-left .arrow::before, .popover.bs-popover-auto[x-placement^="left"] .arrow::before,
.popover.bs-popover-left .arrow::after, .popover.bs-popover-auto[x-placement^="left"] .arrow::after {
  margin-top: -8px;
  border-right-width: 0;
}

.popover.bs-popover-left .arrow::before, .popover.bs-popover-auto[x-placement^="left"] .arrow::before {
  right: -11px;
  border-left-color: rgba(64, 64, 64, 0.25);
}

.popover.bs-popover-left .arrow::after, .popover.bs-popover-auto[x-placement^="left"] .arrow::after {
  right: -10px;
  border-left-color: white;
}

.popover-header {
  padding: 8px 14px;
  margin-bottom: 0;
  font-size: 0.8125rem;
  color: inherit;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-top-left-radius: calc(0.3rem - 1px);
  border-top-right-radius: calc(0.3rem - 1px);
}

.popover-header:empty {
  display: none;
}

.popover-body {
  padding: 9px 14px;
  color: #404040;
}

.align-baseline {
  vertical-align: baseline !important;
}

.align-top {
  vertical-align: top !important;
}

.align-middle {
  vertical-align: middle !important;
}

.align-bottom {
  vertical-align: bottom !important;
}

.align-text-bottom {
  vertical-align: text-bottom !important;
}

.align-text-top {
  vertical-align: text-top !important;
}

.bg-primary {
  background-color: #2a91d1 !important;
}

a.bg-primary:focus, a.bg-primary:hover {
  background-color: #2174a7 !important;
}

.bg-secondary {
  background-color: #a7b3b7 !important;
}

a.bg-secondary:focus, a.bg-secondary:hover {
  background-color: #8b9ba0 !important;
}

.bg-success {
  background-color: #2cbcb2 !important;
}

a.bg-success:focus, a.bg-success:hover {
  background-color: #22938b !important;
}

.bg-info {
  background-color: #17a2b8 !important;
}

a.bg-info:focus, a.bg-info:hover {
  background-color: #117a8b !important;
}

.bg-warning {
  background-color: #f0dc14 !important;
}

a.bg-warning:focus, a.bg-warning:hover {
  background-color: #c4b40d !important;
}

.bg-danger {
  background-color: #dd5e5b !important;
}

a.bg-danger:focus, a.bg-danger:hover {
  background-color: #d43531 !important;
}

.bg-light {
  background-color: #f7f7f7 !important;
}

a.bg-light:focus, a.bg-light:hover {
  background-color: #dedede !important;
}

.bg-dark {
  background-color: #4a4f5a !important;
}

a.bg-dark:focus, a.bg-dark:hover {
  background-color: #33363e !important;
}

.bg-white {
  background-color: white !important;
}

.bg-transparent {
  background-color: transparent !important;
}

.border {
  border: 1px solid #ebedee !important;
}

.border-0 {
  border: 0 !important;
}

.border-top-0 {
  border-top: 0 !important;
}

.border-right-0 {
  border-right: 0 !important;
}

.border-bottom-0 {
  border-bottom: 0 !important;
}

.border-left-0 {
  border-left: 0 !important;
}

.border-primary {
  border-color: #2a91d1 !important;
}

.border-secondary {
  border-color: #a7b3b7 !important;
}

.border-success {
  border-color: #2cbcb2 !important;
}

.border-info {
  border-color: #17a2b8 !important;
}

.border-warning {
  border-color: #f0dc14 !important;
}

.border-danger {
  border-color: #dd5e5b !important;
}

.border-light {
  border-color: #f7f7f7 !important;
}

.border-dark {
  border-color: #4a4f5a !important;
}

.border-white {
  border-color: white !important;
}

.rounded {
  border-radius: 0.25rem !important;
}

.rounded-top {
  border-top-left-radius: 0.25rem !important;
  border-top-right-radius: 0.25rem !important;
}

.rounded-right {
  border-top-right-radius: 0.25rem !important;
  border-bottom-right-radius: 0.25rem !important;
}

.rounded-bottom {
  border-bottom-right-radius: 0.25rem !important;
  border-bottom-left-radius: 0.25rem !important;
}

.rounded-left {
  border-top-left-radius: 0.25rem !important;
  border-bottom-left-radius: 0.25rem !important;
}

.rounded-circle {
  border-radius: 50%;
}

.rounded-0 {
  border-radius: 0;
}

.clearfix::after {
  display: block;
  clear: both;
  content: "";
}

.d-none {
  display: none !important;
}

.d-inline {
  display: inline !important;
}

.d-inline-block {
  display: inline-block !important;
}

.d-block {
  display: block !important;
}

.d-table {
  display: table !important;
}

.d-table-cell {
  display: table-cell !important;
}

.d-flex {
  display: -webkit-box !important;
  display: -ms-flexbox !important;
  display: flex !important;
}

.d-inline-flex {
  display: -webkit-inline-box !important;
  display: -ms-inline-flexbox !important;
  display: inline-flex !important;
}

@media (min-width: 576px) {
  .d-sm-none {
    display: none !important;
  }
  .d-sm-inline {
    display: inline !important;
  }
  .d-sm-inline-block {
    display: inline-block !important;
  }
  .d-sm-block {
    display: block !important;
  }
  .d-sm-table {
    display: table !important;
  }
  .d-sm-table-cell {
    display: table-cell !important;
  }
  .d-sm-flex {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .d-sm-inline-flex {
    display: -webkit-inline-box !important;
    display: -ms-inline-flexbox !important;
    display: inline-flex !important;
  }
}

@media (min-width: 768px) {
  .d-md-none {
    display: none !important;
  }
  .d-md-inline {
    display: inline !important;
  }
  .d-md-inline-block {
    display: inline-block !important;
  }
  .d-md-block {
    display: block !important;
  }
  .d-md-table {
    display: table !important;
  }
  .d-md-table-cell {
    display: table-cell !important;
  }
  .d-md-flex {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .d-md-inline-flex {
    display: -webkit-inline-box !important;
    display: -ms-inline-flexbox !important;
    display: inline-flex !important;
  }
}

@media (min-width: 992px) {
  .d-lg-none {
    display: none !important;
  }
  .d-lg-inline {
    display: inline !important;
  }
  .d-lg-inline-block {
    display: inline-block !important;
  }
  .d-lg-block {
    display: block !important;
  }
  .d-lg-table {
    display: table !important;
  }
  .d-lg-table-cell {
    display: table-cell !important;
  }
  .d-lg-flex {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .d-lg-inline-flex {
    display: -webkit-inline-box !important;
    display: -ms-inline-flexbox !important;
    display: inline-flex !important;
  }
}

@media (min-width: 1200px) {
  .d-xl-none {
    display: none !important;
  }
  .d-xl-inline {
    display: inline !important;
  }
  .d-xl-inline-block {
    display: inline-block !important;
  }
  .d-xl-block {
    display: block !important;
  }
  .d-xl-table {
    display: table !important;
  }
  .d-xl-table-cell {
    display: table-cell !important;
  }
  .d-xl-flex {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
  }
  .d-xl-inline-flex {
    display: -webkit-inline-box !important;
    display: -ms-inline-flexbox !important;
    display: inline-flex !important;
  }
}

.d-print-block {
  display: none !important;
}

@media print {
  .d-print-block {
    display: block !important;
  }
}

.d-print-inline {
  display: none !important;
}

@media print {
  .d-print-inline {
    display: inline !important;
  }
}

.d-print-inline-block {
  display: none !important;
}

@media print {
  .d-print-inline-block {
    display: inline-block !important;
  }
}

@media print {
  .d-print-none {
    display: none !important;
  }
}

.embed-responsive {
  position: relative;
  display: block;
  width: 100%;
  padding: 0;
  overflow: hidden;
}

.embed-responsive::before {
  display: block;
  content: "";
}

.embed-responsive .embed-responsive-item,
.embed-responsive iframe,
.embed-responsive embed,
.embed-responsive object,
.embed-responsive video {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border: 0;
}

.embed-responsive-21by9::before {
  padding-top: 42.85714%;
}

.embed-responsive-16by9::before {
  padding-top: 56.25%;
}

.embed-responsive-4by3::before {
  padding-top: 75%;
}

.embed-responsive-1by1::before {
  padding-top: 100%;
}

.flex-row {
  -webkit-box-orient: horizontal !important;
  -webkit-box-direction: normal !important;
      -ms-flex-direction: row !important;
          flex-direction: row !important;
}

.flex-column {
  -webkit-box-orient: vertical !important;
  -webkit-box-direction: normal !important;
      -ms-flex-direction: column !important;
          flex-direction: column !important;
}

.flex-row-reverse {
  -webkit-box-orient: horizontal !important;
  -webkit-box-direction: reverse !important;
      -ms-flex-direction: row-reverse !important;
          flex-direction: row-reverse !important;
}

.flex-column-reverse {
  -webkit-box-orient: vertical !important;
  -webkit-box-direction: reverse !important;
      -ms-flex-direction: column-reverse !important;
          flex-direction: column-reverse !important;
}

.flex-wrap {
  -ms-flex-wrap: wrap !important;
      flex-wrap: wrap !important;
}

.flex-nowrap {
  -ms-flex-wrap: nowrap !important;
      flex-wrap: nowrap !important;
}

.flex-wrap-reverse {
  -ms-flex-wrap: wrap-reverse !important;
      flex-wrap: wrap-reverse !important;
}

.justify-content-start {
  -webkit-box-pack: start !important;
      -ms-flex-pack: start !important;
          justify-content: flex-start !important;
}

.justify-content-end {
  -webkit-box-pack: end !important;
      -ms-flex-pack: end !important;
          justify-content: flex-end !important;
}

.justify-content-center {
  -webkit-box-pack: center !important;
      -ms-flex-pack: center !important;
          justify-content: center !important;
}

.justify-content-between {
  -webkit-box-pack: justify !important;
      -ms-flex-pack: justify !important;
          justify-content: space-between !important;
}

.justify-content-around {
  -ms-flex-pack: distribute !important;
      justify-content: space-around !important;
}

.align-items-start {
  -webkit-box-align: start !important;
      -ms-flex-align: start !important;
          align-items: flex-start !important;
}

.align-items-end {
  -webkit-box-align: end !important;
      -ms-flex-align: end !important;
          align-items: flex-end !important;
}

.align-items-center {
  -webkit-box-align: center !important;
      -ms-flex-align: center !important;
          align-items: center !important;
}

.align-items-baseline {
  -webkit-box-align: baseline !important;
      -ms-flex-align: baseline !important;
          align-items: baseline !important;
}

.align-items-stretch {
  -webkit-box-align: stretch !important;
      -ms-flex-align: stretch !important;
          align-items: stretch !important;
}

.align-content-start {
  -ms-flex-line-pack: start !important;
      align-content: flex-start !important;
}

.align-content-end {
  -ms-flex-line-pack: end !important;
      align-content: flex-end !important;
}

.align-content-center {
  -ms-flex-line-pack: center !important;
      align-content: center !important;
}

.align-content-between {
  -ms-flex-line-pack: justify !important;
      align-content: space-between !important;
}

.align-content-around {
  -ms-flex-line-pack: distribute !important;
      align-content: space-around !important;
}

.align-content-stretch {
  -ms-flex-line-pack: stretch !important;
      align-content: stretch !important;
}

.align-self-auto {
  -ms-flex-item-align: auto !important;
      align-self: auto !important;
}

.align-self-start {
  -ms-flex-item-align: start !important;
      align-self: flex-start !important;
}

.align-self-end {
  -ms-flex-item-align: end !important;
      align-self: flex-end !important;
}

.align-self-center {
  -ms-flex-item-align: center !important;
      align-self: center !important;
}

.align-self-baseline {
  -ms-flex-item-align: baseline !important;
      align-self: baseline !important;
}

.align-self-stretch {
  -ms-flex-item-align: stretch !important;
      align-self: stretch !important;
}

@media (min-width: 576px) {
  .flex-sm-row {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: row !important;
            flex-direction: row !important;
  }
  .flex-sm-column {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: column !important;
            flex-direction: column !important;
  }
  .flex-sm-row-reverse {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: row-reverse !important;
            flex-direction: row-reverse !important;
  }
  .flex-sm-column-reverse {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: column-reverse !important;
            flex-direction: column-reverse !important;
  }
  .flex-sm-wrap {
    -ms-flex-wrap: wrap !important;
        flex-wrap: wrap !important;
  }
  .flex-sm-nowrap {
    -ms-flex-wrap: nowrap !important;
        flex-wrap: nowrap !important;
  }
  .flex-sm-wrap-reverse {
    -ms-flex-wrap: wrap-reverse !important;
        flex-wrap: wrap-reverse !important;
  }
  .justify-content-sm-start {
    -webkit-box-pack: start !important;
        -ms-flex-pack: start !important;
            justify-content: flex-start !important;
  }
  .justify-content-sm-end {
    -webkit-box-pack: end !important;
        -ms-flex-pack: end !important;
            justify-content: flex-end !important;
  }
  .justify-content-sm-center {
    -webkit-box-pack: center !important;
        -ms-flex-pack: center !important;
            justify-content: center !important;
  }
  .justify-content-sm-between {
    -webkit-box-pack: justify !important;
        -ms-flex-pack: justify !important;
            justify-content: space-between !important;
  }
  .justify-content-sm-around {
    -ms-flex-pack: distribute !important;
        justify-content: space-around !important;
  }
  .align-items-sm-start {
    -webkit-box-align: start !important;
        -ms-flex-align: start !important;
            align-items: flex-start !important;
  }
  .align-items-sm-end {
    -webkit-box-align: end !important;
        -ms-flex-align: end !important;
            align-items: flex-end !important;
  }
  .align-items-sm-center {
    -webkit-box-align: center !important;
        -ms-flex-align: center !important;
            align-items: center !important;
  }
  .align-items-sm-baseline {
    -webkit-box-align: baseline !important;
        -ms-flex-align: baseline !important;
            align-items: baseline !important;
  }
  .align-items-sm-stretch {
    -webkit-box-align: stretch !important;
        -ms-flex-align: stretch !important;
            align-items: stretch !important;
  }
  .align-content-sm-start {
    -ms-flex-line-pack: start !important;
        align-content: flex-start !important;
  }
  .align-content-sm-end {
    -ms-flex-line-pack: end !important;
        align-content: flex-end !important;
  }
  .align-content-sm-center {
    -ms-flex-line-pack: center !important;
        align-content: center !important;
  }
  .align-content-sm-between {
    -ms-flex-line-pack: justify !important;
        align-content: space-between !important;
  }
  .align-content-sm-around {
    -ms-flex-line-pack: distribute !important;
        align-content: space-around !important;
  }
  .align-content-sm-stretch {
    -ms-flex-line-pack: stretch !important;
        align-content: stretch !important;
  }
  .align-self-sm-auto {
    -ms-flex-item-align: auto !important;
        align-self: auto !important;
  }
  .align-self-sm-start {
    -ms-flex-item-align: start !important;
        align-self: flex-start !important;
  }
  .align-self-sm-end {
    -ms-flex-item-align: end !important;
        align-self: flex-end !important;
  }
  .align-self-sm-center {
    -ms-flex-item-align: center !important;
        align-self: center !important;
  }
  .align-self-sm-baseline {
    -ms-flex-item-align: baseline !important;
        align-self: baseline !important;
  }
  .align-self-sm-stretch {
    -ms-flex-item-align: stretch !important;
        align-self: stretch !important;
  }
}

@media (min-width: 768px) {
  .flex-md-row {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: row !important;
            flex-direction: row !important;
  }
  .flex-md-column {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: column !important;
            flex-direction: column !important;
  }
  .flex-md-row-reverse {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: row-reverse !important;
            flex-direction: row-reverse !important;
  }
  .flex-md-column-reverse {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: column-reverse !important;
            flex-direction: column-reverse !important;
  }
  .flex-md-wrap {
    -ms-flex-wrap: wrap !important;
        flex-wrap: wrap !important;
  }
  .flex-md-nowrap {
    -ms-flex-wrap: nowrap !important;
        flex-wrap: nowrap !important;
  }
  .flex-md-wrap-reverse {
    -ms-flex-wrap: wrap-reverse !important;
        flex-wrap: wrap-reverse !important;
  }
  .justify-content-md-start {
    -webkit-box-pack: start !important;
        -ms-flex-pack: start !important;
            justify-content: flex-start !important;
  }
  .justify-content-md-end {
    -webkit-box-pack: end !important;
        -ms-flex-pack: end !important;
            justify-content: flex-end !important;
  }
  .justify-content-md-center {
    -webkit-box-pack: center !important;
        -ms-flex-pack: center !important;
            justify-content: center !important;
  }
  .justify-content-md-between {
    -webkit-box-pack: justify !important;
        -ms-flex-pack: justify !important;
            justify-content: space-between !important;
  }
  .justify-content-md-around {
    -ms-flex-pack: distribute !important;
        justify-content: space-around !important;
  }
  .align-items-md-start {
    -webkit-box-align: start !important;
        -ms-flex-align: start !important;
            align-items: flex-start !important;
  }
  .align-items-md-end {
    -webkit-box-align: end !important;
        -ms-flex-align: end !important;
            align-items: flex-end !important;
  }
  .align-items-md-center {
    -webkit-box-align: center !important;
        -ms-flex-align: center !important;
            align-items: center !important;
  }
  .align-items-md-baseline {
    -webkit-box-align: baseline !important;
        -ms-flex-align: baseline !important;
            align-items: baseline !important;
  }
  .align-items-md-stretch {
    -webkit-box-align: stretch !important;
        -ms-flex-align: stretch !important;
            align-items: stretch !important;
  }
  .align-content-md-start {
    -ms-flex-line-pack: start !important;
        align-content: flex-start !important;
  }
  .align-content-md-end {
    -ms-flex-line-pack: end !important;
        align-content: flex-end !important;
  }
  .align-content-md-center {
    -ms-flex-line-pack: center !important;
        align-content: center !important;
  }
  .align-content-md-between {
    -ms-flex-line-pack: justify !important;
        align-content: space-between !important;
  }
  .align-content-md-around {
    -ms-flex-line-pack: distribute !important;
        align-content: space-around !important;
  }
  .align-content-md-stretch {
    -ms-flex-line-pack: stretch !important;
        align-content: stretch !important;
  }
  .align-self-md-auto {
    -ms-flex-item-align: auto !important;
        align-self: auto !important;
  }
  .align-self-md-start {
    -ms-flex-item-align: start !important;
        align-self: flex-start !important;
  }
  .align-self-md-end {
    -ms-flex-item-align: end !important;
        align-self: flex-end !important;
  }
  .align-self-md-center {
    -ms-flex-item-align: center !important;
        align-self: center !important;
  }
  .align-self-md-baseline {
    -ms-flex-item-align: baseline !important;
        align-self: baseline !important;
  }
  .align-self-md-stretch {
    -ms-flex-item-align: stretch !important;
        align-self: stretch !important;
  }
}

@media (min-width: 992px) {
  .flex-lg-row {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: row !important;
            flex-direction: row !important;
  }
  .flex-lg-column {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: column !important;
            flex-direction: column !important;
  }
  .flex-lg-row-reverse {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: row-reverse !important;
            flex-direction: row-reverse !important;
  }
  .flex-lg-column-reverse {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: column-reverse !important;
            flex-direction: column-reverse !important;
  }
  .flex-lg-wrap {
    -ms-flex-wrap: wrap !important;
        flex-wrap: wrap !important;
  }
  .flex-lg-nowrap {
    -ms-flex-wrap: nowrap !important;
        flex-wrap: nowrap !important;
  }
  .flex-lg-wrap-reverse {
    -ms-flex-wrap: wrap-reverse !important;
        flex-wrap: wrap-reverse !important;
  }
  .justify-content-lg-start {
    -webkit-box-pack: start !important;
        -ms-flex-pack: start !important;
            justify-content: flex-start !important;
  }
  .justify-content-lg-end {
    -webkit-box-pack: end !important;
        -ms-flex-pack: end !important;
            justify-content: flex-end !important;
  }
  .justify-content-lg-center {
    -webkit-box-pack: center !important;
        -ms-flex-pack: center !important;
            justify-content: center !important;
  }
  .justify-content-lg-between {
    -webkit-box-pack: justify !important;
        -ms-flex-pack: justify !important;
            justify-content: space-between !important;
  }
  .justify-content-lg-around {
    -ms-flex-pack: distribute !important;
        justify-content: space-around !important;
  }
  .align-items-lg-start {
    -webkit-box-align: start !important;
        -ms-flex-align: start !important;
            align-items: flex-start !important;
  }
  .align-items-lg-end {
    -webkit-box-align: end !important;
        -ms-flex-align: end !important;
            align-items: flex-end !important;
  }
  .align-items-lg-center {
    -webkit-box-align: center !important;
        -ms-flex-align: center !important;
            align-items: center !important;
  }
  .align-items-lg-baseline {
    -webkit-box-align: baseline !important;
        -ms-flex-align: baseline !important;
            align-items: baseline !important;
  }
  .align-items-lg-stretch {
    -webkit-box-align: stretch !important;
        -ms-flex-align: stretch !important;
            align-items: stretch !important;
  }
  .align-content-lg-start {
    -ms-flex-line-pack: start !important;
        align-content: flex-start !important;
  }
  .align-content-lg-end {
    -ms-flex-line-pack: end !important;
        align-content: flex-end !important;
  }
  .align-content-lg-center {
    -ms-flex-line-pack: center !important;
        align-content: center !important;
  }
  .align-content-lg-between {
    -ms-flex-line-pack: justify !important;
        align-content: space-between !important;
  }
  .align-content-lg-around {
    -ms-flex-line-pack: distribute !important;
        align-content: space-around !important;
  }
  .align-content-lg-stretch {
    -ms-flex-line-pack: stretch !important;
        align-content: stretch !important;
  }
  .align-self-lg-auto {
    -ms-flex-item-align: auto !important;
        align-self: auto !important;
  }
  .align-self-lg-start {
    -ms-flex-item-align: start !important;
        align-self: flex-start !important;
  }
  .align-self-lg-end {
    -ms-flex-item-align: end !important;
        align-self: flex-end !important;
  }
  .align-self-lg-center {
    -ms-flex-item-align: center !important;
        align-self: center !important;
  }
  .align-self-lg-baseline {
    -ms-flex-item-align: baseline !important;
        align-self: baseline !important;
  }
  .align-self-lg-stretch {
    -ms-flex-item-align: stretch !important;
        align-self: stretch !important;
  }
}

@media (min-width: 1200px) {
  .flex-xl-row {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: row !important;
            flex-direction: row !important;
  }
  .flex-xl-column {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: normal !important;
        -ms-flex-direction: column !important;
            flex-direction: column !important;
  }
  .flex-xl-row-reverse {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: row-reverse !important;
            flex-direction: row-reverse !important;
  }
  .flex-xl-column-reverse {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: reverse !important;
        -ms-flex-direction: column-reverse !important;
            flex-direction: column-reverse !important;
  }
  .flex-xl-wrap {
    -ms-flex-wrap: wrap !important;
        flex-wrap: wrap !important;
  }
  .flex-xl-nowrap {
    -ms-flex-wrap: nowrap !important;
        flex-wrap: nowrap !important;
  }
  .flex-xl-wrap-reverse {
    -ms-flex-wrap: wrap-reverse !important;
        flex-wrap: wrap-reverse !important;
  }
  .justify-content-xl-start {
    -webkit-box-pack: start !important;
        -ms-flex-pack: start !important;
            justify-content: flex-start !important;
  }
  .justify-content-xl-end {
    -webkit-box-pack: end !important;
        -ms-flex-pack: end !important;
            justify-content: flex-end !important;
  }
  .justify-content-xl-center {
    -webkit-box-pack: center !important;
        -ms-flex-pack: center !important;
            justify-content: center !important;
  }
  .justify-content-xl-between {
    -webkit-box-pack: justify !important;
        -ms-flex-pack: justify !important;
            justify-content: space-between !important;
  }
  .justify-content-xl-around {
    -ms-flex-pack: distribute !important;
        justify-content: space-around !important;
  }
  .align-items-xl-start {
    -webkit-box-align: start !important;
        -ms-flex-align: start !important;
            align-items: flex-start !important;
  }
  .align-items-xl-end {
    -webkit-box-align: end !important;
        -ms-flex-align: end !important;
            align-items: flex-end !important;
  }
  .align-items-xl-center {
    -webkit-box-align: center !important;
        -ms-flex-align: center !important;
            align-items: center !important;
  }
  .align-items-xl-baseline {
    -webkit-box-align: baseline !important;
        -ms-flex-align: baseline !important;
            align-items: baseline !important;
  }
  .align-items-xl-stretch {
    -webkit-box-align: stretch !important;
        -ms-flex-align: stretch !important;
            align-items: stretch !important;
  }
  .align-content-xl-start {
    -ms-flex-line-pack: start !important;
        align-content: flex-start !important;
  }
  .align-content-xl-end {
    -ms-flex-line-pack: end !important;
        align-content: flex-end !important;
  }
  .align-content-xl-center {
    -ms-flex-line-pack: center !important;
        align-content: center !important;
  }
  .align-content-xl-between {
    -ms-flex-line-pack: justify !important;
        align-content: space-between !important;
  }
  .align-content-xl-around {
    -ms-flex-line-pack: distribute !important;
        align-content: space-around !important;
  }
  .align-content-xl-stretch {
    -ms-flex-line-pack: stretch !important;
        align-content: stretch !important;
  }
  .align-self-xl-auto {
    -ms-flex-item-align: auto !important;
        align-self: auto !important;
  }
  .align-self-xl-start {
    -ms-flex-item-align: start !important;
        align-self: flex-start !important;
  }
  .align-self-xl-end {
    -ms-flex-item-align: end !important;
        align-self: flex-end !important;
  }
  .align-self-xl-center {
    -ms-flex-item-align: center !important;
        align-self: center !important;
  }
  .align-self-xl-baseline {
    -ms-flex-item-align: baseline !important;
        align-self: baseline !important;
  }
  .align-self-xl-stretch {
    -ms-flex-item-align: stretch !important;
        align-self: stretch !important;
  }
}

.float-left {
  float: left !important;
}

.float-right {
  float: right !important;
}

.float-none {
  float: none !important;
}

@media (min-width: 576px) {
  .float-sm-left {
    float: left !important;
  }
  .float-sm-right {
    float: right !important;
  }
  .float-sm-none {
    float: none !important;
  }
}

@media (min-width: 768px) {
  .float-md-left {
    float: left !important;
  }
  .float-md-right {
    float: right !important;
  }
  .float-md-none {
    float: none !important;
  }
}

@media (min-width: 992px) {
  .float-lg-left {
    float: left !important;
  }
  .float-lg-right {
    float: right !important;
  }
  .float-lg-none {
    float: none !important;
  }
}

@media (min-width: 1200px) {
  .float-xl-left {
    float: left !important;
  }
  .float-xl-right {
    float: right !important;
  }
  .float-xl-none {
    float: none !important;
  }
}

.position-static {
  position: static !important;
}

.position-relative {
  position: relative !important;
}

.position-absolute {
  position: absolute !important;
}

.position-fixed {
  position: fixed !important;
}

.position-sticky {
  position: -webkit-sticky !important;
  position: sticky !important;
}

.fixed-top {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
  z-index: 1030;
}

.fixed-bottom {
  position: fixed;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1030;
}

@supports ((position: -webkit-sticky) or (position: sticky)) {
  .sticky-top {
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index: 1020;
  }
}

.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  -webkit-clip-path: inset(50%);
          clip-path: inset(50%);
  border: 0;
}

.sr-only-focusable:active, .sr-only-focusable:focus {
  position: static;
  width: auto;
  height: auto;
  overflow: visible;
  clip: auto;
  white-space: normal;
  -webkit-clip-path: none;
          clip-path: none;
}

.w-25 {
  width: 25% !important;
}

.w-50 {
  width: 50% !important;
}

.w-75 {
  width: 75% !important;
}

.w-100 {
  width: 100% !important;
}

.h-25 {
  height: 25% !important;
}

.h-50 {
  height: 50% !important;
}

.h-75 {
  height: 75% !important;
}

.h-100 {
  height: 100% !important;
}

.mw-100 {
  max-width: 100% !important;
}

.mh-100 {
  max-height: 100% !important;
}

.m-0 {
  margin: 0 !important;
}

.mt-0,
.my-0 {
  margin-top: 0 !important;
}

.mr-0,
.mx-0 {
  margin-right: 0 !important;
}

.mb-0,
.my-0 {
  margin-bottom: 0 !important;
}

.ml-0,
.mx-0 {
  margin-left: 0 !important;
}

.m-1 {
  margin: 0.0625rem !important;
}

.mt-1,
.my-1 {
  margin-top: 0.0625rem !important;
}

.mr-1,
.mx-1 {
  margin-right: 0.0625rem !important;
}

.mb-1,
.my-1 {
  margin-bottom: 0.0625rem !important;
}

.ml-1,
.mx-1 {
  margin-left: 0.0625rem !important;
}

.m-2 {
  margin: 0.125rem !important;
}

.mt-2,
.my-2 {
  margin-top: 0.125rem !important;
}

.mr-2,
.mx-2 {
  margin-right: 0.125rem !important;
}

.mb-2,
.my-2 {
  margin-bottom: 0.125rem !important;
}

.ml-2,
.mx-2 {
  margin-left: 0.125rem !important;
}

.m-3 {
  margin: 0.25rem !important;
}

.mt-3,
.my-3 {
  margin-top: 0.25rem !important;
}

.mr-3,
.mx-3 {
  margin-right: 0.25rem !important;
}

.mb-3,
.my-3 {
  margin-bottom: 0.25rem !important;
}

.ml-3,
.mx-3 {
  margin-left: 0.25rem !important;
}

.m-4 {
  margin: 0.375rem !important;
}

.mt-4,
.my-4 {
  margin-top: 0.375rem !important;
}

.mr-4,
.mx-4 {
  margin-right: 0.375rem !important;
}

.mb-4,
.my-4 {
  margin-bottom: 0.375rem !important;
}

.ml-4,
.mx-4 {
  margin-left: 0.375rem !important;
}

.m-5 {
  margin: 0.75rem !important;
}

.mt-5,
.my-5 {
  margin-top: 0.75rem !important;
}

.mr-5,
.mx-5 {
  margin-right: 0.75rem !important;
}

.mb-5,
.my-5 {
  margin-bottom: 0.75rem !important;
}

.ml-5,
.mx-5 {
  margin-left: 0.75rem !important;
}

.p-0 {
  padding: 0 !important;
}

.pt-0,
.py-0 {
  padding-top: 0 !important;
}

.pr-0,
.px-0 {
  padding-right: 0 !important;
}

.pb-0,
.py-0 {
  padding-bottom: 0 !important;
}

.pl-0,
.px-0 {
  padding-left: 0 !important;
}

.p-1 {
  padding: 0.0625rem !important;
}

.pt-1,
.py-1 {
  padding-top: 0.0625rem !important;
}

.pr-1,
.px-1 {
  padding-right: 0.0625rem !important;
}

.pb-1,
.py-1 {
  padding-bottom: 0.0625rem !important;
}

.pl-1,
.px-1 {
  padding-left: 0.0625rem !important;
}

.p-2 {
  padding: 0.125rem !important;
}

.pt-2,
.py-2 {
  padding-top: 0.125rem !important;
}

.pr-2,
.px-2 {
  padding-right: 0.125rem !important;
}

.pb-2,
.py-2 {
  padding-bottom: 0.125rem !important;
}

.pl-2,
.px-2 {
  padding-left: 0.125rem !important;
}

.p-3 {
  padding: 0.25rem !important;
}

.pt-3,
.py-3 {
  padding-top: 0.25rem !important;
}

.pr-3,
.px-3 {
  padding-right: 0.25rem !important;
}

.pb-3,
.py-3 {
  padding-bottom: 0.25rem !important;
}

.pl-3,
.px-3 {
  padding-left: 0.25rem !important;
}

.p-4 {
  padding: 0.375rem !important;
}

.pt-4,
.py-4 {
  padding-top: 0.375rem !important;
}

.pr-4,
.px-4 {
  padding-right: 0.375rem !important;
}

.pb-4,
.py-4 {
  padding-bottom: 0.375rem !important;
}

.pl-4,
.px-4 {
  padding-left: 0.375rem !important;
}

.p-5 {
  padding: 0.75rem !important;
}

.pt-5,
.py-5 {
  padding-top: 0.75rem !important;
}

.pr-5,
.px-5 {
  padding-right: 0.75rem !important;
}

.pb-5,
.py-5 {
  padding-bottom: 0.75rem !important;
}

.pl-5,
.px-5 {
  padding-left: 0.75rem !important;
}

.m-auto {
  margin: auto !important;
}

.mt-auto,
.my-auto {
  margin-top: auto !important;
}

.mr-auto,
.mx-auto {
  margin-right: auto !important;
}

.mb-auto,
.my-auto {
  margin-bottom: auto !important;
}

.ml-auto,
.mx-auto {
  margin-left: auto !important;
}

@media (min-width: 576px) {
  .m-sm-0 {
    margin: 0 !important;
  }
  .mt-sm-0,
  .my-sm-0 {
    margin-top: 0 !important;
  }
  .mr-sm-0,
  .mx-sm-0 {
    margin-right: 0 !important;
  }
  .mb-sm-0,
  .my-sm-0 {
    margin-bottom: 0 !important;
  }
  .ml-sm-0,
  .mx-sm-0 {
    margin-left: 0 !important;
  }
  .m-sm-1 {
    margin: 0.0625rem !important;
  }
  .mt-sm-1,
  .my-sm-1 {
    margin-top: 0.0625rem !important;
  }
  .mr-sm-1,
  .mx-sm-1 {
    margin-right: 0.0625rem !important;
  }
  .mb-sm-1,
  .my-sm-1 {
    margin-bottom: 0.0625rem !important;
  }
  .ml-sm-1,
  .mx-sm-1 {
    margin-left: 0.0625rem !important;
  }
  .m-sm-2 {
    margin: 0.125rem !important;
  }
  .mt-sm-2,
  .my-sm-2 {
    margin-top: 0.125rem !important;
  }
  .mr-sm-2,
  .mx-sm-2 {
    margin-right: 0.125rem !important;
  }
  .mb-sm-2,
  .my-sm-2 {
    margin-bottom: 0.125rem !important;
  }
  .ml-sm-2,
  .mx-sm-2 {
    margin-left: 0.125rem !important;
  }
  .m-sm-3 {
    margin: 0.25rem !important;
  }
  .mt-sm-3,
  .my-sm-3 {
    margin-top: 0.25rem !important;
  }
  .mr-sm-3,
  .mx-sm-3 {
    margin-right: 0.25rem !important;
  }
  .mb-sm-3,
  .my-sm-3 {
    margin-bottom: 0.25rem !important;
  }
  .ml-sm-3,
  .mx-sm-3 {
    margin-left: 0.25rem !important;
  }
  .m-sm-4 {
    margin: 0.375rem !important;
  }
  .mt-sm-4,
  .my-sm-4 {
    margin-top: 0.375rem !important;
  }
  .mr-sm-4,
  .mx-sm-4 {
    margin-right: 0.375rem !important;
  }
  .mb-sm-4,
  .my-sm-4 {
    margin-bottom: 0.375rem !important;
  }
  .ml-sm-4,
  .mx-sm-4 {
    margin-left: 0.375rem !important;
  }
  .m-sm-5 {
    margin: 0.75rem !important;
  }
  .mt-sm-5,
  .my-sm-5 {
    margin-top: 0.75rem !important;
  }
  .mr-sm-5,
  .mx-sm-5 {
    margin-right: 0.75rem !important;
  }
  .mb-sm-5,
  .my-sm-5 {
    margin-bottom: 0.75rem !important;
  }
  .ml-sm-5,
  .mx-sm-5 {
    margin-left: 0.75rem !important;
  }
  .p-sm-0 {
    padding: 0 !important;
  }
  .pt-sm-0,
  .py-sm-0 {
    padding-top: 0 !important;
  }
  .pr-sm-0,
  .px-sm-0 {
    padding-right: 0 !important;
  }
  .pb-sm-0,
  .py-sm-0 {
    padding-bottom: 0 !important;
  }
  .pl-sm-0,
  .px-sm-0 {
    padding-left: 0 !important;
  }
  .p-sm-1 {
    padding: 0.0625rem !important;
  }
  .pt-sm-1,
  .py-sm-1 {
    padding-top: 0.0625rem !important;
  }
  .pr-sm-1,
  .px-sm-1 {
    padding-right: 0.0625rem !important;
  }
  .pb-sm-1,
  .py-sm-1 {
    padding-bottom: 0.0625rem !important;
  }
  .pl-sm-1,
  .px-sm-1 {
    padding-left: 0.0625rem !important;
  }
  .p-sm-2 {
    padding: 0.125rem !important;
  }
  .pt-sm-2,
  .py-sm-2 {
    padding-top: 0.125rem !important;
  }
  .pr-sm-2,
  .px-sm-2 {
    padding-right: 0.125rem !important;
  }
  .pb-sm-2,
  .py-sm-2 {
    padding-bottom: 0.125rem !important;
  }
  .pl-sm-2,
  .px-sm-2 {
    padding-left: 0.125rem !important;
  }
  .p-sm-3 {
    padding: 0.25rem !important;
  }
  .pt-sm-3,
  .py-sm-3 {
    padding-top: 0.25rem !important;
  }
  .pr-sm-3,
  .px-sm-3 {
    padding-right: 0.25rem !important;
  }
  .pb-sm-3,
  .py-sm-3 {
    padding-bottom: 0.25rem !important;
  }
  .pl-sm-3,
  .px-sm-3 {
    padding-left: 0.25rem !important;
  }
  .p-sm-4 {
    padding: 0.375rem !important;
  }
  .pt-sm-4,
  .py-sm-4 {
    padding-top: 0.375rem !important;
  }
  .pr-sm-4,
  .px-sm-4 {
    padding-right: 0.375rem !important;
  }
  .pb-sm-4,
  .py-sm-4 {
    padding-bottom: 0.375rem !important;
  }
  .pl-sm-4,
  .px-sm-4 {
    padding-left: 0.375rem !important;
  }
  .p-sm-5 {
    padding: 0.75rem !important;
  }
  .pt-sm-5,
  .py-sm-5 {
    padding-top: 0.75rem !important;
  }
  .pr-sm-5,
  .px-sm-5 {
    padding-right: 0.75rem !important;
  }
  .pb-sm-5,
  .py-sm-5 {
    padding-bottom: 0.75rem !important;
  }
  .pl-sm-5,
  .px-sm-5 {
    padding-left: 0.75rem !important;
  }
  .m-sm-auto {
    margin: auto !important;
  }
  .mt-sm-auto,
  .my-sm-auto {
    margin-top: auto !important;
  }
  .mr-sm-auto,
  .mx-sm-auto {
    margin-right: auto !important;
  }
  .mb-sm-auto,
  .my-sm-auto {
    margin-bottom: auto !important;
  }
  .ml-sm-auto,
  .mx-sm-auto {
    margin-left: auto !important;
  }
}

@media (min-width: 768px) {
  .m-md-0 {
    margin: 0 !important;
  }
  .mt-md-0,
  .my-md-0 {
    margin-top: 0 !important;
  }
  .mr-md-0,
  .mx-md-0 {
    margin-right: 0 !important;
  }
  .mb-md-0,
  .my-md-0 {
    margin-bottom: 0 !important;
  }
  .ml-md-0,
  .mx-md-0 {
    margin-left: 0 !important;
  }
  .m-md-1 {
    margin: 0.0625rem !important;
  }
  .mt-md-1,
  .my-md-1 {
    margin-top: 0.0625rem !important;
  }
  .mr-md-1,
  .mx-md-1 {
    margin-right: 0.0625rem !important;
  }
  .mb-md-1,
  .my-md-1 {
    margin-bottom: 0.0625rem !important;
  }
  .ml-md-1,
  .mx-md-1 {
    margin-left: 0.0625rem !important;
  }
  .m-md-2 {
    margin: 0.125rem !important;
  }
  .mt-md-2,
  .my-md-2 {
    margin-top: 0.125rem !important;
  }
  .mr-md-2,
  .mx-md-2 {
    margin-right: 0.125rem !important;
  }
  .mb-md-2,
  .my-md-2 {
    margin-bottom: 0.125rem !important;
  }
  .ml-md-2,
  .mx-md-2 {
    margin-left: 0.125rem !important;
  }
  .m-md-3 {
    margin: 0.25rem !important;
  }
  .mt-md-3,
  .my-md-3 {
    margin-top: 0.25rem !important;
  }
  .mr-md-3,
  .mx-md-3 {
    margin-right: 0.25rem !important;
  }
  .mb-md-3,
  .my-md-3 {
    margin-bottom: 0.25rem !important;
  }
  .ml-md-3,
  .mx-md-3 {
    margin-left: 0.25rem !important;
  }
  .m-md-4 {
    margin: 0.375rem !important;
  }
  .mt-md-4,
  .my-md-4 {
    margin-top: 0.375rem !important;
  }
  .mr-md-4,
  .mx-md-4 {
    margin-right: 0.375rem !important;
  }
  .mb-md-4,
  .my-md-4 {
    margin-bottom: 0.375rem !important;
  }
  .ml-md-4,
  .mx-md-4 {
    margin-left: 0.375rem !important;
  }
  .m-md-5 {
    margin: 0.75rem !important;
  }
  .mt-md-5,
  .my-md-5 {
    margin-top: 0.75rem !important;
  }
  .mr-md-5,
  .mx-md-5 {
    margin-right: 0.75rem !important;
  }
  .mb-md-5,
  .my-md-5 {
    margin-bottom: 0.75rem !important;
  }
  .ml-md-5,
  .mx-md-5 {
    margin-left: 0.75rem !important;
  }
  .p-md-0 {
    padding: 0 !important;
  }
  .pt-md-0,
  .py-md-0 {
    padding-top: 0 !important;
  }
  .pr-md-0,
  .px-md-0 {
    padding-right: 0 !important;
  }
  .pb-md-0,
  .py-md-0 {
    padding-bottom: 0 !important;
  }
  .pl-md-0,
  .px-md-0 {
    padding-left: 0 !important;
  }
  .p-md-1 {
    padding: 0.0625rem !important;
  }
  .pt-md-1,
  .py-md-1 {
    padding-top: 0.0625rem !important;
  }
  .pr-md-1,
  .px-md-1 {
    padding-right: 0.0625rem !important;
  }
  .pb-md-1,
  .py-md-1 {
    padding-bottom: 0.0625rem !important;
  }
  .pl-md-1,
  .px-md-1 {
    padding-left: 0.0625rem !important;
  }
  .p-md-2 {
    padding: 0.125rem !important;
  }
  .pt-md-2,
  .py-md-2 {
    padding-top: 0.125rem !important;
  }
  .pr-md-2,
  .px-md-2 {
    padding-right: 0.125rem !important;
  }
  .pb-md-2,
  .py-md-2 {
    padding-bottom: 0.125rem !important;
  }
  .pl-md-2,
  .px-md-2 {
    padding-left: 0.125rem !important;
  }
  .p-md-3 {
    padding: 0.25rem !important;
  }
  .pt-md-3,
  .py-md-3 {
    padding-top: 0.25rem !important;
  }
  .pr-md-3,
  .px-md-3 {
    padding-right: 0.25rem !important;
  }
  .pb-md-3,
  .py-md-3 {
    padding-bottom: 0.25rem !important;
  }
  .pl-md-3,
  .px-md-3 {
    padding-left: 0.25rem !important;
  }
  .p-md-4 {
    padding: 0.375rem !important;
  }
  .pt-md-4,
  .py-md-4 {
    padding-top: 0.375rem !important;
  }
  .pr-md-4,
  .px-md-4 {
    padding-right: 0.375rem !important;
  }
  .pb-md-4,
  .py-md-4 {
    padding-bottom: 0.375rem !important;
  }
  .pl-md-4,
  .px-md-4 {
    padding-left: 0.375rem !important;
  }
  .p-md-5 {
    padding: 0.75rem !important;
  }
  .pt-md-5,
  .py-md-5 {
    padding-top: 0.75rem !important;
  }
  .pr-md-5,
  .px-md-5 {
    padding-right: 0.75rem !important;
  }
  .pb-md-5,
  .py-md-5 {
    padding-bottom: 0.75rem !important;
  }
  .pl-md-5,
  .px-md-5 {
    padding-left: 0.75rem !important;
  }
  .m-md-auto {
    margin: auto !important;
  }
  .mt-md-auto,
  .my-md-auto {
    margin-top: auto !important;
  }
  .mr-md-auto,
  .mx-md-auto {
    margin-right: auto !important;
  }
  .mb-md-auto,
  .my-md-auto {
    margin-bottom: auto !important;
  }
  .ml-md-auto,
  .mx-md-auto {
    margin-left: auto !important;
  }
}

@media (min-width: 992px) {
  .m-lg-0 {
    margin: 0 !important;
  }
  .mt-lg-0,
  .my-lg-0 {
    margin-top: 0 !important;
  }
  .mr-lg-0,
  .mx-lg-0 {
    margin-right: 0 !important;
  }
  .mb-lg-0,
  .my-lg-0 {
    margin-bottom: 0 !important;
  }
  .ml-lg-0,
  .mx-lg-0 {
    margin-left: 0 !important;
  }
  .m-lg-1 {
    margin: 0.0625rem !important;
  }
  .mt-lg-1,
  .my-lg-1 {
    margin-top: 0.0625rem !important;
  }
  .mr-lg-1,
  .mx-lg-1 {
    margin-right: 0.0625rem !important;
  }
  .mb-lg-1,
  .my-lg-1 {
    margin-bottom: 0.0625rem !important;
  }
  .ml-lg-1,
  .mx-lg-1 {
    margin-left: 0.0625rem !important;
  }
  .m-lg-2 {
    margin: 0.125rem !important;
  }
  .mt-lg-2,
  .my-lg-2 {
    margin-top: 0.125rem !important;
  }
  .mr-lg-2,
  .mx-lg-2 {
    margin-right: 0.125rem !important;
  }
  .mb-lg-2,
  .my-lg-2 {
    margin-bottom: 0.125rem !important;
  }
  .ml-lg-2,
  .mx-lg-2 {
    margin-left: 0.125rem !important;
  }
  .m-lg-3 {
    margin: 0.25rem !important;
  }
  .mt-lg-3,
  .my-lg-3 {
    margin-top: 0.25rem !important;
  }
  .mr-lg-3,
  .mx-lg-3 {
    margin-right: 0.25rem !important;
  }
  .mb-lg-3,
  .my-lg-3 {
    margin-bottom: 0.25rem !important;
  }
  .ml-lg-3,
  .mx-lg-3 {
    margin-left: 0.25rem !important;
  }
  .m-lg-4 {
    margin: 0.375rem !important;
  }
  .mt-lg-4,
  .my-lg-4 {
    margin-top: 0.375rem !important;
  }
  .mr-lg-4,
  .mx-lg-4 {
    margin-right: 0.375rem !important;
  }
  .mb-lg-4,
  .my-lg-4 {
    margin-bottom: 0.375rem !important;
  }
  .ml-lg-4,
  .mx-lg-4 {
    margin-left: 0.375rem !important;
  }
  .m-lg-5 {
    margin: 0.75rem !important;
  }
  .mt-lg-5,
  .my-lg-5 {
    margin-top: 0.75rem !important;
  }
  .mr-lg-5,
  .mx-lg-5 {
    margin-right: 0.75rem !important;
  }
  .mb-lg-5,
  .my-lg-5 {
    margin-bottom: 0.75rem !important;
  }
  .ml-lg-5,
  .mx-lg-5 {
    margin-left: 0.75rem !important;
  }
  .p-lg-0 {
    padding: 0 !important;
  }
  .pt-lg-0,
  .py-lg-0 {
    padding-top: 0 !important;
  }
  .pr-lg-0,
  .px-lg-0 {
    padding-right: 0 !important;
  }
  .pb-lg-0,
  .py-lg-0 {
    padding-bottom: 0 !important;
  }
  .pl-lg-0,
  .px-lg-0 {
    padding-left: 0 !important;
  }
  .p-lg-1 {
    padding: 0.0625rem !important;
  }
  .pt-lg-1,
  .py-lg-1 {
    padding-top: 0.0625rem !important;
  }
  .pr-lg-1,
  .px-lg-1 {
    padding-right: 0.0625rem !important;
  }
  .pb-lg-1,
  .py-lg-1 {
    padding-bottom: 0.0625rem !important;
  }
  .pl-lg-1,
  .px-lg-1 {
    padding-left: 0.0625rem !important;
  }
  .p-lg-2 {
    padding: 0.125rem !important;
  }
  .pt-lg-2,
  .py-lg-2 {
    padding-top: 0.125rem !important;
  }
  .pr-lg-2,
  .px-lg-2 {
    padding-right: 0.125rem !important;
  }
  .pb-lg-2,
  .py-lg-2 {
    padding-bottom: 0.125rem !important;
  }
  .pl-lg-2,
  .px-lg-2 {
    padding-left: 0.125rem !important;
  }
  .p-lg-3 {
    padding: 0.25rem !important;
  }
  .pt-lg-3,
  .py-lg-3 {
    padding-top: 0.25rem !important;
  }
  .pr-lg-3,
  .px-lg-3 {
    padding-right: 0.25rem !important;
  }
  .pb-lg-3,
  .py-lg-3 {
    padding-bottom: 0.25rem !important;
  }
  .pl-lg-3,
  .px-lg-3 {
    padding-left: 0.25rem !important;
  }
  .p-lg-4 {
    padding: 0.375rem !important;
  }
  .pt-lg-4,
  .py-lg-4 {
    padding-top: 0.375rem !important;
  }
  .pr-lg-4,
  .px-lg-4 {
    padding-right: 0.375rem !important;
  }
  .pb-lg-4,
  .py-lg-4 {
    padding-bottom: 0.375rem !important;
  }
  .pl-lg-4,
  .px-lg-4 {
    padding-left: 0.375rem !important;
  }
  .p-lg-5 {
    padding: 0.75rem !important;
  }
  .pt-lg-5,
  .py-lg-5 {
    padding-top: 0.75rem !important;
  }
  .pr-lg-5,
  .px-lg-5 {
    padding-right: 0.75rem !important;
  }
  .pb-lg-5,
  .py-lg-5 {
    padding-bottom: 0.75rem !important;
  }
  .pl-lg-5,
  .px-lg-5 {
    padding-left: 0.75rem !important;
  }
  .m-lg-auto {
    margin: auto !important;
  }
  .mt-lg-auto,
  .my-lg-auto {
    margin-top: auto !important;
  }
  .mr-lg-auto,
  .mx-lg-auto {
    margin-right: auto !important;
  }
  .mb-lg-auto,
  .my-lg-auto {
    margin-bottom: auto !important;
  }
  .ml-lg-auto,
  .mx-lg-auto {
    margin-left: auto !important;
  }
}

@media (min-width: 1200px) {
  .m-xl-0 {
    margin: 0 !important;
  }
  .mt-xl-0,
  .my-xl-0 {
    margin-top: 0 !important;
  }
  .mr-xl-0,
  .mx-xl-0 {
    margin-right: 0 !important;
  }
  .mb-xl-0,
  .my-xl-0 {
    margin-bottom: 0 !important;
  }
  .ml-xl-0,
  .mx-xl-0 {
    margin-left: 0 !important;
  }
  .m-xl-1 {
    margin: 0.0625rem !important;
  }
  .mt-xl-1,
  .my-xl-1 {
    margin-top: 0.0625rem !important;
  }
  .mr-xl-1,
  .mx-xl-1 {
    margin-right: 0.0625rem !important;
  }
  .mb-xl-1,
  .my-xl-1 {
    margin-bottom: 0.0625rem !important;
  }
  .ml-xl-1,
  .mx-xl-1 {
    margin-left: 0.0625rem !important;
  }
  .m-xl-2 {
    margin: 0.125rem !important;
  }
  .mt-xl-2,
  .my-xl-2 {
    margin-top: 0.125rem !important;
  }
  .mr-xl-2,
  .mx-xl-2 {
    margin-right: 0.125rem !important;
  }
  .mb-xl-2,
  .my-xl-2 {
    margin-bottom: 0.125rem !important;
  }
  .ml-xl-2,
  .mx-xl-2 {
    margin-left: 0.125rem !important;
  }
  .m-xl-3 {
    margin: 0.25rem !important;
  }
  .mt-xl-3,
  .my-xl-3 {
    margin-top: 0.25rem !important;
  }
  .mr-xl-3,
  .mx-xl-3 {
    margin-right: 0.25rem !important;
  }
  .mb-xl-3,
  .my-xl-3 {
    margin-bottom: 0.25rem !important;
  }
  .ml-xl-3,
  .mx-xl-3 {
    margin-left: 0.25rem !important;
  }
  .m-xl-4 {
    margin: 0.375rem !important;
  }
  .mt-xl-4,
  .my-xl-4 {
    margin-top: 0.375rem !important;
  }
  .mr-xl-4,
  .mx-xl-4 {
    margin-right: 0.375rem !important;
  }
  .mb-xl-4,
  .my-xl-4 {
    margin-bottom: 0.375rem !important;
  }
  .ml-xl-4,
  .mx-xl-4 {
    margin-left: 0.375rem !important;
  }
  .m-xl-5 {
    margin: 0.75rem !important;
  }
  .mt-xl-5,
  .my-xl-5 {
    margin-top: 0.75rem !important;
  }
  .mr-xl-5,
  .mx-xl-5 {
    margin-right: 0.75rem !important;
  }
  .mb-xl-5,
  .my-xl-5 {
    margin-bottom: 0.75rem !important;
  }
  .ml-xl-5,
  .mx-xl-5 {
    margin-left: 0.75rem !important;
  }
  .p-xl-0 {
    padding: 0 !important;
  }
  .pt-xl-0,
  .py-xl-0 {
    padding-top: 0 !important;
  }
  .pr-xl-0,
  .px-xl-0 {
    padding-right: 0 !important;
  }
  .pb-xl-0,
  .py-xl-0 {
    padding-bottom: 0 !important;
  }
  .pl-xl-0,
  .px-xl-0 {
    padding-left: 0 !important;
  }
  .p-xl-1 {
    padding: 0.0625rem !important;
  }
  .pt-xl-1,
  .py-xl-1 {
    padding-top: 0.0625rem !important;
  }
  .pr-xl-1,
  .px-xl-1 {
    padding-right: 0.0625rem !important;
  }
  .pb-xl-1,
  .py-xl-1 {
    padding-bottom: 0.0625rem !important;
  }
  .pl-xl-1,
  .px-xl-1 {
    padding-left: 0.0625rem !important;
  }
  .p-xl-2 {
    padding: 0.125rem !important;
  }
  .pt-xl-2,
  .py-xl-2 {
    padding-top: 0.125rem !important;
  }
  .pr-xl-2,
  .px-xl-2 {
    padding-right: 0.125rem !important;
  }
  .pb-xl-2,
  .py-xl-2 {
    padding-bottom: 0.125rem !important;
  }
  .pl-xl-2,
  .px-xl-2 {
    padding-left: 0.125rem !important;
  }
  .p-xl-3 {
    padding: 0.25rem !important;
  }
  .pt-xl-3,
  .py-xl-3 {
    padding-top: 0.25rem !important;
  }
  .pr-xl-3,
  .px-xl-3 {
    padding-right: 0.25rem !important;
  }
  .pb-xl-3,
  .py-xl-3 {
    padding-bottom: 0.25rem !important;
  }
  .pl-xl-3,
  .px-xl-3 {
    padding-left: 0.25rem !important;
  }
  .p-xl-4 {
    padding: 0.375rem !important;
  }
  .pt-xl-4,
  .py-xl-4 {
    padding-top: 0.375rem !important;
  }
  .pr-xl-4,
  .px-xl-4 {
    padding-right: 0.375rem !important;
  }
  .pb-xl-4,
  .py-xl-4 {
    padding-bottom: 0.375rem !important;
  }
  .pl-xl-4,
  .px-xl-4 {
    padding-left: 0.375rem !important;
  }
  .p-xl-5 {
    padding: 0.75rem !important;
  }
  .pt-xl-5,
  .py-xl-5 {
    padding-top: 0.75rem !important;
  }
  .pr-xl-5,
  .px-xl-5 {
    padding-right: 0.75rem !important;
  }
  .pb-xl-5,
  .py-xl-5 {
    padding-bottom: 0.75rem !important;
  }
  .pl-xl-5,
  .px-xl-5 {
    padding-left: 0.75rem !important;
  }
  .m-xl-auto {
    margin: auto !important;
  }
  .mt-xl-auto,
  .my-xl-auto {
    margin-top: auto !important;
  }
  .mr-xl-auto,
  .mx-xl-auto {
    margin-right: auto !important;
  }
  .mb-xl-auto,
  .my-xl-auto {
    margin-bottom: auto !important;
  }
  .ml-xl-auto,
  .mx-xl-auto {
    margin-left: auto !important;
  }
}

.text-justify {
  text-align: justify !important;
}

.text-nowrap {
  white-space: nowrap !important;
}

.text-truncate {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.text-left {
  text-align: left !important;
}

.text-right {
  text-align: right !important;
}

.text-center {
  text-align: center !important;
}

@media (min-width: 576px) {
  .text-sm-left {
    text-align: left !important;
  }
  .text-sm-right {
    text-align: right !important;
  }
  .text-sm-center {
    text-align: center !important;
  }
}

@media (min-width: 768px) {
  .text-md-left {
    text-align: left !important;
  }
  .text-md-right {
    text-align: right !important;
  }
  .text-md-center {
    text-align: center !important;
  }
}

@media (min-width: 992px) {
  .text-lg-left {
    text-align: left !important;
  }
  .text-lg-right {
    text-align: right !important;
  }
  .text-lg-center {
    text-align: center !important;
  }
}

@media (min-width: 1200px) {
  .text-xl-left {
    text-align: left !important;
  }
  .text-xl-right {
    text-align: right !important;
  }
  .text-xl-center {
    text-align: center !important;
  }
}

.text-lowercase {
  text-transform: lowercase !important;
}

.text-uppercase {
  text-transform: uppercase !important;
}

.text-capitalize {
  text-transform: capitalize !important;
}

.font-weight-light {
  font-weight: 300 !important;
}

.font-weight-normal {
  font-weight: normal !important;
}

.font-weight-bold {
  font-weight: bold !important;
}

.font-italic {
  font-style: italic !important;
}

.text-white {
  color: #fff !important;
}

.text-primary {
  color: #2a91d1 !important;
}

a.text-primary:focus, a.text-primary:hover {
  color: #2174a7 !important;
}

.text-secondary {
  color: #a7b3b7 !important;
}

a.text-secondary:focus, a.text-secondary:hover {
  color: #8b9ba0 !important;
}

.text-success {
  color: #2cbcb2 !important;
}

a.text-success:focus, a.text-success:hover {
  color: #22938b !important;
}

.text-info {
  color: #17a2b8 !important;
}

a.text-info:focus, a.text-info:hover {
  color: #117a8b !important;
}

.text-warning {
  color: #f0dc14 !important;
}

a.text-warning:focus, a.text-warning:hover {
  color: #c4b40d !important;
}

.text-danger {
  color: #dd5e5b !important;
}

a.text-danger:focus, a.text-danger:hover {
  color: #d43531 !important;
}

.text-light {
  color: #f7f7f7 !important;
}

a.text-light:focus, a.text-light:hover {
  color: #dedede !important;
}

.text-dark {
  color: #4a4f5a !important;
}

a.text-dark:focus, a.text-dark:hover {
  color: #33363e !important;
}

.text-muted {
  color: #656c7e !important;
}

.text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}

.visible {
  visibility: visible !important;
}

.invisible {
  visibility: hidden !important;
}

@keyframes Select-animation-spin {
  to {
    -webkit-transform: rotate(1turn);
            transform: rotate(1turn);
  }
}

@-webkit-keyframes Select-animation-spin {
  to {
    -webkit-transform: rotate(1turn);
  }
}

.Select {
  position: relative;
}

.Select,
.Select div,
.Select input,
.Select span {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.Select.is-disabled > .Select__control,
.Select.is-disabled > .Select-control {
  background-color: #d1d7d9;
}

.Select.is-disabled > .Select__control:hover,
.Select.is-disabled > .Select-control:hover {
  -webkit-box-shadow: none;
          box-shadow: none;
}

.Select.is-disabled .Select__indicators,
.Select.is-disabled .Select-indicators {
  cursor: default;
  pointer-events: none;
}

.Select__control,
.Select-control {
  background-color: white;
  border-color: #b5bfc2 #a7b3b7 #8b9ba0;
  border-radius: 0.25rem;
  border: 1px solid #a7b3b7;
  color: #404040;
  cursor: default;
  border-spacing: 0;
  border-collapse: separate;
  height: calc(1.91562rem + 2px);
  outline: none;
  overflow: hidden;
  position: relative;
  width: 100%;
}

.Select__control:hover,
.Select-control:hover {
  -webkit-box-shadow: 0 0 2px 0 rgba(125, 143, 149, 0.5) inset;
          box-shadow: 0 0 2px 0 rgba(125, 143, 149, 0.5) inset;
}

.Select__control .Select__input:focus,
.Select-control .Select-input:focus {
  outline: none;
}

.Select.is-searchable .Select__menu > .Select__control,
.Select.is-searchable .Select-menu > .Select-control {
  cursor: text;
}

.Select .Select__menu > .Select__control,
.Select .Select__menu > .Select-control {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  background: white;
  border-color: #8b9ba0 #a7b3b7 #b5bfc2;
}

.Select .Select__menu > .Select__control .Select-arrow,
.Select .Select-menu > .Select-control .Select-arrow{
  top: -2px;
  border-color: transparent transparent #404040;
  border-width: 0 5px 5px;
}

.is-searchable > .Select__control--is-focused,
.is-searchable > .Select-control--is-focused {
  cursor: text;
}

.is-focused:not(.Select .Select__menu) > .Select__control,
.is-focused:not(.Select .Select-menu) > .Select-control {
  border-color: #2a91d1 #3d9cd8 #3d9cd8;
  -webkit-box-shadow: inset 0 0 2px 0 rgba(29, 101, 145, 0.5);
          box-shadow: inset 0 0 2px 0 rgba(29, 101, 145, 0.5);
}

.Select__placeholder, .Select__control .Select__single-value,
.Select-placeholder, .Select-control .Select-single-value {
  color: #333;
  left: 0;
  line-height: calc(1.91562rem);
  padding-left: 0.5rem;
  padding-right: 0.5rem;
  position: absolute;
  right: 0;
  max-width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.Select__placeholder, .Select-placeholder  {
  color: #8d8d8d;
}

.Select__value-container, .Select-multi-value-wrapper {
  position: inherit;
  overflow: hidden;
}

.is-clearable.Select--single .Select__value-container--has-value > .Select__single-value,
.is-clearable.Select--single .Select-value-container--has-value > .Select-single-value {
  padding-right: 40.5px;
}

.Select--single .Select__value-container--has-value > .Select__single-value,
.Select--single .Select__control-is-focused .Select__value-container--has-value > .Select__single-value,
.Select--single .Select-value-container--has-value > .Select-single-value,
.Select--single .Select-control-is-focused .Select-value-container--has-value > .Select-single-value {
  color: #404040;
}

.Select--single .Select__value-container--has-value > .Select__single-value a,
.Select--single .Select__control-is-focused .Select__value-container--has-value > .Select__single-value a,
.Select--single .Select-value-container--has-value > .Select-single-value a,
.Select--single .Select-control-is-focused .Select-value-container--has-value > .Select-single-value a {
  cursor: pointer;
  text-decoration: none;
}

.Select--single .Select__value-container--has-value > .Select__single-value a:hover,
.Select--single .Select__value-container--has-value > .Select__single-value a:focus,
.Select--single .Select__control-is-focused .Select__value-container--has-value > .Select__single-value a:hover,
.Select--single .Select__control-is-focused .Select__value-container--has-value > .Select__single-value a:focus,
.Select--single .Select-value-container--has-value > .Select-single-value a:hover,
.Select--single .Select-value-container--has-value > .Select-single-value a:focus,
.Select--single .Select-control-is-focused .Select-value-container--has-value > .Select-single-value a:hover,
.Select--single .Select-control-is-focused .Select-value-container--has-value > .Select-single-value a:focus{
  color: #2a91d1;
  outline: none;
  text-decoration: underline;
}

.Select__input, .Select-input {
  vertical-align: middle;
  border: 0;
}

.Select__input > input, .Select-input > input {
  background: none transparent;
  border: 0 none;
  -webkit-box-shadow: none;
          box-shadow: none;
  cursor: default;
  display: inline-block;
  font-family: inherit;
  font-size: inherit;
  margin: 0;
  outline: none;
  /* For IE 8 compatibility */
  -webkit-appearance: none;
}

.Select__control-is-focused .Select__input > input,
.Select-control-is-focused .Select-input > input {
  cursor: text;
}

.Select__control-is-focused .Select__value-container--has-value .Select__input,
.Select-control-is-focused .Select-value-container--has-value .Select-input {
  opacity: 0;
}

.Select__control:not(.is-searchable) > .Select__input,
.Select-control:not(.is-searchable) > .Select-input {
  outline: none;
}

.Select-loading-zone {
  cursor: pointer;
  display: table-cell;
  position: relative;
  text-align: center;
  vertical-align: middle;
  width: 1.2rem;
}

.Select-loading {
  -webkit-animation: Select-animation-spin 400ms infinite linear;
  animation: Select-animation-spin 400ms infinite linear;
  width: 1.2rem;
  height: 1.2rem;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  border-radius: 50%;
  border: 0rem solid #a7b3b7;
  border-right-color: #404040;
  display: inline-block;
  position: relative;
  vertical-align: middle;
}

.Select__clear-indicator,
.Select-clear-indicator {
  -webkit-animation: Select-animation-fadeIn 200ms;
  animation: Select-animation-fadeIn 200ms;
  color: #8d8d8d;
  cursor: pointer;
  position: relative;
  text-align: center;
  vertical-align: middle;
  padding: 0;
}

.Select__clear-indicator:hover,
.Select-clear-indicator:hover {
  color: #dd5e5b;
}

.Select__indicator-separator,
.Select-indicator-separator {
  display: none;
}

.Select__clear-indicator svg,
.Select-clear-indicator svg {
  display: inline-block;
  font-size: 1.2rem;
  line-height: 1;
}

.Select--multi .Select__clear-indicator,
.Select-multi .Select__clear-indicator {
  width: 15.5px;
}

.Select__value-container--is-multi,
.Select-value-container--is-multi {
  display: inline-block;
}

.Select .Select-aria-only {
  display: inline-block;
  height: 1px;
  width: 1px;
  margin: -1px;
  clip: rect(0, 0, 0, 0);
  overflow: hidden;
  float: left;
}

.Select__dropdown-indicator,
.Select-dropdown-indicator {
  cursor: pointer;
  display: table-cell;
  position: relative;
  text-align: center;
  vertical-align: middle;
  padding-right: 10px;
}

.Select__dropdown-indicator svg,
.Select-dropdown-indicator svg {
  border-color: #404040 transparent transparent;
  border-style: solid;
  border-width: 5px 5px 2.5px;
  display: inline-block;
  height: 0;
  width: 0;
  position: relative;
}

.Select .Select__menu > .Select__dropdown-indicator svg,
.Select__dropdown-indicator svg:hover > svg,
.Select .Select-menu > .Select-dropdown-indicator svg,
.Select-dropdown-indicator svg:hover > svg {
  border-top-color: #404040;
}

@-webkit-keyframes Select-animation-fadeIn {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}

@keyframes Select-animation-fadeIn {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}

.Select__menu, .Select-menu {
  border-bottom-right-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem;
  background-color: white;
  border: 1px solid #a7b3b7;
  border-top-color: #d3d9db;
  -webkit-box-shadow: 0 0 2px 0 rgba(125, 143, 149, 0.5) inset;
          box-shadow: 0 0 2px 0 rgba(125, 143, 149, 0.5) inset;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  margin-top: -1px;
  max-height: 200px;
  position: absolute;
  top: 100%;
  width: 100%;
  z-index: 1000;
  -webkit-overflow-scrolling: touch;
}

.Select__menu-list, .Select-menu-list {
  max-height: 198px;
  overflow-y: auto;
}

.Select__option, .Select-option {
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  background-color: white;
  color: #737373;
  cursor: pointer;
  display: block;
  padding: 0.375rem 0.75rem;
}

.Select__option:last-child, .Select-option:last-child {
  border-bottom-right-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem;
}

.Select__option--is-selected, .Select-option--is-selected {
  background-color: ransparentize(#52bbef, 0.8);
  color: #404040;
}

.Select__option--is-focused, .Select-option--is-focused {
  background-color: rgba(42, 145, 209, 0.2);
  color: #404040;
}

.Select__option--is-disabled, .Select-option--is-disabled {
  color: #d9d9d9;
  cursor: default;
}

.Select__noresults, .Select-noresults {
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  color: #a6a6a6;
  cursor: default;
  display: block;
  padding: 0.375rem 0.75rem;
}

.Select--multi .Select__input, .Select--multi .Select-input {
  vertical-align: middle;
  padding: 0;
}

.Select__value-container--is-multi.Select__value-container--has-value .Select__input,
.Select-value-container--is-multi.Select-value-container--has-value .Select-input{
  margin-left: 5px;
}

.Select__value-container--is-multi > div:last-child,
.Select-value-container--is-multi > div:last-child {
  display: inline-block;
}

.Select__multi-value, .Select-multi-value {
  border-radius: 2px;
  color: white;
  display: inline-flex;
  font-size: 0.9em;
  margin-left: 5px;
  vertical-align: top;
}

.Select__multi-value__label, .Select-multi-value-label {
  display: inline-block;
}

.Select__multi-value__label, .Select-multi-value-label {
  border-bottom-right-radius: 2px;
  border-top-right-radius: 2px;
  cursor: default;
  color: black;
  vertical-align: middle;
}

a.Select__multi-value__label, a.Select-multi-value-label{
  color: white;
  cursor: pointer;
  text-decoration: none;
}

.Select__multi-value__label:hover, .Select-multi-value-label:hover {
  text-decoration: underline;
}

.Select__multi-value__remove, .Select-multi-value-remove {
  cursor: pointer;
  border-bottom-left-radius: 2px;
  border-top-left-radius: 2px;
  color: black;
}

.Select__multi-value__remove:hover,
.Select__multi-value__remove:focus,
.Select-multi-value-remove:hover,
.Select-multi-value-remove:focus {
  background-color: #3bb2ed;
  color: #f2f2f2;
}

.Select__multi-value__remove:active,
.Select-multi-value-remove:active {
  background-color: #2a91d1;
}

.Select.is-disabled .Select__multi-value,
.Select.is-disabled .Select-multi-value {
  background-color: #ebedee;
  border: 1px solid #cfd4d7;
  color: #404040;
}

.Select.is-disabled .Select__multi-value__remove,
.Select.is-disabled .Select-multi-value-remove {
  cursor: not-allowed;
  border-right: 1px solid #cfd4d7;
}

.Select.is-disabled .Select__multi-value__remove:hover,
.Select.is-disabled .Select__multi-value__remove:focus,
.Select.is-disabled .Select__multi-value__remove:active,
.Select.is-disabled .Select-multi-value-remove:hover,
.Select.is-disabled .Select-multi-value-remove:focus,
.Select.is-disabled .Select-multi-value-remove:active {
  background-color: #ebedee;
}

@keyframes Select-animation-spin {
  to {
    -webkit-transform: rotate(1turn);
            transform: rotate(1turn);
  }
}

@-webkit-keyframes Select-animation-spin {
  to {
    -webkit-transform: rotate(1turn);
  }
}

.app-header {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  position: fixed;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  z-index: 10;
  margin-bottom: 3px;
  -webkit-box-shadow: 0 3px 0 0 #2a91d1;
          box-shadow: 0 3px 0 0 #2a91d1;
  background: linear-gradient(85deg, #004c93, #2a91d1 70%, #52bbef);
  height: 3rem;
  color: white;
  width: 100%;
}

div.container-fluid.glc > div#content {
  padding-top: 4.95em;
}

div#content {
  padding-top: 3.95em;
}

div#content.admin {
  padding-top: 0;
}

div.debug {
  padding-top: 4em;
}

@media (max-width: 1024px) {
  .app-header {
    height: 6rem;
  }

  .app-header__nav--secondary {
    position: fixed;
    right: 0;
  }

  div#content {
    padding-top: 6.95em;
  }

  div.debug {
    padding-top: 8em;
  }

  .Login .row {
    margin-top: 10px;
  }
}

@media (max-width: 767px) {
  .app-header {
    height: 6rem;
  }
}

.app-header a {
  color: white;
}

.app-header a:visited {
  color: white;
}

.app-header a:hover, .app-header a:focus, .app-header a:active {
  color: white;
}

.app-header a:focus {
  outline: 0;
}

.app-header a:hover {
  text-decoration: none;
}

.app-header__logo {
  -ms-flex-item-align: center;
      align-self: center;
  margin: 0;
  line-height: 1;
  font-size: 1.27rem;
}

.logo--man-grail {
  display: inline-block;
  padding: .5rem 2rem 0 1rem;
  font-weight: normal;
}

@media (max-width: 991px) {
  .logo--man-grail {
    padding-right: 1em;
  }
}

.logo--man-grail::before {
  margin-right: .3em;
  margin-bottom: .2em;
  font-size: 2rem;
  content: "";
}

.app-header__nav--main a, .app-header__nav--secondary a {
  display: block;
  -webkit-transition: -webkit-box-shadow .2s ease-out;
  transition: -webkit-box-shadow .2s ease-out;
  transition: box-shadow .2s ease-out;
  transition: box-shadow .2s ease-out, -webkit-box-shadow .2s ease-out;
  padding: 1.4em 1.4em .8em;
}

@media (max-width: 991px) {
  .app-header__nav--main a, .app-header__nav--secondary a {
    border-bottom: solid 1px rgba(255, 255, 255, 0.1);
    padding: 1.5em .8em 1.1em;
    font-size: .95em;
  }
}

.app-header__nav--main a:hover, .app-header__nav--secondary a:hover {
  -webkit-transition: -webkit-box-shadow .2s ease-out;
  transition: -webkit-box-shadow .2s ease-out;
  transition: box-shadow .2s ease-out;
  transition: box-shadow .2s ease-out, -webkit-box-shadow .2s ease-out;
  -webkit-box-shadow: -1px 0 0 0 rgba(255, 255, 255, 0.1) inset, 10em 0 0 0 rgba(42, 145, 209, 0.5) inset;
          box-shadow: -1px 0 0 0 rgba(255, 255, 255, 0.1) inset, 10em 0 0 0 rgba(42, 145, 209, 0.5) inset;
  text-decoration: none;
}

.active .app-header__nav--main a, .app-header__nav--main .active a, .active .app-header__nav--secondary a, .app-header__nav--secondary .active a {
  -webkit-box-shadow: none;
          box-shadow: none;
  background: #2a91d1;
}

.app-header__nav--main {
  -webkit-box-shadow: 1px 0 0 0 rgba(255, 255, 255, 0.1) inset;
          box-shadow: 1px 0 0 0 rgba(255, 255, 255, 0.1) inset;
}

.app-header__nav--main a {
  -webkit-box-shadow: -1px 0 0 0 rgba(255, 255, 255, 0.1) inset;
          box-shadow: -1px 0 0 0 rgba(255, 255, 255, 0.1) inset;
}

.app-header__nav--secondary {
  margin-left: auto;
}

.toolbar {
  background: #dce0e2;
  padding: 1.25em;
  width: 100%;
}

.toolbar__column {
  -webkit-box-flex: 1;
      -ms-flex: 1 0 50%;
          flex: 1 0 50%;
}

.toolbar__column:first-child {
  border-right: solid 0.8em #ebedee;
}

.toolbar__column:last-child {
  border-left: solid 0.8em #ebedee;
}

.toolbar__section {
  border-bottom: solid 2px #ebedee;
  padding: .5em 1em;
  width: 100%;
}

.toolbar__actions {
  position: relative;
  padding: .5em 1em;
  width: 100%;
}

.toolbar__actions .btn-primary {
  min-width: 8em;
}

.toolbar__actions .actions--secondary {
  position: absolute;
  top: 0.5em;
  right: 0;
}

.thead-tools {
  margin: .2em 1em .2em 0;
}

caption {
  caption-side: top;
}

.table--property {
  width: 100%;
}

.table--property thead {
  border-bottom: solid 1px white;
}

.table--property th {
  padding: .2em 1em .1em .2em;
}

.table--property th.text-right {
  padding: .2em .2em .1em 1em;
}

.table--property td {
  padding: .2em .5em .1em .2em;
}

.table--property td.text-right {
  padding: .2em .2em .1em .5em;
}

.table--property th,
.table--property td {
  border-bottom: solid 1px white;
  vertical-align: top;
}

.table--property tr:last-of-type th,
.table--property tr:last-of-type td {
  border-bottom: 0;
}

.table thead th {
  border-bottom: solid 1px #a7b3b7;
  color: #565b68;
}

.table tbody + tbody {
  border-top: 0;
}

.thead-default td,
.thead-default th {
  border-color: #a7b3b7;
}

.table-bordered thead th {
  border-bottom: solid 1px #a7b3b7;
  padding: .2em .5em;
}

.table-bordered tbody th,
.table-bordered tbody td {
  border-right: 0;
  border-left: 0;
  padding: .2em .5em;
}

.table-bordered tbody th:last-child,
.table-bordered tbody td:last-child {
  border-right: solid 1px #ced5d8;
}

.table-bordered tbody th:first-child,
.table-bordered tbody td:first-child {
  border-left: solid 1px #ced5d8;
}

.table-bordered caption + tbody tr:first-of-type td,
.table-bordered caption + tbody tr:first-of-type th {
  border-top: solid 1px #a7b3b7;
}

.table-hover .data--path {
  visibility: hidden;
}

.table-hover tbody tr:hover .data--path {
  visibility: visible;
}

.table-hover tbody tr:hover .btn-ico {
  background: #52bbef;
}

.table-hover tbody tr:hover .btn-ico:hover {
  background: #2a91d1;
}

.table-hover tbody tr:hover .ico-collapse-square,
.table-hover tbody tr:hover .ico-expand-square {
  color: #52bbef;
}

.data-table + .data-table {
  margin-top: 2em;
}

.table-complex thead {
  border-top: solid 2px #a7b3b7;
}

.table-complex thead:first-of-type {
  border-top-width: 1px;
}

.table-complex thead.even th {
  border-color: #dce0e2;
  background: white;
}

.table-complex thead.even th:first-child {
  border-left: solid 1px #a7b3b7;
}

.table-complex thead.even th:last-child {
  border-right: solid 1px #a7b3b7;
}

.table-complex thead.odd th {
  border-color: white;
  background: #ebedee;
}

.table-complex thead.odd th:first-child {
  border-left: solid 1px #656c7e;
}

.table-complex thead.odd th:last-child {
  border-right: solid 1px #656c7e;
}

.table-complex thead h4 {
  margin: 1em 0 .5em;
}

.table-complex tbody.even th,
.table-complex tbody.even td {
  border: solid 1px #f7f7f7;
  background: white;
}

.table-complex tbody.even th:first-child,
.table-complex tbody.even td:first-child {
  border-left: solid 1px #a7b3b7;
}

.table-complex tbody.even th:last-child,
.table-complex tbody.even td:last-child {
  border-right: solid 1px #a7b3b7;
}

.table-complex tbody.even tr:last-child th,
.table-complex tbody.even tr:last-child td {
  border-bottom: solid 1px #ced5d8;
}

.table-complex tbody.odd th,
.table-complex tbody.odd td {
  border: solid 1px white;
  background: #f7f7f7;
}

.table-complex tbody.odd th:first-child,
.table-complex tbody.odd td:first-child {
  border-left: solid 1px #656c7e;
}

.table-complex tbody.odd th:last-child,
.table-complex tbody.odd td:last-child {
  border-right: solid 1px #656c7e;
}

.table-complex tbody.odd tr:last-child th,
.table-complex tbody.odd tr:last-child td {
  border-bottom: solid 1px #ced5d8;
}

.table-scrollable {
  display: block;
  position: relative;
  height: 40em;
}

.table-scrollable table {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-flow: column;
          flex-flow: column;
  width: 100%;
  height: 100%;
}

.table-scrollable table thead {
  -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
          flex: 0 0 auto;
  width: calc(100% - .5rem);
}

.table-scrollable table tbody {
  display: block;
  -webkit-box-flex: 1;
      -ms-flex: 1 1 auto;
          flex: 1 1 auto;
  overflow-y: scroll;
}

.table-scrollable table tbody::-webkit-scrollbar {
  -webkit-box-shadow: 0 0 2px 0 #dce0e2 inset;
          box-shadow: 0 0 2px 0 #dce0e2 inset;
  background-color: white;
  width: .5rem;
}

.table-scrollable table tbody::-webkit-scrollbar-thumb {
  border-radius: .3em;
  background-color: #a7b3b7;
}

.table-scrollable table tr {
  display: table;
  margin-bottom: -1px;
  width: 100%;
  table-layout: fixed;
}

.table-scrollable table td:active,
.table-scrollable table td:focus {
  -webkit-box-shadow: 0 0 0 1px #52bbef inset;
          box-shadow: 0 0 0 1px #52bbef inset;
}

.table-scrollable .table-bordered {
  border: 0;
  -webkit-box-shadow: 0 0 0 1px #f7f7f7 inset;
          box-shadow: 0 0 0 1px #f7f7f7 inset;
}

.table-scrollable::after {
  position: absolute;
  right: 0;
  bottom: 0;
  left: 0;
  background: -webkit-gradient(linear, left top, left bottom, from(rgba(64, 64, 64, 0)), to(rgba(64, 64, 64, 0.2)));
  background: linear-gradient(to bottom, rgba(64, 64, 64, 0), rgba(64, 64, 64, 0.2));
  height: 1em;
  content: '';
}

.column-toggle,
.sort-menu-toggle,
.filter-menu-toggle,
.hidden-menu-toggle {
  position: relative;
  text-align: center;
}

.column-toggle__dropdown {
  position: absolute;
  top: 100%;
  left: -0.5em;
  margin-top: 1em;
  -webkit-box-shadow: 0 0 0 1px rgba(101, 108, 126, 0.5) inset, 0 1px 3px 1px rgba(64, 64, 64, 0.2);
          box-shadow: 0 0 0 1px rgba(101, 108, 126, 0.5) inset, 0 1px 3px 1px rgba(64, 64, 64, 0.2);
  background: #ebedee;
  min-width: 15em;
  color: #404040;
  font-weight: 400;
  z-index: 10;
}

.column-toggle__dropdown.right {
  left: auto;
  right: -0.5em;
}

.column-toggle__dropdown::before {
  position: absolute;
  bottom: 100%;
  /*left: 0.6em;*/
  content: ' ';
  z-index: 2;
  width: 0;
  height: 0;
  border-bottom: 0.5em solid rgba(101, 108, 126, 0.5);
  margin-right: -0.5em;
  border-right: 0.5em solid transparent;
  border-left: 0.5em solid transparent;
}

.column-toggle__dropdown::after {
  position: absolute;
  bottom: calc(100% - .1em);
  /*left: 0.6em;*/
  content: ' ';
  z-index: 2;
  width: 0;
  height: 0;
  border-bottom: 0.5em solid #ebedee;
  margin-right: -0.5em;
  border-right: 0.5em solid transparent;
  border-left: 0.5em solid transparent;
}

.column-toggle__dropdown header {
  border-bottom: solid 1px #a7b3b7;
  padding: .3em .5em;
  color: #565b68;
  font-weight: 600;
}

.column-toggle__dropdown ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

.column-toggle__dropdown li {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  border-bottom: solid 1px #a7b3b7;
  width: 100%;
}

.column-toggle__dropdown li span {
  padding: .3em;
}

.toggler-action {
  border-right: solid 1px #a7b3b7;
  width: 2em;
  text-align: center;
}

.btn-group .btn.btn-primary {
  border: solid 1px #a7b3b7;
  -webkit-box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.2);
          box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.2);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(80%, white), to(#ebedee));
  background: linear-gradient(to bottom, white 80%, #ebedee);
  color: #404040;
}

.btn-group .btn.btn-primary:enabled {
  cursor: pointer;
}

.btn-group .btn.btn-primary:enabled:hover, .btn-group .btn.btn-primary:enabled:focus {
  border: solid 1px #99a7ac;
  -webkit-box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.3);
          box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.3);
}

.btn-group .btn.btn-primary:enabled:active {
  border: solid 1px #99a7ac;
  -webkit-box-shadow: 0 0 1px 0 rgba(112, 130, 136, 0.3), 0 0 1px 0 #cfd4d7 inset;
          box-shadow: 0 0 1px 0 rgba(112, 130, 136, 0.3), 0 0 1px 0 #cfd4d7 inset;
  background: -webkit-gradient(linear, left top, left bottom, from(#ebedee), to(white));
  background: linear-gradient(to bottom, #ebedee, white);
}

.btn-group .btn.btn-primary.active {
  border: solid 1px #2174a7;
  -webkit-box-shadow: 0 0 3px 0 #2174a7 inset;
          box-shadow: 0 0 3px 0 #2174a7 inset;
  background: #2a91d1;
  color: white;
}

.btn-group .btn.btn-primary.active:enabled:hover {
  border: solid 1px #2174a7;
  -webkit-box-shadow: 0 0 3px 0 #2174a7 inset;
          box-shadow: 0 0 3px 0 #2174a7 inset;
  background: #2a91d1;
  cursor: default;
}

.btn-group .btn.btn-primary.active:enabled:active, .btn-group .btn.btn-primary.active:enabled:focus {
  border: solid 1px #2174a7;
  -webkit-box-shadow: 0 0 3px 0 #2174a7 inset;
          box-shadow: 0 0 3px 0 #2174a7 inset;
  background: #2a91d1;
}

.btn-group .btn.btn-secondary, .btn-secondary {
  border: 0;
  background: #a7b3b7;
  color: white;
}

.btn-group .btn.btn-secondary:enabled, .btn-secondary:enabled {
  cursor: pointer;
}

.btn-secondary:enabled:hover {
  background: #88989e;
  color: white;
}

.btn-secondary:enabled:active, .btn-secondary:enabled:focus {
  -webkit-box-shadow: 0 0 1px 1px #59676c inset;
          box-shadow: 0 0 1px 1px #59676c inset;
  background: #88989e;
}

.btn-plain {
  margin: 0;
  border: 0;
  background: transparent;
  cursor: pointer;
  padding: 0;
  color: #565b68;
}

.btn-plain:hover, .btn-plain:focus, .btn-plain:active {
  outline: 0;
  color: #52bbef;
}

.btn-settings, .btn-hint {
  padding: .45rem;
}

.btn-settings::before, .btn-hint::before {
  margin: -.1em .2em -.1em 0;
  font-size: 1rem;
}

.btn + .btn {
  margin-left: .2em;
}

.btn [class*='ico-'] + * {
  margin-left: .3em;
}

.btn-group.compact {
  -ms-flex-item-align: center;
      align-self: center;
  vertical-align: middle;
}

.btn-group.compact .btn {
  padding: .3em .4em;
  font-size: .85em;
}

.btn-ico {
  border-radius: .2em;
  padding: 0;
  line-height: 1;
}

.btn-ico + .btn-ico {
  margin-left: .3em;
}

.btn-settings::before {
  content: "";
}

.btn-hint {
  cursor: auto !important;
  border-left: solid 1px #ced5d8 !important;
}

.btn-hint::before {
  content: "";
}

.custom-select,
select.form-control,
[type="text"],
[type="password"],
[type="email"],
[type="number"], .Select__control {
  border: solid 1px #a7b3b7;
  -webkit-box-shadow: 0 0 2px 0 rgba(125, 143, 149, 0.5) inset;
          box-shadow: 0 0 2px 0 rgba(125, 143, 149, 0.5) inset;
  min-height: auto;
}

.custom-select:hover,
select.form-control:hover,
[type="text"]:hover,
[type="password"]:hover,
[type="email"]:hover,
[type="number"]:hover, .Select__control:hover {
  border: solid 1px #2a91d1;
}

.custom-select:focus,
select.form-control:focus,
[type="text"]:focus,
[type="password"]:focus,
[type="email"]:focus,
[type="number"]:focus {
  border: solid 1px #2a91d1;
  -webkit-box-shadow: 0 0 2px 0 rgba(29, 101, 145, 0.5) inset;
          box-shadow: 0 0 2px 0 rgba(29, 101, 145, 0.5) inset;
}

.Select__input > input:focus {
  border: none;
  -webkit-box-shadow: none;
          box-shadow: none;
}

.input-group-addon {
  border: solid 1px #2174a7;
  background: #2a91d1;
  color: white;
}

.input-group-addon--secondary {
  border: solid 1px #a7b3b7;
  background: #ebedee;
  color: #404040;
}

.input-group-addon + .Select .Select__control,
.input-group-addon + div > .Select .Select-control,
.input-group-addon + .form-control {
  border-radius: 0 .25rem .25rem 0;
}

.input-group-addon--secondary {
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  padding: .5em;
  min-width: 5.5em;
}

.form-group:last-child {
  margin-bottom: 0;
}

.form-group.row:last-child {
  margin-bottom: .5em;
}

.Select--single,
.Select--multi {
  width: 100%;
  min-width: 15em;
}

.Select--multi .Select-multi-value-wrapper {
    display: block !important;
}

.Select__clear-indicator,
.Select__dropdown-indicator {
  vertical-align: middle;
}

.refreshable .Select {
  display: inline-block;
  width: calc(100% - 4em - 15px);
  vertical-align: middle;
}

.refreshable .btn {
  margin-left: .3em;
  vertical-align: middle;
}

[class^='ico-'] {
  display: inline-block;
  vertical-align: middle;
  line-height: 1;
}

[class^='ico-']::before {
  font-size: 1rem;
}

.ico-hint::before {
  content: "";
}

.ico-hint-outline::before {
  content: "";
}

.ico-hint-more::before {
  content: "";
}

.ico-hint-alert::before {
  content: "";
}

.ico-hint-question::before {
  content: "";
}

.ico-hint-text::before {
  content: "";
}

.ico-hint-edit::before {
  content: "";
}

.ico-chat::before {
  content: "";
}

.ico-equalizer::before {
  content: "";
}

.ico-bubble-chart::before {
  content: "";
}

.ico-show-chart::before {
  content: "";
}

.ico-timeline::before {
  content: "";
}

.ico-multiline-chart::before {
  content: "";
}

.ico-donut-small::before {
  content: "";
}

.ico-donut-large::before {
  content: "";
}

.ico-data-usage::before {
  content: "";
}

.ico-pie-chart::before {
  content: "";
}

.ico-pie-chart-outlined::before {
  content: "";
}

.ico-block::before {
  content: "";
}

.ico-trending-down::before {
  content: "";
}

.ico-trending-flat::before {
  content: "";
}

.ico-trending-up::before {
  content: "";
}

.ico-close::before {
  content: "";
}

.ico-done::before {
  content: "";
}

.ico-done-all::before {
  content: "";
}

.ico-add::before {
  content: "";
}

.ico-remove::before {
  content: "";
}

.ico-priority-high::before {
  content: "";
}

.ico-new-releases::before {
  content: "";
}

.ico-warning::before {
  content: "";
}

.ico-report::before {
  content: "";
}

.ico-collapse-square::before {
  content: "";
}

.ico-expand-square::before {
  content: "";
}

.ico-add-circle::before {
  content: "";
}

.ico-remove-circle::before {
  content: "";
}

.ico-check-circle::before {
  content: "";
}

.ico-add-outline::before {
  content: "";
}

.ico-remove-outline::before {
  content: "";
}

.ico-check-box::before {
  content: "";
}

.ico-check-box-outline-blank::before {
  content: "";
}

.ico-radio-button-checked::before {
  content: "";
}

.ico-radio-button-unchecked::before {
  content: "";
}

.ico-lens::before {
  content: "";
}

.ico-error::before {
  content: "";
}

.ico-help::before {
  content: "";
}

.ico-info::before {
  content: "";
}

.ico-cancel::before {
  content: "";
}

.ico-error-outline::before {
  content: "";
}

.ico-help-outline::before {
  content: "";
}

.ico-info-outline::before {
  content: "";
}

.ico-close-circle::before {
  content: "";
}

.ico-arrow-drop-up::before {
  content: "";
}

.ico-arrow-drop-down::before {
  content: "";
}

.ico-navigate-before::before {
  content: "";
}

.ico-navigate-next::before {
  content: "";
}

.ico-expand-less::before {
  content: "";
}

.ico-expand-more::before {
  content: "";
}

.ico-arrow-back::before {
  content: "";
}

.ico-arrow-forward::before {
  content: "";
}

.ico-arrow-upward::before {
  content: "";
}

.ico-arrow-downward::before {
  content: "";
}

.ico-call-made::before {
  content: "";
}

.ico-call-received::before {
  content: "";
}

.ico-shuffle::before {
  content: "";
}

.ico-unfold-more::before {
  content: "";
}

.ico-unfold-less::before {
  content: "";
}

.ico-swap-horiz::before {
  content: "";
}

.ico-import-export::before {
  content: "";
}

.ico-open-with::before {
  content: "";
}

.ico-zoom-out-map::before {
  content: "";
}

.ico-publish::before {
  content: "";
}

.ico-get-app::before {
  content: "";
}

.ico-file-upload::before {
  content: "";
}

.ico-repeat::before {
  content: "";
}

.ico-autorenew::before {
  content: "";
}

.ico-sync::before {
  content: "";
}

.ico-cached::before {
  content: "";
}

.ico-replay::before {
  content: "";
}

.ico-refresh::before {
  content: "";
}

.ico-settings-backup-restore::before {
  content: "";
}

.ico-redo::before {
  content: "";
}

.ico-undo::before {
  content: "";
}

.ico-reply::before {
  content: "";
}

.ico-reply-all::before {
  content: "";
}

.ico-visibility::before {
  content: "";
}

.ico-visibility-off::before {
  content: "";
}

.ico-edit::before {
  content: "";
}

.ico-delete::before {
  content: "";
}

.ico-settings::before {
  content: "";
}

.ico-build::before {
  content: "";
}

.ico-dns::before {
  content: "";
}

.ico-storage::before {
  content: "";
}

.ico-tune::before {
  content: "";
}

.ico-power::before {
  content: "";
}

.ico-exit-to-app::before {
  content: "";
}

.ico-input::before {
  content: "";
}

.ico-open-in-new::before {
  content: "";
}

.ico-system-update-alt::before {
  content: "";
}

.ico-backspace::before {
  content: "";
}

.ico-label::before {
  content: "";
}

.ico-label-outline::before {
  content: "";
}

.ico-beenhere::before {
  content: "";
}

.ico-content-cut::before {
  content: "";
}

.ico-content-paste::before {
  content: "";
}

.ico-link::before {
  content: "";
}

.ico-mailbox::before {
  content: "";
}

.ico-inbox::before {
  content: "";
}

.ico-markunread::before {
  content: "";
}

.ico-mail-outline::before {
  content: "";
}

.ico-drafts::before {
  content: "";
}

.ico-unarchive::before {
  content: "";
}

.ico-archive::before {
  content: "";
}

.ico-import-contacts::before {
  content: "";
}

.ico-insert-drive-file::before {
  content: "";
}

.ico-note-add::before {
  content: "";
}

.ico-description::before {
  content: "";
}

.ico-find-in-page::before {
  content: "";
}

.ico-folder-open::before {
  content: "";
}

.ico-folder::before {
  content: "";
}

.ico-create-new-folder::before {
  content: "";
}

.ico-account-balance::before {
  content: "";
}

.ico-business-center::before {
  content: "";
}

.ico-work::before {
  content: "";
}

.ico-account-balance-wallet::before {
  content: "";
}

.ico-payment::before {
  content: "";
}

.ico-functions::before {
  content: "";
}

.ico-attach-money::before {
  content: "";
}

.ico-euro-symbol::before {
  content: "";
}

.ico-local-atm::before {
  content: "";
}

.ico-key::before {
  content: "";
}

.ico-local-offer::before {
  content: "";
}

.ico-favorite::before {
  content: "";
}

.ico-favorite-border::before {
  content: "";
}

.ico-star::before {
  content: "";
}

.ico-star-border::before {
  content: "";
}

.ico-star-half::before {
  content: "";
}

.ico-turned-in::before {
  content: "";
}

.ico-turned-in-not::before {
  content: "";
}

.ico-thumb-down::before {
  content: "";
}

.ico-thumb-up::before {
  content: "";
}

.ico-thumbs-up-down::before {
  content: "";
}

.ico-home::before {
  content: "";
}

.ico-flag::before {
  content: "";
}

.ico-lightbulb-outline::before {
  content: "";
}

.ico-style::before {
  content: "";
}

.ico-palette::before {
  content: "";
}

.ico-photo::before {
  content: "";
}

.ico-photo-camera::before {
  content: "";
}

.ico-extension::before {
  content: "";
}

.ico-straighten::before {
  content: "";
}

.ico-receipt::before {
  content: "";
}

.ico-share::before {
  content: "";
}

.ico-colorize::before {
  content: "";
}

.ico-attach-file::before {
  content: "";
}

.ico-attachment::before {
  content: "";
}

.ico-bug-report::before {
  content: "";
}

.ico-security::before {
  content: "";
}

.ico-verified-user::before {
  content: "";
}

.ico-vpn-lock::before {
  content: "";
}

.ico-public::before {
  content: "";
}

.ico-map::before {
  content: "";
}

.ico-near-me::before {
  content: "";
}

.ico-room::before {
  content: "";
}

.ico-location-off::before {
  content: "";
}

.ico-explore::before {
  content: "";
}

.ico-wb-cloudy::before {
  content: "";
}

.ico-cloud-done::before {
  content: "";
}

.ico-cloud-upload::before {
  content: "";
}

.ico-cloud-download::before {
  content: "";
}

.ico-cloud-off::before {
  content: "";
}

.ico-cloud-queue::before {
  content: "";
}

.ico-access-alarms::before {
  content: "";
}

.ico-alarm-on::before {
  content: "";
}

.ico-alarm-off::before {
  content: "";
}

.ico-timer::before {
  content: "";
}

.ico-timer-off::before {
  content: "";
}

.ico-restore::before {
  content: "";
}

.ico-schedule::before {
  content: "";
}

.ico-watch-later::before {
  content: "";
}

.ico-timelapse::before {
  content: "";
}

.ico-watch::before {
  content: "";
}

.ico-hourglass-empty::before {
  content: "";
}

.ico-hourglass-full::before {
  content: "";
}

.ico-today::before {
  content: "";
}

.ico-insert-invitation::before {
  content: "";
}

.ico-event-available::before {
  content: "";
}

.ico-event-busy::before {
  content: "";
}

.ico-event-note::before {
  content: "";
}

.ico-date-range::before {
  content: "";
}

.ico-flash-off::before {
  content: "";
}

.ico-flash-on::before {
  content: "";
}

.ico-person::before {
  content: "";
}

.ico-account-box::before {
  content: "";
}

.ico-person-add::before {
  content: "";
}

.ico-people::before {
  content: "";
}

.ico-group-add::before {
  content: "";
}

.ico-lock::before {
  content: "";
}

.ico-enhanced-encryption::before {
  content: "";
}

.ico-no-encryption::before {
  content: "";
}

.ico-lock-open::before {
  content: "";
}

.ico-lock-outline::before {
  content: "";
}

.ico-keyboard::before {
  content: "";
}

.ico-phone::before {
  content: "";
}

.ico-call-end::before {
  content: "";
}

.ico-keyboard-voice::before {
  content: "";
}

.ico-language::before {
  content: "";
}

.ico-g-translate::before {
  content: "";
}

.ico-layers::before {
  content: "";
}

.ico-layers-clear::before {
  content: "";
}

.ico-web-asset::before {
  content: "";
}

.ico-filter-none::before {
  content: "";
}

.ico-more::before {
  content: "";
}

.ico-eject::before {
  content: "";
}

.ico-code::before {
  content: "";
}

.ico-settings-ethernet::before {
  content: "";
}

.ico-list::before {
  content: "";
}

.ico-apps::before {
  content: "";
}

.ico-view-agenda::before {
  content: "";
}

.ico-view-stream::before {
  content: "";
}

.ico-view-week::before {
  content: "";
}

.ico-view-array::before {
  content: "";
}

.ico-view-carousel::before {
  content: "";
}

.ico-view-column::before {
  content: "";
}

.ico-view-comfy::before {
  content: "";
}

.ico-view-compact::before {
  content: "";
}

.ico-view-day::before {
  content: "";
}

.ico-dashboard::before {
  content: "";
}

.ico-view-list::before {
  content: "";
}

.ico-view-module::before {
  content: "";
}

.ico-view-quilt::before {
  content: "";
}

.ico-menu::before {
  content: "";
}

.ico-view-headline::before {
  content: "";
}

.ico-reorder::before {
  content: "";
}

.ico-more-horiz::before {
  content: "";
}

.ico-more-vert::before {
  content: "";
}

.ico-linear-scale::before {
  content: "";
}

.ico-network-wifi::before {
  content: "";
}

.ico-next-week::before {
  content: "";
}

.ico-notifications::before {
  content: "";
}

.ico-add-alert::before {
  content: "";
}

.ico-notifications-active::before {
  content: "";
}

.ico-notifications-none::before {
  content: "";
}

.ico-notifications-off::before {
  content: "";
}

.ico-notifications-paused::before {
  content: "";
}

.ico-wifi::before {
  content: "";
}

.ico-rss-feed::before {
  content: "";
}

.ico-wifi-tethering::before {
  content: "";
}

.ico-search::before {
  content: "";
}

.ico-zoom-in::before {
  content: "";
}

.ico-zoom-out::before {
  content: "";
}

.ico-youtube-searched-for::before {
  content: "";
}

.ico-doc::before {
  content: "";
}

.ico-pdf::before {
  content: "";
}

.ico-excel::before {
  content: "";
}

.ico-man::before {
  content: "";
}

.modal-dialog {
  -webkit-box-shadow: 0 0 0 1px rgba(101, 108, 126, 0.5) inset, 0 1px 3px 1px rgba(64, 64, 64, 0.5);
          box-shadow: 0 0 0 1px rgba(101, 108, 126, 0.5) inset, 0 1px 3px 1px rgba(64, 64, 64, 0.5);
}

.modal-content {
  border: 0;
  border-radius: .2em;
}

.modal-title {
  color: #004c93;
  font-size: .9375rem;
  font-weight: normal;
}

.modal-title i {
  margin-right: .2em;
  margin-left: -.5em;
  color: #2a91d1;
}

.modal-body + .modal-body {
  border-top: solid 1px #ebedee;
}

.modal-form {
  background: #f7f7f7;
  padding: .5em 1em;
}

.modal-body .chart-wrapper {
  margin: 1em -1em 0;
  border: 0;
}

.modal-body.scatter-body .chart-wrapper {
  margin: 0 -1em 0;
  border: 0;
}

.modal-body.scatter-body .chart-wrapper {
  border-top: none;
}

.modal-body.scatter-body .row {
  margin-left: 0;
  margin-right: 0;
}


.modal-header .close {
  cursor: pointer;
}

.modal-footer {
  border-radius: 0 0 .2em .2em;
  background: #ebedee;
  padding: .5em 1em;
}

.modal-footer > :not(:first-child) {
  margin-left: 1em;
}

.modal-footer .btn-primary {
  min-width: 8em;
}

.modal-footer .bouncer {
    height: 20px;
    width: 20px;
}

@media (min-width: 1200px) {
  .modal-lg {
    max-width: 85em;
  }
}

.hoverable__content {
  -webkit-box-shadow: 0 0 0 1px rgba(101, 108, 126, 0.5) inset, 0 1px 3px 1px rgba(64, 64, 64, 0.2);
          box-shadow: 0 0 0 1px rgba(101, 108, 126, 0.5) inset, 0 1px 3px 1px rgba(64, 64, 64, 0.2);
  background: white;
}

.app-main {
  padding: 1.25em;
}

.property-pair {
  margin-bottom: 0;
}

.property-pair.inline {
  display: inline-block;
  margin: 0 1em 0 0;
  vertical-align: middle;
}

.property-pair.block dt {
  display: block;
}

.property-pair dt {
  display: inline;
  vertical-align: top;
}

.property-pair dt::after {
  content: ': ';
}

.property-pair dd {
  display: inline;
  margin: 0;
  font-weight: normal;
}

.property-pair dd + dd::before,
.property-pair dd + dt::before {
  content: ' ';
}

.title {
  font-size: .75rem;
}

.link--secondary {
  color: #565b68;
  text-decoration: underline;
}

.link--secondary:visited {
  color: #5b5d63;
}

.link--secondary:hover, .link--secondary:focus, .link--secondary:active {
  color: #2a91d1;
}

.link--secondary:focus {
  outline: 0;
}

.hoverable {
  color: #004c93;
  display: inline;
  position: relative;
  border-bottom: dashed 1px #004c93;
}
.cell.hoverable {
  border-bottom: solid 1px rgba(170, 170, 170, 0.25);
}
.hoverable-click {
  display: inline;
  position: relative;
}

.hoverable:visited {
  color: #044c8f;
}

.hoverable:hover, .hoverable:focus, .hoverable:active {
  color: #2a91d1;
}
li.hoverable:hover {
  border-bottom: solid 1px #a7b3b7;
}
.cell.hoverable:hover {
  border-bottom: solid 1px rgba(170, 170, 170, 0.25);
}

.hoverable:focus {
  outline: 0;
}

.hoverable:hover {
  border-bottom: solid 1px #004c93;
  text-decoration: none;
}

.hoverable:hover .hoverable__content {
  display: block;
}

.hoverable .hoverable__content,
.hoverable-click .hoverable__content{
  display: none;
}

.hoverable__content {
  position: absolute;
  top: 100%;
  right: 0;
  z-index: 100;
  margin-top: .5em;
  padding: .5em 1em;
  width: 20em;
  text-align: left;
  color: #404040;
}
.hoverable__content.menu-description,
.hoverable__content.edit-cell {
    top: -0.8em;
    left: 13em;
}
.hoverable__content.map-types {
    min-width: 13em;
    right: unset;
    left: 0;
}
.hoverable__content.build-code {
    width: auto;
    right: unset;
    left: 0;
    top: 3em;
}
.hoverable__content.copy-tt-bottom {
  padding: .5em .5em;
  width: 10em;
  text-align: center;
}
.hoverable__content.copy-tt-top {
  padding: .5em .5em;
  width: 10em;
  text-align: center;
  top: unset;
  bottom: 110%;
}
.hoverable__content.col-menu-desc {
  padding: .5em .5em;
  text-align: center;
  top: unset;
  bottom: 110%;
}

div.hoverable.label {
  border-bottom: none;
}

div.hoverable.label > div.hoverable__content {
  width: inherit;
}

.hoverable__content::before {
  position: absolute;
  right: 2em;
  bottom: 100%;
  content: ' ';
  z-index: 2;
  width: 0;
  height: 0;
  border-bottom: 0.5em solid rgba(101, 108, 126, 0.5);
  margin-right: -0.5em;
  border-right: 0.5em solid transparent;
  border-left: 0.5em solid transparent;
}
.hoverable__content.menu-description::before {
    left: -0.7em;
    top: 1em;
    right: inherit;
    transform: rotate(270deg);
}
.hoverable__content.edit-cell::before {
    left: -0.7em;
    top: 2.75em;
    right: inherit;
    transform: rotate(270deg);
}
.hoverable__content.build-code::before,
.hoverable__content.map-types::before {
    right: unset;
    left: 2em;
}
.hoverable__content.copy-tt-top::before,
.hoverable__content.col-menu-desc::before {
    bottom: unset;
    border-bottom: none;
    top: 95%;
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    -o-transform: rotate(180deg);
    transform: rotate(180deg);
}

.hoverable__content::after {
  position: absolute;
  right: 2em;
  bottom: calc(100% - .1em);
  content: ' ';
  z-index: 2;
  width: 0;
  height: 0;
  border-bottom: 0.5em solid white;
  margin-right: -0.5em;
  border-right: 0.5em solid transparent;
  border-left: 0.5em solid transparent;
}
.hoverable__content.menu-description::after {
    left: -0.6em;
    top: 1em;
    right: inherit;
    transform: rotate(270deg);
}
.hoverable__content.edit-cell::after {
    left: -0.6em;
    top: 2.75em;
    right: inherit;
    transform: rotate(270deg);
}
.hoverable__content.build-code::after,
.hoverable__content.map-types::after {
    right: unset;
    left: 2em;
}
.hoverable__content.copy-tt-top::after,
.hoverable__content.col-menu-desc::after {
    bottom: unset;
    top: calc(92% + .1em);
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    -o-transform: rotate(180deg);
    transform: rotate(180deg);
}

.tooltip-wrapper {
  display: inline-block;
}

.tooltip-wrapper i::before {
  color: #a7b3b7;
  font-size: .9rem;
}

.small-gutters {
  margin-right: -5px;
  margin-left: -5px;
}

.small-gutters > .col,
.small-gutters > [class*="col-"] {
  padding-right: 5px;
  padding-left: 5px;
}

.col--toggle {
  padding: .2rem !important;
  width: fit-content;
}

.table .ico-collapse-square {
  color: #656c7e;
}

.table .ico-expand-square {
  color: #a7b3b7;
}

.chart-wrapper {
  margin-top: 1em;
  border: solid #dce0e2 1px;
  padding: 1em;
  height: 25em;
  border-radius: 0.25rem;
  position: relative;
}

.menu-scrollable {
  height: 20em;
}

.menu-scrollable ul {
  height: 100%;
  overflow-y: scroll;
}

tr.selected {
  background-color: rgba(82, 187, 239, 0.2);
}

.pointer {
  cursor: pointer;
}

.tooltip-wrapper {
  padding-left: 5px;
  display: inline;
}

pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 11px;
  line-height: 1.42857143;
  color: #333;
  word-break: break-all;
  word-wrap: break-word;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border-radius: 4px;
}

pre {
    font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
}

pre {
    overflow: auto;
}

table tbody tr.clickable-row {
  cursor: pointer;
}

table tbody tr.highlight-row {
  background-color: rgba(82, 187, 239, 0.2);
}

.custom-select.axis-select {
  background: white url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 2'%3E%3Cpath fill='%23333' d='M2 2 L0 0 H4 Z'/%3E%3C/svg%3E") no-repeat right 0.75rem center;
  background-clip: padding-box;
  background-size: 8px 10px;
  border-radius: 0 .25rem .25rem 0 !important;
  cursor: pointer;
}

.dtale-alert {
  margin-top: 0.5em;
}

.dtale-alert.alert span.message {
  padding-left: 5px;
}

.dtale-alert.alert span {
  padding-left: 5px;
}

.dtale-alert.alert div.traceback {
  padding-top: 5px;
}

.dtale-alert.alert .ico-cancel {
  cursor: pointer;
}

.dtale-alert [class^="ico-"]::before {
  font-size: 1.25rem;
}

.modal-body table.table thead th {
  vertical-align: top;
}

.modal-body table.table thead label {
  font-weight: bold;
}

.hoverable.shape-info,
.hoverable.shape-info:hover {
  border-bottom: none;
}

.hoverable.shape-info button {
  line-height: 1.5;
}

.hoverable.shape-info .hoverable__content {
  left: 0;
  width: fit-content;
}

.hoverable.shape-info .hoverable__content::before,
.hoverable.shape-info .hoverable__content::after {
  right: auto;
  left: 1em;
}

.shape-info .prop-name {
  vertical-align: top;
  color: #656c7e;
}

.shape-info .prop-name::after {
  content: ': ';
}

.shape-info .prop-val {
  font-size: 0.7rem;
}

.dropdown {
    position: relative;
    display: inline-block;
}

.dropdown-content {
    display: none;
    position: absolute;
    min-width: 10em;
    border: 1px solid #ccc;
    background-color: #fff;
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px;
    box-shadow: 0 3px 6px rgba(0,0,0,0.2);
    z-index: 3000;
    right: 1em;
}

.dropdown-content a {
    display: block;
}

.dropdown:hover .dropdown-content {
    display: block;
}

.flames {
    background: url('../images/fire.jpg');
    background-size: cover;
    background-repeat: no-repeat;
    background-position: center;
    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
    -webkit-animation: fire .4s linear infinite;
}

@keyframes fire {
    0%{background-position:0% 50%;}
    0%{background-position:100% -50%;}
}

[data-tip] {
	position:relative;

}
[data-tip]:before {
	content:'';
	/* hides the tooltip when not hovered */
	display:none;
	content:'';
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	border-bottom: 5px solid #1a1a1a;
	position:absolute;
	top:30px;
	left:35px;
	z-index:8;
	font-size:0;
	line-height:0;
	width:0;
	height:0;
}
[data-tip]:after {
	display:none;
	content:attr(data-tip);
	position:absolute;
	top:35px;
	left:0px;
	padding:5px 8px;
	background:#1a1a1a;
	color:#fff;
	z-index:9;
	font-size: 0.75em;
	line-height:18px;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	white-space:nowrap;
	word-wrap:normal;
}
[data-tip]:hover:before,
[data-tip]:hover:after {
	display:block;
}

div#popup-content > div.modal-body > div.row {
    margin-left: 0;
    margin-right: 0;
}

div.container-fluid.build > div#popup-content > div.modal-body,
div.container-fluid.reshape > div#popup-content > div.modal-body{
  height: 260px;
}

div.container-fluid.describe > div#popup-content > div.modal-body {
  height: 450px;
}

div.container-fluid.describe {
    height: calc(100vh);
}
div.container-fluid.describe > div#popup-content {
    height: calc(100vh - 30px);
}
div.container-fluid.describe > div#popup-content > div.modal-body {
    height: calc(100vh - 75px);
    overflow-y: scroll;
}
div.container-fluid.describe div.describe-dtypes-grid-col {
    height: calc(100vh - 112px);
}
div.modal-dialog div.modal-body.describe-body {
  height: 500px;
  overflow-y: scroll;
  overflow-x: hidden;
}

div.modal-dialog div.modal-body.describe-body div.describe-dtypes-grid-col {
  height: 470px;
}

div.container-fluid.filter > div#popup-content > div.modal-body {
  height: 400px;
}

div.container-fluid.code-popup > div#popup-content > div.modal-footer,
div.container-fluid.code-export > div#popup-content > div.modal-footer {
  position: absolute;
  bottom: 0;
  width: 100%;
}

@media (min-height: 330px) {
  div.container-fluid.build > div#popup-content > div.modal-footer,
  div.container-fluid.reshape > div#popup-content > div.modal-footer {
    position: absolute;
    bottom: 0;
    width: 100%;
  }
}

@media (min-height: 475px) {
  div.container-fluid.filter > div#popup-content > div.modal-footer {
    position: absolute;
    bottom: 0;
    width: 100%;
  }
}

@media (min-height: 510px) {
  div.container-fluid.describe > div#popup-content > div.modal-footer {
    position: absolute;
    bottom: 0;
    width: 100%;
  }
}

@keyframes dtype-spin
{
  0% { transform: rotate(0);}
  100% { transform: rotate(360deg); }
}

.bg-icon {
  height: 18px;
  width: 18px;
  box-sizing: border-box;
  border: 5px solid; /* (1.5em * 0.25) */
  border-color: rgba(102,205,170,1.0) rgba(65,105,225,0.5) rgba(255,182,193,1.0) rgba(255,215,0,1.0);
  border-radius: 50%;
  opacity: 0.9;
  float: left;
}


.dtype-bg {
  border-color: rgba(102,205,170,1.0) rgba(65,105,225,0.5) rgba(255,182,193,1.0) rgba(255,215,0,1.0);
}

.missing-bg {
  border-color: #FFF59D #FFF59D #FFCC80 #FFCC80;
}

.outliers-bg {
  border-color: dodgerblue dodgerblue red red;
}

.dtype-bg.spin, .missing-bg.spin, .outliers-bg.spin {
  animation: dtype-spin 1s infinite linear;
}

.btn-group.column-sorting .btn.btn-primary {
  border: solid 1px #a7b3b7;
  -webkit-box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.2);
  box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.2);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(80%, white), to(#ebedee));
  background: linear-gradient(to bottom, white 80%, #ebedee);
  color: #404040;
}

.btn-group.column-sorting .btn.btn-primary:enabled:hover,
.btn-group.column-sorting .btn.btn-primary:enabled:focus {
  border: solid 1px #99a7ac;
  -webkit-box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.3);
  box-shadow: 0 1px 1px 0 rgba(112, 130, 136, 0.3);
}

.btn-group.column-sorting .btn.btn-primary:enabled:active {
  border: solid 1px #99a7ac;
  -webkit-box-shadow: 0 0 1px 0 rgba(112, 130, 136, 0.3), 0 0 1px 0 #cfd4d7 inset;
  box-shadow: 0 0 1px 0 rgba(112, 130, 136, 0.3), 0 0 1px 0 #cfd4d7 inset;
  background: -webkit-gradient(linear, left top, left bottom, from(#ebedee), to(white));
  background: linear-gradient(to bottom, #ebedee, white);
}

.btn-group.column-sorting .btn.btn-primary.active {
  border: solid 1px #88989e;
  -webkit-box-shadow: 0 0 3px 0 #88989e inset;
  box-shadow: 0 0 3px 0 #88989e inset;
  background: #a7b3b7;
  color: white;
}

.btn-group.column-sorting .btn.btn-primary.active:enabled:hover {
  border: solid 1px #88989e;
  -webkit-box-shadow: 0 0 3px 0 #88989e inset;
  box-shadow: 0 0 3px 0 #88989e inset;
  background: #a7b3b7;
  cursor: default;
}

.btn-group.column-sorting .btn.btn-primary.active:enabled:active,
.btn-group.column-sorting .btn.btn-primary.active:enabled:focus {
  border: solid 1px #88989e;
  -webkit-box-shadow: 0 0 3px 0 #88989e inset;
  box-shadow: 0 0 3px 0 #88989e inset;
  background: #a7b3b7;
}


